// COSMIC CLOCK ATmega644 Rev B 

// Changes since Rev A:

// 1) Can now auto cycle through all the seconds ring animation modes at a user configurable interval (instead
//    of just being able to cycle through 6 seconds ring animation modes at a fixed interval of 10 minutes).

// 2) When showing the full planet's name can now optionally alternate it with displaying an abbreviated form
//    of the planet's name together with its current magnitude.

// 3) When the Moon is full, instead of displaying 'All' as the percentage, we are now displaying 'FL.' - which
//    is short for FULL (we only have 2 digits to display something on)


// adapted sketch by niq_ro from http://arduinotehniq.blogspot.com
// and http://nicuflorica.blogspot.ro
// version 1.0 in 6.11.2014, Craiova - Romanaia
// curent version in 12.1.2015
// source for LEDControl: http://embedded-lab.com/blog/?p=6862


void(* resetFunc) (void) = 0; // create a standard reset function to be called at midnight

#include "LedControl.h" 
#include <OneWire.h>                     // This library allows you to communicate with I2C                   
#include <DallasTemperature.h>           // For Dallas DS18B20 Temp-Sensor
 
 
// #define LIGHT A0                         // Photoresistor (LDR) for steering brightness on Arduino atmega328
#define LIGHT A0                         // Photoresistor (LDR) for steering brightness on Arduino atmega644 -  actual pin 40
//#define ONE_WIRE_BUS 4                   // Data wire is plugged into pin 4 on the Arduino atmega328
#define ONE_WIRE_BUS 12                   // Data wire is plugged into port D4 on the Arduino atmega644
OneWire oneWire(ONE_WIRE_BUS);           // Setup a oneWire instance to communicate with any OneWire devices (not just Maxim/Dallas temperature ICs) 
DallasTemperature sensors(&oneWire);     // Pass our oneWire reference to Dallas Temperature.
DeviceAddress tempDeviceAddress;         // We'll use this variable to store a found device address
 
//CHOOSE EITHER ONE OF THE 2 LINES BELOW MAKING SURE YOU HAVE THE CORRECT LIBRARY (ORIGINAL SLOW SOFTWARE BITBANGING, OR FAST HARDWARE SPI) IN THE ARDUINO LIBRARIES FOLDER
//LedControl lc=LedControl(12,11,10,1); //authors original
//LedControl lc=LedControl(11,13,10,4); // for atmega328. if using slow original software bitbanging library version. For Reference, LedControl parameters: LedControl(data pin, clock pin, load pin, max7219_quantity). Pins chosen so that hardware or bitbanged SPI can be implemented without any electrical changes
LedControl lc=LedControl(5,7,23,7); // for atmega644 using Mightycore. if using slow original software bitbanging library version. For Reference, LedControl parameters: LedControl(data pin, clock pin, load pin, max7219_quantity). Pins chosen so that hardware or bitbanged SPI can be implemented without any electrical changes
//LedControl lc=LedControl(23, 4); // if using new fast hardware spi library. Needs only 2 parameters, the load pin, and the number of cascaded max7219 devices (the Data and clk pins are fixed in hardware with this hardware spi library, for Atmega328/Atmega8: Data is Arduino pin 11, Clk is Arduino pin 13). For Reference, LedControl parameters: LedControl(load pin, max7219_quantity)


int t;
int ziua0, luna0, anul0, dow0;


#include <Wire.h>
#include "RTClib.h" // from https://github.com/adafruit/RTClib
//#include <LiquidCrystal.h>
//#include <Encoder.h> // from http://www.pjrc.com/teensy/td_libs_Encoder.html

//RTC_DS1307 RTC; // Tells the RTC library that we're using a DS1307 RTC - ORIGINAL WORKS
RTC_DS3231 RTC; // Tells the RTC library that we're using a DS3231 RTC
///Encoder knob(2, 3); //encoder connected to pins 2 and 3 (and ground)

//the variables provide the holding values for the set clock routine
int setyeartemp; 
int setmonthtemp;
int setdaytemp;
int sethourstemp;
int setminstemp;
int setsecs = 0;
int maxday; // maximum number of days in the given month
int TimeOut = 10;
int TimeOutCounter;

// These variables are for the push button routine
int buttonstate = 0; //flag to see if the button has been pressed, used internal on the subroutine only
int pushlengthset = 6000; // value for a long push in mS - was 2000
int pushlength = pushlengthset; // set default pushlength
int pushstart = 0;// sets default push value for the button going low
int pushstop = 0;// sets the default value for when the button goes back high

int knobval; // value for the rotation of the knob
boolean buttonflag = false; // default value for the button flag

//byte SW1 = 6;  // switch for down - was 2 (moved to enable use of first interupt pin which is Arduino pin 2 - real pin D2) for atmega328
byte SW1 = 18;  // 'down' button for atmega644, actual Atmega644 pin 24
//byte SW2 = 7;  // switch for up - was 3 (moved to enable use of second interupt pin which is Arduino pin 3 - real pin D3) for atmega328
//byte SW2 = 15;  // switch for up - was 3 (moved to enable use of second interupt pin which is Arduino pin 3 - real pin D3) for atmega644
byte SW2 = 30;  // 'up' button for atmega644, actual Atmega644 pin 34


//Reason for 'byte ggg' on line below - IN PROTEUS SIMULATION IT SEEMED (BEFORE 'byte ggg' was introduced) TO TAKE A NOTICEABLE FRACTION OF A SECOND FOR THE TEMPERATURE
//                                      TO SHOW A STEADY READING, AND NOT A LEFT OVER FROM WHAT WAS BEING DISPLAYED ON THE DATE SCREEN PREVIOUSLY BEING DISPLAYED. MAYBE THIS IS
//                                      HAPPENING AS BEFORE THE 'byte ggg' WAS INTRODUCED THE TEMPERATURE WAS BEING UPDATED NUMEROUS TIMES (11 TO 13
//                                      DURING SIMULATION) THROUGHOUT THE 1 SECOND THAT THE 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13...'
//                                      STATEMENT IS 'TRUE' FOR.

byte ggg = 0; // counter variable to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 11 || second0 == 21 || second0 == 31...' statement that defines when the temperature is displayed
byte hhh = 0; // counter variable to limit scrolling section of date display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 8 || second0 == 18 || second0 == 28 || second0 == 38...' statement that defines when the scrolling temperature is displayed
byte ddd = 0; // counter variable to limit ring second reset at 0 seconds (ie, turn all LEDs off) to one instance as opposed to multiple updates throughout the full second that the seconds are at 0
byte eee = 0; // counter variable to limit all the 60 LEDs making up the second ring to being lit up just once, at startup only, when 'Inverse of single LED lit at current second' animation is selected.
byte ttt = 0; // counter variable to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 11 || second0 == 21 || second0 == 31...' statement that defines when the temperature and humidity is displayed
byte fff = 0; // counter variable to limit static date display ('15 May' format) to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 9 || second0 == 19 || second0 == 29 || second0 == 39...' statement that defines when the static date ('15 May' format) is displayed
byte xxx = 0; // counter variable to limit static date display ('Mon 15' format) to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 6 || second0 == 16 || second0 == 26 || second0 == 36...' statement that defines when the static date ('Mon 15' format) is displayed
byte yyy = 0; // counter variable to limit 'crimbo' to a single instance during the full second of the 'if' statement that defines when it's displayed
byte ccc = 0; // counter variable to limit 'birthday' to a single instance during the full second of the 'if' statement that defines when it's displayed
byte www = 0; // counter variable to limit 'newyear' to a single instance during the full second of the 'if' statement that defines when it's displayed
byte kkk = 0; // counter variable to limit quotes on top and bottom 4-digit displays to a single instance during the full second of the 'if' statement that defines when it's displayed
byte zzz = 0; // counter variable to limit ring second reset at 0 seconds (ie, turn all LEDs off) to one instance as opposed to multiple updates throughout the full second that the seconds are at 0
byte nnn = 0; // counter variable to limit ring second reset at 0 seconds (ie, turn all LEDs on) to one instance as opposed to multiple updates throughout the full second that the seconds are at 0
byte aaa = 0; // counter variable to limit ring minute reset at 0 seconds (ie, turn all LEDs off) to one instance as opposed to multiple updates throughout the full second that the seconds are at 0

bool ClockJustBeenSet = false;

//#define HYSTERESIS 20 // in ADC counts, prevents oscillation for autodimming. was 5
//static int8_t currentHysteresis = 0; // Do not use hysteresis the first time
//byte brightness2 = 255; // Use an invalid value so that brightness is updated the first time
int bright; // used in auto-dimming subroutine

int old_secs = 65; //holds old seconds value - from last time seconds were updated to display - used to check if seconds have changed. (Use an invalid value, ie any value above 59 seconds, as the seconds never exceed 59 obviously, so that time is updated the first time)

//byte QuotePin = 8; // Actual Atmega328 pin Port B0, ie. pin 14. input for sensing whether the quotes should be displayed or not via a switch on the back of the clock
//byte BirthdayPin = 9; // Actual Atmega328 pin Port B1, ie. pin 15. input for sensing whether the birthday countdowns should be displayed or not via a switch on the back of the clock
//byte FacePin = 16; // Actual Atmega328 pin Port C2, ie. pin 25. input for sensing whether the sleepy/awake faces should be displayed or not via a switch on the back of the clock
//byte FunnyPin = 17; // Actual Atmega328 pin Port C3, ie. pin 26. input for sensing whether either the 'motivational' or the 'funny' 4-digit quotes should should be displayed via a switch on the back of the clock

#define BINARY_1 31 // Actual Atmega644 pin Port A7, ie. pin 33. OUTPUT PIN FOR LEAST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
#define BINARY_2 22 // Actual Atmega644 pin Port C6, ie. pin 28. OUTPUT PIN FOR 2ND LEAST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
#define BINARY_4 21 // Actual Atmega644 pin Port C5, ie. pin 27. OUTPUT PIN FOR 2ND MOST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
#define BINARY_8 20 // Actual Atmega644 pin Port C4, ie. pin 26. OUTPUT PIN FOR MOST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
#define DOT_CLOCK 15 // Actual Atmega644 pin Port D7, ie. pin 21. Output pin linked to Atmega328 that is logic high if seconds are being shown on outer yellow LED ring, and logic low if minutes are being shown on outer yellow LED ring (THE HOUR BEING DISPLAYED SIMULTANEOUSLY AS A SINGLE LIT PINK INDEX LED VIA THE ATMEGA328)
byte twelve_clock; // variable that is the time (hours only) in 12 hour clock format that is used to send this time (hours only), binary encoded, via 4x Atmega644 pins to the Atmega328

//#define BST_pin A2 // switch conected to pin Port A2, ie, pin 38 to define british summer time
//#define auto_cycling_pin A3 // switch conected to pin Port A3, ie, pin 37 to select or not an auto cycling (every 10 mins) LED seconds ring animation
#define meteor_option_pin A3 // switch conected to pin Port A3, ie, pin 37 to select whether to show either when the next meteor shower is, or atmospheric pressure info (if BMP180 fitted)

//#include <Arduino.h> // needed when using EasyButton library
#include <EasyButton.h> // needed when using EasyButton library
//#define BUTTON_ONE_PIN 2 // pin for 'menu' button arduino atmega328
#define BUTTON_ONE_PIN 0 // pin for 'menu' button arduino atmega644 actual pin no. 1
EasyButton button1(BUTTON_ONE_PIN); // Instance of the button.
//#define BUTTON_TWO_PIN 3 // pin for 'LED ring alter' button arduino atmega328
//#define BUTTON_TWO_PIN 1 // pin for 'LED ring alter' button arduino atmega644 actual pin no. 2
#define BUTTON_TWO_PIN 10 // pin for 'LED ring alter' button arduino atmega644 actual pin no. 16 - supports external interrupts
EasyButton button2(BUTTON_TWO_PIN); // Instance of the button.
//#define BUTTON_THREE_PIN 7 // pin for 'UP' button arduino atmega328
//#define BUTTON_THREE_PIN 15 // pin for 'UP' button arduino atmega644 actual pin no. 21
#define BUTTON_THREE_PIN 11 // pin for 'UP' button arduino atmega644 actual pin no. 17 - supports external interrupts
EasyButton button3(BUTTON_THREE_PIN); // Instance of the button.

byte LED_RING_ANIMATION = 0; // was 0
byte time_display_mode = 0;
boolean LED_MODE_1_CHANGED = false; // to allow all LEDs to be turned off for LED_MODE 1 (just once) when the mode has just been changed
boolean LED_MODE_1_CHANGED_END = false; // to allow all LEDs to be turned off for LED_MODE 1 (just once) when the mode has just been changed
// boolean LED_MODE_3_CHANGED = false; // to allow all LEDs to be turned on for LED_MODE 3 (just once) when the mode has just been changed

boolean short_push = false; // to allow seconds ring LEDs to be reset (all turned off) when pushing button on port C0 do display something for 2 secs
boolean just_powered_up = true; // to allow seconds LED ring to fill to current seconds on power-up in anticlockwise animating seconds LED mode
boolean midnight_animation = false; // to allow seconds LED ring to fill to current seconds on power-up in anticlockwise animating seconds LED mode after a midnight animation
boolean quote_occured = false; // to allow seconds ring to fill up with the appropraite number of LEDs after a 'on this day in 1945...' style quote
boolean scroll_occured = false; // to allow seconds ring to fill up with the appropraite number of LEDs after a scrolling quote (or fun fact)
boolean face_occured = false; // to allow seconds LED ring to fill to current seconds in various animating seconds LED mode after a sleepy/awake face showing

// NOTE, for Atmega644 the 6 PWM output pins are actual pins 4, 5, 18, 19, 20, 21 (which corresponds to Arduino MightyCore pins 3, 4, 12, 13, 14, 15 - where pins 3 and 4 are 1Khz, the other 4 pins being 500Hz)
//#define pwm_auto_dimming 5  // pwm auto dimming pin is arduino pin D5 for atmega328
//#define pwm_auto_dimming 3  // pwm auto dimming pin is arduino pin D3 for atmega644
#define pwm_auto_dimming 14  // pwm auto dimming pin is arduino pin D14 for atmega644

int days_left; // days remaining to next event (eg birthday)

byte hour_twelve; // time (hours only) in 12 hour format
boolean IS_IT_AM; // is it am or pm


// EXTRA SUN MOON STUFF
#include <sundata.h>
// For Birmingham
#define LONGITUDE -1.8904  // Longitude of current location (west is negative)
#define LATITUDE  52.4862 // Latitude of current location (north is positive
#define rad  PI/180               // degrees / rad 
#define irad 180/PI               // rad / degree
#define ob rad*23.4397            // obliquity of the earth (23.4397 deg.)
double mdist;                     // distance to moon
double mra,mdec,maz,mad,mal;      // moon info. (right ascension,declination, azimuth, azimuth_degrees, altitude)
sundata vdm(0,0,0);


double mfract, mphase, mangle;    // moon fraction illuminated, moon phase, moon angle
double sra,sdec,saz,sad,sal;      // solar information



// Array of character strings stored in PROGMEM

// cardinal directions
const char ca0[]  PROGMEM = "N  ";
const char ca1[]  PROGMEM = "NNE";
const char ca2[]  PROGMEM = "NE ";
const char ca3[]  PROGMEM = "ENE";
const char ca4[]  PROGMEM = "E  ";
const char ca5[]  PROGMEM = "ESE";
const char ca6[]  PROGMEM = "SE ";
const char ca7[]  PROGMEM = "SSE";
const char ca8[]  PROGMEM = "S  ";
const char ca9[]  PROGMEM = "SSW";
const char caA[]  PROGMEM = "SW ";
const char caB[]  PROGMEM = "WSW";
const char caC[]  PROGMEM = "W  ";
const char caD[]  PROGMEM = "WNW";
const char caE[]  PROGMEM = "NW  ";
const char caF[]  PROGMEM = "NNW";

const char * const cas[] PROGMEM = { ca0,ca1,ca2,ca3,ca4,ca5,ca6,ca7,ca8,ca9,caA,caB,caC,caD,caE,caF };

 char cb[4];                 // character buffer for character strings. Set dimension to length of longest string
 float el_deg, az_deg, sunup, sundn;
// int phase, azi,oazi=400,ele,oele=400;
// byte ms,mt,mi;
// float s,x,y,x1,y1;

// https://raw.githubusercontent.com/slackmasterstan/Moon-in-my-room/master/Moon.ino
// http://slackworld.org/blog/archives/311

static float Dec[3] = { 0.0, 0.0, 0.0 };
static float RAn[3] = { 0.0, 0.0, 0.0 };
static float VHz[3] = { 0.0, 0.0, 0.0 };
static float Sky[3] = { 0.0, 0.0, 0.0 };
const static float DR = M_PI / 180;

static int Rise_time[2] = {0.0, 0.0}; 
static int Set_time[2] = {0.0, 0.0};

static bool Moonrise, Moonset;
//static int TZ;
static long TZ; //  see reasons in nDays subroutine as to why this was changed to an 'long'

int hr, mn, se, osec=-1, omin=-1, ohr=-1, dy, ody=0, mo, yr, dw;

// eeprom storage
// #include <EEPROM.h>               // for alarm and mode data storage
// int dst;                          // dst setting                      
// int *set[] = { &dst };            // values to set/recover from EEPROM

//#define serEn true            // set to true to enable a serial output if the '#if(serEn)' command, followed by a '#endif' command at the end of the serial.print commands is used.
#define serEn false            // set to false to disable a serial output if the '#if(serEn)' command, followed by a '#endif' command at the end of any serial.print commands is used.

#include <avr/pgmspace.h>          // for memory storage in program space
#include <math.h>                 // math for moon position calculations 

#include "clock_planets.h"

int Year, Hour;
byte Month, Day, Minute, Seconds;

// boolean IsDST;

int ora0;
float Merc_elev, Merc_azim, Merc_mag, Ven_elev, Ven_azim, Ven_mag, Mars_elev, Mars_azim, Mars_mag, Jup_elev, Jup_azim, Jup_mag, Sat_elev, Sat_azim, Sat_mag, Uran_elev, Uran_azim, Uran_mag, Nep_elev, Nep_azim, Nep_mag;
byte moon_ill;
float ph_1;

boolean cycle = false; // to determine wheher or not the LED seconds ring animation is auto cycling every 10 mins or not
boolean min_0s = true;
boolean min_10s = true;
boolean min_20s = true;
boolean min_30s = true;
boolean min_40s = true;
boolean min_50s = true;

#define LED1 2 // Moon visible LED, Atmega 644 pin 3
#define LED2 28 // Saturn visible LED, Atmega 644 pin 36
#define LED3 4 // Neptune visible LED, Atmega 644 pin 5
#define LED4 6 // Mercury visible LED, Atmega 644 pin 7
//#define LED5 10 // Mars visible LED, Atmega 644 pin 16
#define LED5 1 // Mars visible LED, Atmega 644 pin 2
//#define LED6 11 // Venus visible LED, Atmega 644 pin 17
#define LED6 29 // Venus visible LED, Atmega 644 pin 35
#define LED7 13 // Uranus visible LED, Atmega 644 pin 19
//#define LED8 14 // Jupiter visible LED, Atmega 644 pin 20
#define LED8 3 // Jupiter visible LED, Atmega 644 pin 4


byte temp_limiter = 0; // to allow the display to show '---' degrees instead of '00.0' degrees before a temperature measurement has been made

int LED_azim = 400; // an impossible azimuth number to stop LEDs lighting at switch on
float LED_elev = 100.0;

#include <FastPwmPin.h>


#include <Wire.h>
#include <SFE_BMP180.h>

// You will need to create an SFE_BMP180 object, here called "bmp180":
SFE_BMP180 bmp180;

float alt = 214.0; // Altitude of current location in meters above sea level, used to convert local pressure reading to a reading referenced to sea level
unsigned long TFT_Millis = 0;
unsigned long TFT_Previous = 0;
const unsigned long TFT_Interval = 600000; // 600000 is 10 minutes (interval between pressure readings)
//const unsigned long TFT_Interval = 1000; // testing only - interval between pressure readings is 1 second
#define sizeTrend 27 // number of points in the pressure trend array
int in1[sizeTrend];// array for the pressure trend. int refers to the data type in the buffer (not the number of values in the buffer)
int pressure_holding;
float difference_4hour; // change in pressure over the previous 4 hours
float difference_2hour; // change in pressure over the previous 2 hours
byte pressure_counter = 0; // only display pressure difference over last 4 hours and 2 hours if 'pressure_counter' has reached certain values (equivalent to 4 hours and 2 hours having elapsed since power-up)
#define bmp180En true // if bmp180 is fitted
//#define bmp180En false // if bmp180 is not fitted
double seaLevelPressure;
float seaLevelPressure_round;
float difference_2hour_temp;
float difference_4hour_temp;
float difference_2hour_holding;
float difference_4hour_holding;
int diff_2hour_holding;
int diff_2hour_holding_old = 999; // an impossible number to force an immediate update
int diff_4hour_holding;
int diff_4hour_holding_old = 999; // an impossible number to force an immediate update

boolean press_auto_cycle = true; // when displaying an alternating actual seconds/pressure history on the seconds ring, when displaying the actual seconds, the LED animation mode will change every 10 minutes
//boolean press_auto_cycle = false; // when displaying an alternating actual seconds/pressure history on the seconds ring, when displaying the actual seconds, the LED animation mode will stay fixed and NOT change every 10 minutes

boolean dot_clock_display_seconds = true; // when in 'dot clock' display mode show the actual seconds on the display that usually displays the time
//boolean dot_clock_display_seconds = false; // when in 'dot clock' display mode show 'AM' or 'PM' on the display that usually displays the time

#define Time_Zone_DST 1  // The numbers or hours ahead/behind UTC (GMT) time when IN Daylight Saving Time of your location. (If ahead of UTC time, number is positive. If behind of UTC time, number is negative)
#define Time_Zone_NO_DST 0  // The numbers or hours ahead/behind UTC (GMT) time when NOT IN Daylight Saving Time of your location. (If ahead of UTC time, number is positive. If behind of UTC time, number is negative)

unsigned long Seconds_Millis = 0; // to auto cycle seconds ring animation modes with new method
unsigned long Seconds_Previous = 0; // to auto cycle seconds ring animation modes with new method
const unsigned long Seconds_Interval = 300000; // 300000 is 5 minutes (interval between seconds ring animation modes)
//const unsigned long Seconds_Interval = 5000; // testing only - interval between seconds ring animation modes is 5 seconds

boolean mag_show = true; // show the planet's magnitude, together with an abbreviated version of it's name, 2 seconds after showing the full planets name (with its azimuth and elevation)
//boolean mag_show = false; // does NOT show the planet's magnitude, together with an abbreviated version of it's name, 2 seconds after showing the full planets name (with its azimuth and elevation)


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// THE OPTIONALLY FITTED TOP MOUNTED AZIMUTH RING OF LEDs NEEDS TO HAVE THE NORTH DIRECTION DEFINED
// TO MATCH THE CLOSEST ORIENTATION OF YOUR DISPLAY FRAME, AS SHOWN IN THE 2 EXAMPLES AND SUMMARY BELOW:


// EXAMPLE 1, WITH NORTH POINTING DIRECTLY AWAY FROM VIEWING SIDE OF DISPLAY (#define north_angle 0).
// --------------------------------------------------------------------------------------------------


//              TOP VIEW
//              --------

 
//       Eg. NORTH AT 0 DEGREES
//                 /|\
//                  |
//                  |
//                  |
 
//            back of frame
//           _______________
//          |               |
//          |_______________|

//     front of frame (viewing side)







// EXAMPLE 2, WITH NORTH POINTING TO THE RIGHT OF THE FRAME AS VIEWED FROM THE FRONT (#define north_angle 90).
// -----------------------------------------------------------------------------------------------------------


//              TOP VIEW
//              --------


//            back of frame
//           _______________
//          |               |        ________\   Eg. NORTH AT 90 DEGREES  
//          |_______________|                /

//     front of frame (viewing side)







// ORIENTATION SUMMARY:
// --------------------

//                                 TOP VIEW
//                                 --------

//                               back of frame
//                              _______________
//                             |               |
//                             |_______________|

//                       front of frame (viewing side)



//                             NORTH AT 0 DEGREES
//                                    /|\
//                                     |
//                                     |
//                                     |
//    NORTH AT 270 DEGREES  /________     ________\  NORTH AT 90 DEGREES  
//                          \                     /
//                                     |
//                                     |
//                                     |
//                                    \|/
//                            NORTH AT 180 DEGREES






// UNCOMMENT ONE OF THE 12 FOLLOWING NORTH ORIENTATIONS TO MATCH THE CLOSEST ORIENTATION OF YOUR DISPLAY FRAME:

#define north_angle 0 // NORTH AT 0 DEGREES
//#define north_angle 30 // NORTH AT 30 DEGREES
//#define north_angle 60 // NORTH AT 60 DEGREES
//#define north_angle 90 // NORTH AT 90 DEGTREES
//#define north_angle 120 // NORTH AT 120 DEGREES
//#define north_angle 150 // NORTH AT 150 DEGREES
//#define north_angle 180 // NORTH AT 180 DEGREES
//#define north_angle 210 // NORTH AT 210 DEGREES
//#define north_angle 240 // NORTH AT 240 DEGREES
//#define north_angle 270 // NORTH AT 270 DEGREES
//#define north_angle 300 // NORTH AT 300 DEGREES
//#define north_angle 330 // NORTH AT 330 DEGREES

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void button2ISR()
{
  button2.read();
}

void button3ISR()
{
  button3.read();
}


////////////////////////////////////////////////////////////////////////////////////////////////////////

void setup()
{
	
// Initialize MAX7219 devices

lc.shutdown(0,false); // Enable time display 
lc.setIntensity(0,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(0); // Clear display register 

lc.shutdown(1,false); // Enable date display 
lc.setIntensity(1,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(1); // Clear display register 

lc.shutdown(2,false); // Enable ring seconds display 
lc.setIntensity(2,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(2); // Clear display register 

lc.shutdown(3,false); // Enable 2x 4-digit displays connected to this max7219 (show temperature, and rise/set times)
lc.setIntensity(3,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(3); // Clear display register 

lc.shutdown(4,false); // Enable top 8-digit display cycling through planet names 
lc.setIntensity(4,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(4); // Clear display register 

lc.shutdown(5,false); // Enable 2x 4-digit displays cycling through elevation and azimuth realtime moon/planet positions
lc.setIntensity(5,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(5); // Clear display register 

lc.shutdown(6,false); // Enable 2x 2-digit displays showing moon day number (0 to 29), and moon illumination in percent
lc.setIntensity(6,3); // Set brightness level (0 is min, 15 is max) 
lc.clearDisplay(6); // Clear display register 
 

    Wire.begin();
    RTC.begin();
//  if (! RTC.isrunning()) {
    //Serial.println("RTC is NOT running!");
    // following line sets the RTC to the date & time this sketch was compiled
//    RTC.adjust(DateTime(__DATE__, __TIME__));
// }

/*
// part code from http://tronixstuff.wordpress.com/
Wire.beginTransmission(0x68);
Wire.write(0x07); // move pointer to SQW address
//Wire.write(0x10); // sends 0x10 (hex) 00010000 (binary) to control register - turns on square wave
Wire.write(0x13); // sends 0x13 (hex) 00010011 (binary) to control register - turns on square wave at 32kHz
Wire.endTransmission();
// end part code from http://tronixstuff.wordpress.com/
*/

//pinMode(A0,INPUT);//push button on encoder connected to A0 (and GND) or MENU/NEXT
//digitalWrite(A0,HIGH); //Pull A0 high - ging old version of activating pullup - still seems to work
pinMode(A1,INPUT_PULLUP); // for navigating through menu button on atmega644

// pinMode(SW1, INPUT);  // N.O. push button switch
// pinMode(SW2, INPUT);  // N.O. push button switch

// digitalWrite(SW1, HIGH); // Pull SW1 pin high  - ging old version of activating pullup - still seems to work
// digitalWrite(SW2, HIGH); // pull SW2 pin high  - ging old version of activating pullup - still seems to work

pinMode(SW1,INPUT_PULLUP);
pinMode(SW2,INPUT_PULLUP);

// pinMode(BST_pin,INPUT_PULLUP); // switch to define british summer time
//pinMode(auto_cycling_pin,INPUT_PULLUP); // switch to define whether the LED seconds ring animation is auto cycling every 10 mins or not
pinMode(meteor_option_pin,INPUT_PULLUP); // switch to define whether to show either when the next meteor shower is, or atmospheric pressure info (if BMP180 fitted)

pinMode(BINARY_1,OUTPUT); // OUTPUT PIN FOR LEAST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
pinMode(BINARY_2,OUTPUT); // OUTPUT PIN FOR 2ND LEAST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
pinMode(BINARY_4,OUTPUT); // OUTPUT PIN FOR 2ND MOST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
pinMode(BINARY_8,OUTPUT); // OUTPUT PIN FOR MOST SIGNIFICANT BIT OF BINARY ENCODED HOUR INFORMATION FROM ATMEGA644 TO INPUTS OF ATMEGA328
pinMode(DOT_CLOCK,OUTPUT); // Output pin linked to Atmega328 that is logic high if seconds are being shown on outer yellow LED ring, and logic low if minutes are being shown on outer yellow LED ring (THE HOUR BEING DISPLAYED SIMULTANEOUSLY AS A SINGLE LIT PINK INDEX LED VIA THE ATMEGA328)



  //Setup DS18B20 Temperature-Sensor 
  sensors.begin();                                          // start up Dallas Temperature library
  sensors.getAddress(tempDeviceAddress, 0);                 // get the address of the first DS18B20 Temp-Sensor
  sensors.requestTemperaturesByAddress(tempDeviceAddress);  // sends command for one device to perform a temperature by address
//  sensors.setResolution(tempDeviceAddress, 11); // set the resolution of the DS18B20 to 11 bit (can be 9, 10, 11, or 12 bit) - defaults to 12 bit. 12 bit (0.0625 degrees resolution) takes 750msec, 11 bit (0.125 degrees resolution) takes 375msec, 10 bit (0.25 degrees resolution) takes 188msec, 9 bit (0.5 degrees resolution) takes 94msec


  button1.begin();  // Initialize the EasyButton library for button 1.
  button2.begin();  // Initialize the EasyButton library for button 2.
  button3.begin();  // Initialize the EasyButton library for button 3.
  
  button2.onPressed(Increment_LED_RING);
  button3.onPressed(Increment_time_display);
  
  if (button2.supportsInterrupt())
  {
    button2.enableInterrupt(button2ISR);
  }
  
  if (button3.supportsInterrupt())
  {
    button3.enableInterrupt(button3ISR);
  }

  button1.onPressedFor(500, test_only); // if button pressed for 1 secs go to 'test_only' subroutine
//  button1.onPressedFor(1000, ShortPush); // if button pressed for 1 secs go to 'test_only' subroutine - OVERRIDES THE SHORTER onPressedFor, so can't have a long and short press
//  button1.onSequence(2, 800, ShortPush); // 2 is 2 button presses (ie a double click), 1000 is 1000msec timeout - DOESN'T WORK PROPERLY

//  button2.onPressedFor(30, Increment_LED_RING); // if button 2 pressed for 30mSec go to 'Increment_LED_RING' subroutine
  
//  button3.onPressedFor(30, Increment_time_display); // if button 3 pressed for 30mSec go to 'Increment_time_display' subroutine

  // enable the 1 Hz output of DS3231
  RTC.writeSqwPinMode (DS3231_SquareWave1Hz);
  
 // pinMode(12,OUTPUT); // 10msec pulse at change of second. atmega328
  pinMode(19,OUTPUT); // 10msec pulse at change of second. atmega644
  
  
  digitalWrite(LED1, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED2, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED3, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED4, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED5, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED6, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED7, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  digitalWrite(LED8, HIGH);// so that planet visibilty LED doesn't light up briefly at power up
  pinMode(LED1,OUTPUT); // moon visible LED
  pinMode(LED2,OUTPUT); // saturn visible LED
  pinMode(LED3,OUTPUT); // neptune visible LED
  pinMode(LED4,OUTPUT); // mercury visible LED
  pinMode(LED5,OUTPUT); // mars visible LED
  pinMode(LED6,OUTPUT); // venus visible LED
  pinMode(LED7,OUTPUT); // uranus visible LED
  pinMode(LED8,OUTPUT); // jupiter visible LED
  
//  analogWrite(pwm_auto_dimming, 70); // set an initial autodimming intensity pink seconds index LEDs (which aren't powered by the max7219s)
  pinMode(14, OUTPUT);  
  FastPwmPin::enablePwmPin(pwm_auto_dimming, 7800L, 90); // setup FastPWM output on Arduino pin 14 (actual pin 20) of the Atmega644, at 7800Hz, at 90% duty cycle initially (could infact be anything)

  bool success = bmp180.begin(); 
 
#if(serEn)
 Serial.begin(57600);
 Serial.println("Output variables test ");
 Serial.println("---------------------");
 Serial.print("DS18B20 temperature sensor resolution: ");
 Serial.print(sensors.getResolution(tempDeviceAddress), DEC); // either 9, 10, 11, or 12 bit - defaults to 12 bit
 Serial.println("  (can be 9, 10, 11, or 12 bit)");
 
 if (success) Serial.println("BMP180 init success");
#endif


//delay(800); // this is the minimum value to get a valid temperature measurement via the line below at initial power up, though it may add a visually unappealing blank display if reboting atmega644 at midnight (as a workaround) due to incorrect moonrise/moonset times on days where moon doesn't rise or set if atmetga644 is power up when transitioning to these days
//t = measure_Temp(); // routine to measure temperature (not display it).



// midnight (); // midnight animation with quote - test only

//  getTime();

}



////////////////////////////////////////////////////////////////////////////////////////////////

//void(* resetFunc) (void) = 0; // declare reset function at address 0

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


void loop()
{
    TFT_Millis = millis(); 
    Seconds_Millis = millis(); 

// Serial.print("counts for LED animation ring in main loop are  ");
// Serial.println(LED_RING_ANIMATION);
 
  button1.read(); //     When using the EasyButton library continuously read the status of button 1.
//  button2.read(); //     When using the EasyButton library continuously read the status of button 2. UPDATE - NOW THIS BUTTON IS AN INTERRUPT BASED ONE
//  button3.read(); //     When using the EasyButton library continuously read the status of button 3 ('UP' button). UPDATE - NOW THIS BUTTON IS AN INTERRUPT BASED ONE
 

	
DateTime now = RTC.now();
    ora0 = now.hour(); // have removed the 'int' from the beginning of this line, and added 'int ora0' at the begining of the sketch as, for some unexplained reason, adding 'if (ora0 == 0)...' when displaying the Sun's azimuth as the text value 'Nor.' between 00:00 and 00:59 causes Proteus to hang the sketch very quickly after starting it, but not in a predictable timescale..could be almost immediately..could be after several seconds
int minut0 = now.minute();
int second0 = now.second();	
int ziua0 = now.day();
int luna0 = now.month();
int anul0 = now.year();
int dow0 = now.dayOfTheWeek(); // Day of the week. returns 0-6 where 0 = Sunday, and 6 = Saturday
 hr = now.hour(); if(hr==0) hr=24;                      // adjust to 1-24
 mn = now.minute();
 se = now.second();
 yr = now.year();
 mo = now.month();
 dy = now.day();
 dw = now.dayOfTheWeek();

if (ora0 <= 12) twelve_clock = ora0; // 12 hour clock format 
if (ora0 > 12) twelve_clock = ora0 - 12; // 12 hour clock forma

if (ora0 < 12) IS_IT_AM = true;
if (ora0 >= 12) IS_IT_AM = false;


if (twelve_clock == 0 || twelve_clock == 12) { // SENDING HOURS TO ATMEGA328 VIA 4-BIT BINARY
	digitalWrite(BINARY_1, LOW); 
	digitalWrite(BINARY_2, LOW); 
	digitalWrite(BINARY_4, LOW); 
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 1) {
	digitalWrite(BINARY_1, HIGH);
    digitalWrite(BINARY_2, LOW);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 2) {
	digitalWrite(BINARY_1, LOW);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 3) {
	digitalWrite(BINARY_1, HIGH);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 4) {
	digitalWrite(BINARY_1, LOW);
	digitalWrite(BINARY_2, LOW);
	digitalWrite(BINARY_4, HIGH);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 5) {
	digitalWrite(BINARY_1, HIGH);
	digitalWrite(BINARY_2, LOW);
	digitalWrite(BINARY_4, HIGH);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 6) {
	digitalWrite(BINARY_1, LOW);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, HIGH);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 7) {
	digitalWrite(BINARY_1, HIGH);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, HIGH);
	digitalWrite(BINARY_8, LOW);
   }
if (twelve_clock == 8) {
	digitalWrite(BINARY_1, LOW);
	digitalWrite(BINARY_2, LOW);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, HIGH);
   }
if (twelve_clock == 9) {
	digitalWrite(BINARY_1, HIGH);
	digitalWrite(BINARY_2, LOW);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, HIGH);
   }
if (twelve_clock == 10) {
	digitalWrite(BINARY_1, LOW);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, HIGH);
   }
if (twelve_clock == 11) {
	digitalWrite(BINARY_1, HIGH);
	digitalWrite(BINARY_2, HIGH);
	digitalWrite(BINARY_4, LOW);
	digitalWrite(BINARY_8, HIGH);
   }


/*
// serial monitor
  Serial.print(now.hour(), DEC);
  Serial.print(":");
  Serial.print(now.minute(), DEC);
  Serial.print(":");
  Serial.print(now.second(), DEC);
  Serial.print(" -> Day number is ");
  Serial.print(now.dayOfTheWeek(), DEC);
//  Serial.print(ora1);
//  Serial.println(":");
//  Serial.print(minut1);
//  Serial.print(":");
//  Serial.print(second1);
  Serial.println("------------------");
*/

/*
if (second0 == 0 && minut0 == 0 && ora0 == 0) {
//	resetFunc(); //reset the chip
	midnight (); //  display at midnight a short 7 second animation with quote
	second0 = 7; // needed, otherwise, after displaying this animation lasting 7 secs, the sketch still thinks it's at 0 seconds, so, this avoids weird shit happening
    }
*/

/*
/////////////////OPTIONAL TO FILL IN A BLANK 8-DIGIT DATE DISPLAY AND 4-DIGIT MONTH DISPLAY after a midnight forced reboot (until 3 seconds later the temperature and date are displayed)
if (second0 == 1 && minut0 == 0 && ora0 == 0) { // display "A new day" after a midnight forced reboot (until 3 seconds later the temperature and date are displayed)
  lc.setChar(1,6,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,4,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,3,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,2,'X',false); // 'X' is left hand side of a 'w' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,1,'V',false); // 'V' is right hand side of a 'w' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)

  lc.setChar(3,3,'d',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(3,2,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(3,1,'Y',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
}
*/
 


ora (ora0, minut0, second0); // original location




//if (second0 == 11 || second0 == 41) t = measure_Temp(); // ORIGINALLY HERE. routine to measure temperature (not display it). Need to limit to specific times when temperature measurements are taken (ie, not overlapping with when temperature or date is displayed), otherwise, without the 'IF' statement, occasional garbage temperatures are displayed when having an additional 3rd Max7219 for a circular second display (probably due to the 0.75 secs it takes the DS18B20 to make a measurement)
//if (second0 == 21 || second0 == 51) setBright(); // ORIGINALLY HERE. autodimming - does this work?
if (second0 == 5 || second0 == 15 || second0 == 25 || second0 == 35 || second0 == 45 || second0 == 55) { // to allow date and temperature and intensity to be displayed just once
	ggg = 0;
	xxx = 0;
	www = 0;
	}


//lc.clearDisplay(1); // Clear display register 
//for(int j=0; j<300; j++){
//for(int j=0; j<30; j++){


//if (second0 == 3 || second0 == 7 || second0 == 11 || second0 == 15 || second0 == 19 || second0 == 23 || second0 == 27 || second0 == 31 || second0 == 35 || second0 == 39 || second0 == 43 || second0 == 47 || second0 == 51 || second0 == 55 || second0 == 59) { // display date. alternates with temperature every 2 seconds  - choose this or line below {in conjunction with appropriate temperature (every 2 seconds swapping) timing 'IF' statement}
//if (second0 == 5 || second0 == 11 || second0 == 17 || second0 == 23 || second0 == 29 || second0 == 35 || second0 == 41 || second0 == 47 || second0 == 53 || second0 == 59) { // display date. alternates with temperature every 3 seconds  - choose this or line above {in conjunction with appropriate temperature (every 3 seconds swapping) timing 'IF' statement}
if (second0 == 0 || second0 == 12 || second0 == 24 || second0 == 36 || second0 == 48) { // display date together with temperature. 


//lc.clearDisplay(1); // Clear display register 
/*
// serial monitor
  Serial.print(now.day(), DEC);
  Serial.print(":");
  Serial.print(now.month(), DEC);
  Serial.print(":");
  Serial.print(now.year(), DEC);
  Serial.print(" -> ");
  Serial.print(ziua0);
  Serial.println(".");
  Serial.print(luna0);
  Serial.print(".");
  Serial.print(anul0);
  Serial.println("------------------");
*/

//data_2a (ziua0, luna0, anul0, dow0); // date (day, month, year, day of the week from 0 to 6 - Sun is 0). Static date format 'Wed 23'
 data_3 (ziua0, luna0, anul0, dow0); // date (day, month, year, day of the week from 0 to 6 - Sun is 0). Static date format 'Wed 23 May' spread over 1x 8-digit display and 1x 4-digit display
 temperatura (t);	// display temperature   

//delay (900);
}


/*
if (second0 == 3 || second0 == 13 || second0 == 23 || second0 == 33 || second0 == 43 || second0 == 53) { // display date. alternates with temperature every 5 seconds  - choose this or line above {in conjunction with appropriate temperature (every 5 seconds swapping) timing 'IF' statement}
 data_scrolling (ziua0, luna0, anul0, dow0); // date (day, month, year, day of the week from 0 to 6 - Sun is 0). Scrolling date format going from 'Wed 23' to '23 May' over a fraction of a second
 }

if (second0 == 4 || second0 == 14 || second0 == 24 || second0 == 34 || second0 == 44 || second0 == 54) { // display date. alternates with temperature every 5 seconds  - choose this or line above {in conjunction with appropriate temperature (every 5 seconds swapping) timing 'IF' statement}
 data_2b (ziua0, luna0, anul0, dow0); // date (day, month, year, day of the week from 0 to 6 - Sun is 0). Static date format '23 May'
 }
*/


    pushlength = pushlengthset;
    pushlength = getpushlength ();
//    delay (10);
    if (pushlength <pushlengthset) {
      ShortPush ();   
    }
	
	




////// START of NEW SUN/MOON

//  getTime();
  
//  	if(digitalRead(BST_pin) == 1) TZ = 0; // pin high means it is NOT daylight saving time
//  	if(digitalRead(BST_pin) == 0) TZ = 1; // pin low means it IS daylight saving time

// we are combining 2 switches here (the Daylight saving time switch, and the seconds ring auto cycling mode switch) into a single pin (Atmega644 pin 38) to (because i've run out of pins) allow the BMP180 pressure sensor to have its readings to be displayed or not (as opposed to displaying the next meteor day information) via a switch
//     if (((analogRead(A2) >= 460) && (analogRead(A2) <= 563)) || ((analogRead(A2) >= 755) && (analogRead(A2) <= 858))) TZ = 1; //'TZ' is the number of hours either ahead of, or behind UTC(GMT) when in Daylight Saving Time. If pin is at 2.50V or 3.94V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band either way) it means Daylight saving time switch has been set to ON, and so it IS daylight saving time, with the approprate value for 'TZ'
//    if (((analogRead(A2) >= 0) && (analogRead(A2) <= 102)) || ((analogRead(A2) >= 613) && (analogRead(A2) <= 715))) TZ = 0; // 'TZ' is the number of hours either ahead of, or behind UTC(GMT) when NOT in Daylight Saving Time. If pin is at 0.0V or 3.24V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band) it means Daylight saving time switch has been set to OFF, and so it IS NOT daylight saving time, with the approprate value for 'TZ'

// we are combining 2 switches here (the Daylight saving time switch, and the seconds ring auto cycling mode switch) into a single pin (Atmega644 pin 38) to (because i've run out of pins) allow the BMP180 pressure sensor to have its readings to be displayed or not (as opposed to displaying the next meteor day information) via a switch
     if (((analogRead(A2) >= 460) && (analogRead(A2) <= 563)) || ((analogRead(A2) >= 755) && (analogRead(A2) <= 858))) TZ = Time_Zone_DST; //'TZ' is the number of hours either ahead of, or behind UTC(GMT) when in Daylight Saving Time. If pin is at 2.50V or 3.94V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band either way) it means Daylight saving time switch has been set to ON, and so it IS daylight saving time, with the approprate value for 'TZ'
     if (((analogRead(A2) >= 0) && (analogRead(A2) <= 102)) || ((analogRead(A2) >= 613) && (analogRead(A2) <= 715))) TZ = Time_Zone_NO_DST; // 'TZ' is the number of hours either ahead of, or behind UTC(GMT) when NOT in Daylight Saving Time. If pin is at 0.0V or 3.24V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band) it means Daylight saving time switch has been set to OFF, and so it IS NOT daylight saving time, with the approprate value for 'TZ'


	vdm = sundata(LATITUDE, LONGITUDE, TZ);
  
  
  if(se != osec) {

   if (second0 == 0 && minut0 == 0 && ora0 == 0) { // at midnight reset the following variables to zero to get around the bug where the moonrise or moonset times were not updating when going into a new day if, in that day there is either no moonrise or moonset

    VHz[0] = 0;
    VHz[1] = 0;
    VHz[2] = 0;
    Dec[0] = 0;
    Dec[1] = 0;
    Dec[2] = 0;
    RAn[0] = 0;
    RAn[1] = 0;
    RAn[2] = 0;
    Sky[0] = 0;
    Sky[1] = 0;
    Sky[2] = 0;
    Rise_time[0] = 0;
    Rise_time[1] = 0;
    Set_time[0] = 0;
    Set_time[1] = 0;

////the following 2 lines were to reset the atmega644 at midnight to get rid of the bug where moonrise/moonset times were not updating when going into a new day if, in that day there is either no moonrise or moonset
//    delay(800); // to prevent a brief flashing on and off of the time before it comes back properly after about 1 second
//    resetFunc(); // reset atmega644 by called on reset function at very top of this sketch.
   }

   
//if (second0 == 11 || second0 == 41) t = measure_Temp(); // ORIGINAL SECONDS. routine to measure temperature (not display it). Need to limit to specific times when temperature measurements are taken (ie, not overlapping with when temperature or date is displayed), otherwise, without the 'IF' statement, occasional garbage temperatures are displayed when having an additional 3rd Max7219 for a circular second display (probably due to the 0.75 secs it takes the DS18B20 to make a measurement)
if (second0 == 9 || second0 == 39) t = measure_Temp(); // ORIGINAL SECONDS. routine to measure temperature (not display it). Need to limit to specific times when temperature measurements are taken (ie, not overlapping with when temperature or date is displayed), otherwise, without the 'IF' statement, occasional garbage temperatures are displayed when having an additional 3rd Max7219 for a circular second display (probably due to the 0.75 secs it takes the DS18B20 to make a measurement)
if (second0 == 21 || second0 == 51) setBright(); // autodimming - does this work?
   

    
    vdm.time(yr, mo, dy, hr, mn, se);           // current year, month, day, hour, minutes and seconds
    vdm.calculations();                              // update calculations for current time
    el_deg = vdm.elevation_deg();                    // store sun's elevation in degrees
    az_deg = vdm.azimuth_deg();                      // store sun's azimuth in degrees
//    sunup  = vdm.sunrise_time();                     // store sunrise time in decimal form - authors original
//    sundn  = vdm.sunset_time();                      // store sunset time in decimal form - authors original
    sunup  = vdm.sunrise_time() - 0.15;                     // store sunrise time in decimal form - ging subtract about 9 mins
    sundn  = vdm.sunset_time() + 0.15;                      // store sunset time in decimal form - ging add about 9 mins
    riseset(LATITUDE, LONGITUDE, dy, mo, yr, TZ);  // moon rise and set information - was 1st
	getMoonPosition();  // was 2nd
	PlanetVisibility();
	moonphase();
	
	
    getSunPosition();
//    getMoonPosition(); IS THIS THE SAME AS THE ONE A FEW LINES ABOVE (AS THIS ONE IS FROM '/2' FOLDER)
    getMoonIllumination();                           // preceeding two are prerequisites	
	
	

if (second0 == 4 || second0 == 16 || second0 == 28 || second0 == 40 || second0 == 52) { // display the word 'sun' and display the sunrise and sunset times
  lc.clearDisplay(1); // Clear display register (date)
  lc.clearDisplay(3); // Clear display register (upper and lower 4-digit displays)
  lc.setChar(1,6,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,5,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,4,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setRow(1,3,B00001000); // horizontal line at bottom correspoding to sun just appearing at sunrise.  d.p, a, b, c, d, e, f, g (the 8 numbers following the letter B in the 'lc.setRow' parameters corresponds to these segments - where 1 is lit and 0 is unlit
  lc.setRow(1,2,B01100011); // degree symbol- simulating sun having fully risen
  lc.setRow(1,1,B00001000); // horizontal line at bottom correspoding to sun just disappearing at sunset.  d.p, a, b, c, d, e, f, g (the 8 numbers following the letter B in the 'lc.setRow' parameters corresponds to these segments - where 1 is lit and 0 is unlit
   
   // sunrise hour
  byte srise_hr1 = byte(sunup/10); // determin cifra zecilor, determine the number of hour tens
  byte srise_hr2 = byte(sunup) - (10*srise_hr1); // determin cifra unitatilor, determine the number of hour units
  lc.setDigit(3,7,srise_hr1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,6,srise_hr2, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  
  //sunrise minute
  byte srise_min1 = (int((sunup - int(sunup))*60.0)) / 10;  // determine the number of minute tens
  byte srise_min2 = (int((sunup - int(sunup))*60.0)) - (10*srise_min1); // determine the number of minute units
  lc.setDigit(3,5,srise_min1, false); // display the minute tens
  lc.setDigit(3,4,srise_min2, false); // display the minute units
  
   // sunset hour
  byte sset_hr1 = byte(sundn/10); // determin cifra zecilor, determine the number of hour tens
  byte sset_hr2 = byte(sundn) - (10*sset_hr1); // determin cifra unitatilor, determine the number of hour units
  lc.setDigit(3,3,sset_hr1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,2,sset_hr2, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  
  //sunset minute
  byte sset_min1 = (int((sundn - int(sundn))*60.0)) / 10;  // determine the number of minute tens
  byte sset_min2 = (int((sundn - int(sundn))*60.0)) - (10*sset_min1); // determine the number of minute units
  lc.setDigit(3,1,sset_min1, false); // display the minute tens
  lc.setDigit(3,0,sset_min2, false); // display the minute units
  
 }
 
 
if (second0 == 8 || second0 == 20 || second0 == 32 || second0 == 44 || second0 == 56) { // display the word 'moon' and display the moonrise and moonset times
  lc.clearDisplay(1); // Clear display register (date)
  lc.clearDisplay(3); // Clear display register (upper and lower 4-digit displays)
  lc.setChar(1,7,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,6,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,5,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,4,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,3,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setRow(1,2,B00001000); // horizontal line at bottom correspoding to moon just appearing at moonrise.  d.p, a, b, c, d, e, f, g (the 8 numbers following the letter B in the 'lc.setRow' parameters corresponds to these segments - where 1 is lit and 0 is unlit
  lc.setRow(1,1,B01100011); // degree symbol- simulating moon having fully risen
  lc.setRow(1,0,B00001000); // horizontal line at bottom correspoding to moon just disappearing at moonset.  d.p, a, b, c, d, e, f, g (the 8 numbers following the letter B in the 'lc.setRow' parameters corresponds to these segments - where 1 is lit and 0 is unlit
 
  
  // moonrise hour
  byte mrise_hr1 = byte(Rise_time[0] / 10); // determin cifra zecilor, determine the number of hour tens - does this work?
  byte mrise_hr2 = byte(Rise_time[0]) - (10*mrise_hr1);  // determin cifra unitatilor, determine the number of hour units - does this work?
  if(Rise_time[0]==0 && Rise_time[1] ==0) { // if there's no moonrise today then display 'none'
   lc.setChar(3,7,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,6,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,5,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,4,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
   else { // if there is a moonrise today show the time
  lc.setDigit(3,7,mrise_hr1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,6,mrise_hr2, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
   
  //moonrise minute    
  byte mrise_min1 = byte(Rise_time[1] / 10); // determin cifra zecilor, determine the number of hour tens - does this work?
  byte mrise_min2 = byte(Rise_time[1]) - (10*mrise_min1);  // determin cifra unitatilor, determine the number of hour units - does this work?
  lc.setDigit(3,5,mrise_min1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,4,mrise_min2, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
}

  // moonset hour
  byte mset_hr1 = byte(Set_time[0] / 10); // determin cifra zecilor, determine the number of hour tens - does this work?
  byte mset_hr2 = byte(Set_time[0]) - (10*mset_hr1);  // determin cifra unitatilor, determine the number of hour units - does this work?
  if(Set_time[0]==0 && Set_time[1] ==0) { // if there's no moonset today then display 'none'
   lc.setChar(3,3,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,2,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,1,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,0,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
   else { // if there is a moonset today show the time
  lc.setDigit(3,3,mset_hr1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,2,mset_hr2, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
   
  //moonset minute    
  byte mset_min1 = byte(Set_time[1] / 10); // determin cifra zecilor, determine the number of hour tens - does this work?
  byte mset_min2 = byte(Set_time[1]) - (10*mset_min1);  // determin cifra unitatilor, determine the number of hour units - does this work?
  lc.setDigit(3,1,mset_min1, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(3,0,mset_min2, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  }
   
 } 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  if(digitalRead(meteor_option_pin) == 1) { // if meteor_option_pin is high show meteor information, otherwise show atmospheric pressure information (if bmp180 fitted)
	  

//if (second0 == 0 || second0 == 30) { // display the words 'Cosmic run thru' on top 8-digit and just below 2x 4-digit displays
  if ((minut0 % 2 == 0 && (second0 == 0 || second0 == 40)) || (minut0 % 2 == 1 && second0 == 20)) { // if the current minute is an even number and the seconds are 0 or 40, or, if the current minute is odd and the seconds are 20, then display the word 'meteors' and show the date of the next large meteor shower
   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and azimuth)
   meteors(); // display word 'meteors'
/*   // display 'cosmic run thru'
   lc.setChar(4,7,'C',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'i',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'C',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)

   lc.setChar(5,7,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,6,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,5,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)

   lc.setChar(5,3,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'h',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,0,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
*/
  if ((luna0 == 12 && ziua0 >= 17) || (luna0 == 1 && ziua0 <= 5)) // if it's between Dec 17 and Jan 5 inclusive show 'meteors 5 Jan'
  {
   lc.setChar(5,4,'5',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'J',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 1 && ziua0 >= 6) || luna0 == 2 || luna0 == 3 || (luna0 == 4 && ziua0 <= 24)) // if it's between Jan 6 and Apr 24 inclusive show 'meteors 24 Apr'
  {
   lc.setChar(5,5,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'4',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'P',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 4 && ziua0 >= 25) || (luna0 == 5 && ziua0 <= 7)) // if it's between Apr 25 and May 7 inclusive show 'meteors 7 May'
  {
   lc.setChar(5,4,'7',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,0,'Y',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 5 && ziua0 >= 8) || luna0 == 6 || (luna0 == 7 && ziua0 <= 31)) // if it's between May 8 and Jul 31 inclusive show 'meteors 31 Jul'
  {
   lc.setChar(5,5,'3',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'1',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'J',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'U',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'L',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 8 && ziua0 >= 1) && (luna0 == 8 && ziua0 <= 14)) // if it's between Aug 1 and Aug 14 inclusive show 'meteors 14 Aug'
  {
   lc.setChar(5,5,'1',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'4',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'U',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'G',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 8 && ziua0 >= 15) || luna0 == 9 || (luna0 == 10 && ziua0 <= 10)) // if it's between Aug 15 and Oct 10 inclusive show 'meteors 10 Oct'
  {
   lc.setChar(5,5,'1',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'0',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'O',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'c',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 10 && ziua0 >= 11) && (luna0 == 10 && ziua0 <= 23)) // if it's between Oct 11 and Oct 23 inclusive show 'meteors 23 Oct'
  {
   lc.setChar(5,5,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'3',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'O',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'c',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 10 && ziua0 >= 24) || (luna0 == 11 && ziua0 <= 19)) // if it's between Oct 24 and Nov 19 inclusive show 'meteors 19 Nov'
  {
   lc.setChar(5,5,'1',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'9',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'O',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'U',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  if ((luna0 == 11 && ziua0 >= 20) || (luna0 == 12 && ziua0 <= 16)) // if it's between Nov 20 and Dec 16 inclusive show 'meteors 16 Dec'
  {
   lc.setChar(5,5,'1',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,4,'6',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,3,'d',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,2,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(5,1,'C',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }

 LED_azim = 400; // for 13 LED azimuth display at top of frame - an imposible number to stop LEDs lighting when showing meteor information
 LED_elev = 400.0; // for 12 LED elevation display at top of frame - an imposible number to stop LEDs lighting when showing meteor information

 }
}
 
///////////////////////////////////////////////////////////////////////////////////////////////////////////// 

  if((digitalRead(meteor_option_pin) == 0) && bmp180En == true) { // if meteor_option_pin is high show meteor information, otherwise show atmospheric pressure information (if bmp180 fitted)
	
  if ((minut0 % 2 == 0 && (second0 == 0 || second0 == 40)) || (minut0 % 2 == 1 && second0 == 20)) { // if the current minute is an even number and the seconds are 0 or 40, or, if the current minute is odd and the seconds are 20, then display current pressure and pressure difference over the last 2 hours
   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and azimuth)
   seaLevelPressure_round = seaLevelPressure + 0.5; // round up/down pressure value
   
   if((int)seaLevelPressure_round != 0) { //  if it's within the first 10 minutes of power-up, a pressure reading won't have been taken yet, so it makes little sense in displaying a value of zero for the 'seaLevelPressure_round' number, so instead i'm displaying nothing
     
   byte pressure1 = (int)seaLevelPressure_round / 1000; // thousands
   byte pressure2 = ((int)seaLevelPressure_round / 100) % 10; // hundreds
   byte pressure3 = ((int)seaLevelPressure_round / 10) % 10; // tens
   byte pressure4 = (int)seaLevelPressure_round % 10; // units
   if (pressure1 == 1) lc.setDigit(4,7,pressure1,false); // display the thousands digit only if it's a '1', if it's a zero nothing is displayed (ie, leading zero is not displayed)
   lc.setDigit(4,6,pressure2,false); // display the hundreds digit
   lc.setDigit(4,5,pressure3,false); // display the tens digit
   lc.setDigit(4,4,pressure4,false); // display the units digit
   }
   
   lc.setChar(4,2,'h',false); 
   lc.setChar(4,1,'P',false); 
   lc.setChar(4,0,'A',false); 
   lc.setChar(5,7,'d',false); // delta
   lc.setChar(5,6,'2',false); // 2
   lc.setChar(5,5,'h',false); // hour
   lc.setChar(5,4,'r',false); // hour

   if(pressure_counter < 13) { // if less than 2 hours have elapsed since power-up then display '----'
    lc.setChar(5,3,'-',false); //
    lc.setChar(5,2,'-',false); // 
    lc.setChar(5,1,'-',false); // 
    lc.setChar(5,0,'-',false); // 
   }

   if(pressure_counter > 12) { // if 2 hours or more have elapsed since power-up then display the pressure change over the last 2 hours
//   	 difference_2hour = -6.4; // TESTING ONLY - comment out in final code
    if(difference_2hour < 0.0)  lc.setChar(5,3,'-',false); // display minus sign if pressure change is negative
	 difference_2hour_temp = difference_2hour * 10; // to remove decimal point
	 difference_2hour_temp = fabs(difference_2hour_temp); // to find absolute value - fabs is absolute value of a float
	 byte two_hour_1 = (int)difference_2hour_temp / 100; // hundreds
	 byte two_hour_2 = ((int)difference_2hour_temp / 10) % 10; // tens
	 byte two_hour_3 = (int)difference_2hour_temp % 10; // units
	 if(two_hour_1 != 0)  lc.setDigit(5,2,two_hour_1,false); // display the hundreds digit if it's not zero (ie, don't display leading zero for the hundreds digit)
     lc.setDigit(5,1,two_hour_2,true); // display the tens digit with decimal point
     lc.setDigit(5,0,two_hour_3,false); // display the units digit
   }
   
 LED_azim = 400; // for 13 LED azimuth display at top of frame - an imposible number to stop LEDs lighting when showing pressure information
 LED_elev = 400.0; // for 12 LED elevation display at top of frame - an imposible number to stop LEDs lighting when showing pressure information   
   
  }
   
   
   
  if ((minut0 % 2 == 0 && (second0 == 2 || second0 == 42)) || (minut0 % 2 == 1 && second0 == 22)) { // if the current minute is an even number and the seconds are 2 or 42, or, if the current minute is odd and the seconds are 22, then display pressure difference over the last 4 hours. No need to display actual pressure as it's still on the display from 2 seconds ago
//   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and azimuth)
//   seaLevelPressure_round = seaLevelPressure + 0.5; // round up/down pressure value
//   byte pressure1 = (int)seaLevelPressure_round / 1000; // thousands
//   byte pressure2 = ((int)seaLevelPressure_round / 100) % 10; // hundreds
//   byte pressure3 = ((int)seaLevelPressure_round / 10) % 10; // tens
//   byte pressure4 = (int)seaLevelPressure_round % 10; // units
//   if (pressure1 == 1) lc.setDigit(4,7,pressure1,false); // display the thousands digit only if it's a '1', if it's a zero nothing is displayed (ie, leading zero is not displayed)
//   lc.setDigit(4,6,pressure2,false); // display the hundreds digit
//   lc.setDigit(4,5,pressure3,false); // display the tens digit
//   lc.setDigit(4,4,pressure4,false); // display the units digit
//   lc.setChar(4,2,'h',false); 
//   lc.setChar(4,1,'P',false); 
//   lc.setChar(4,0,'A',false); 
   lc.setChar(5,7,'d',false); // delta
   lc.setChar(5,6,'4',false); // 4
   lc.setChar(5,5,'h',false); // hour
   lc.setChar(5,4,'r',false); // hour

   if(pressure_counter < 25) { // if less than 4 hours have elapsed since power-up then display '----'
    lc.setChar(5,3,'-',false); //
    lc.setChar(5,2,'-',false); // 
    lc.setChar(5,1,'-',false); // 
    lc.setChar(5,0,'-',false); // 
   }

   if(pressure_counter > 24) { // if 4 hours or more have elapsed since power-up then display the pressure change over the last 4 hours
//   	 difference_4hour = 23.6; // TESTING ONLY - comment out in final code
    if(difference_4hour < 0.0)  lc.setChar(5,3,'-',false); // display minus sign if pressure change is negative
	 difference_4hour_temp = difference_4hour * 10; // to remove decimal point
	 difference_4hour_temp = fabs(difference_4hour_temp); // to find absolute value - fabs is absolute value of a float
	 byte four_hour_1 = (int)difference_4hour_temp / 100; // hundreds
	 byte four_hour_2 = ((int)difference_4hour_temp / 10) % 10; // tens
	 byte four_hour_3 = (int)difference_4hour_temp % 10; // units
	 if(four_hour_1 != 0)  lc.setDigit(5,2,four_hour_1,false); // display the hundreds digit if it's not zero (ie, don't display leading zero for the hundreds digit)
     lc.setDigit(5,1,four_hour_2,true); // display the tens digit with decimal point
     lc.setDigit(5,0,four_hour_3,false); // display the units digit
    }
	
 LED_azim = 400; // for 13 LED azimuth display at top of frame - an imposible number to stop LEDs lighting when showing pressure information
 LED_elev = 400.0; // for 12 LED elevation display at top of frame - an imposible number to stop LEDs lighting when showing pressure information
	
   }   
    
  }


//////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
//if (second0 == 3 || second0 == 33) { // shows the suns name and its elevation and azimuth
  if ((minut0 % 2 == 0 && (second0 == 4 || second0 == 44)) || (minut0 % 2 == 1 && second0 == 24)) { // if the current minute is an even number and the seconds are 4 or 44, or, if the current minute is odd and the seconds are 24, then display the suns name and its elevation and azimuth
   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and aximuth)
   lc.setChar(4,7,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'h',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'S',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'u',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
 
 // sun's elevation
   lc.setRow(5,4,B01100011); // degree symbol on far right of left 4 digit display
//   int sun_elev = round(el_deg);// old version although seems to be ok. rounded up/down sun elevation
   int sun_elev = round(sal*irad);// new version. rounded up/down sun elevation
   int sun_elev2 = abs(sun_elev); // absolute value of rounded up/down sun elevation
   byte elev1 = sun_elev2 / 10; // tens
   byte elev2 = sun_elev2 % 10; // units
   if (sun_elev >= 10) { // if sun elevation is greater or equal to 10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,6,elev1,false); // display the tens digit	   
    lc.setDigit(5,5,elev2,false); // display the units digit
     }
   if (sun_elev >= 0 && sun_elev < 10) { // if sun elevation is between 0 degrees and 9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,5,elev2,false); // display the units digit	   
     }
   if (sun_elev < 0 && sun_elev > -10) { // if sun elevation is between -1 degrees and -9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,6,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,5,elev2,false); // display the units digit	   
     }
   if (sun_elev <= -10) { // if sun elevation is less than or equal to -10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,7,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,6,elev1,false); // display the tens digit	   
    lc.setDigit(5,5,elev2,false); // display the units digit
     }
	 
	 
	 
/*	 
 // sun's azimuth - note, there's a bug in the calculation when it gets close to 360 degree, with the azimuth starting to decrease instead of increasing as time goes on - this bug disappears before 00:00 (ie before midnight) and after 01:00, hence the need for the line below which between 00:00 and 01:00, instead of showing the azimuth in degrees, just shows the letter 'N' for north - this is ok as throughout the year the sun is within 25 degrees of due North between 00:00 and 01:00. (the sun's calculated elevation is unaffected by this bug)

   if (ora0 == 0) {
	   lc.setChar(5,3,'N',false); // display the letter N for north between 00:00 and 00:59. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   lc.setChar(5,2,'o',false); // display the letter N for north between 00:00 and 00:59. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   lc.setChar(5,1,'r',true); // display the letter N for north between 00:00 and 00:59. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
       }
   if (ora0 != 0) { // shows sun's azimuth in degrees outside of the hours 00:00 to 00:59
   lc.setRow(5,0,B01100011); // degree symbol on far right of right 4 digit display 
   int sun_azim = round(az_deg);// rounded up/down sun azimuth
   if (sun_azim == 360) sun_azim = 0; // if azimuth is 360 then make it 0, as 360 and 0 degrees are the same thing, ie due North. 
   byte azim1 = sun_azim / 100; // hundreds
   byte azim2 = (sun_azim / 10) % 10; // tens
   byte azim3 = sun_azim % 10; // units
   if (sun_azim <= 9) {  //if sun azimuth is less than or equal to 9 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,1,azim3,false); // display the units digit
    }
   if (sun_azim >= 10 && sun_azim <= 99) { // if sun azimuth is between 10 and 99 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,2,azim2,false); // display the tens digit
    lc.setDigit(5,1,azim3,false); // display the units digit
    }	
   if (sun_azim	> 99 && sun_azim <= 359) { // if sun azimuth is between 100 and 359 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,3,azim1,false); // display the hundreds digit
    lc.setDigit(5,2,azim2,false); // display the tens digit
    lc.setDigit(5,1,azim3,false); // display the units digit
     }
	} 
*/


 // sun's azimuth - new that doesn't go mad around 0 degrees although the value only updates every 2 minutes or so, maybe (although I'm only guessing) due to the fact that a double variable used in the calculation only has the same precision as a float on avr chips

   lc.setRow(5,0,B01100011); // degree symbol on far right of right 4 digit display 
   int sun_azim = round(sad);// rounded up/down sun azimuth
   if (sun_azim == 360) sun_azim = 0; // if azimuth is 360 then make it 0, as 360 and 0 degrees are the same thing, ie due North. 
   byte azim1 = sun_azim / 100; // hundreds
   byte azim2 = (sun_azim / 10) % 10; // tens
   byte azim3 = sun_azim % 10; // units
   if (sun_azim <= 9) {  //if sun azimuth is less than or equal to 9 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,1,azim3,false); // display the units digit
    }
   if (sun_azim >= 10 && sun_azim <= 99) { // if sun azimuth is between 10 and 99 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,2,azim2,false); // display the tens digit
    lc.setDigit(5,1,azim3,false); // display the units digit
    }	
   if (sun_azim	> 99 && sun_azim <= 359) { // if sun azimuth is between 100 and 359 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,3,azim1,false); // display the hundreds digit
    lc.setDigit(5,2,azim2,false); // display the tens digit
    lc.setDigit(5,1,azim3,false); // display the units digit
     }
	 
  LED_azim = sun_azim; // for 13 LED azimuth display at top of frame 
  LED_elev = sal*irad; // for 12 LED elevation display at top of frame

 }
 
////////////////////////////////////////////////////////////////////////////////////////////////////////// 

/* // Original moon working beginning
if (second0 == 6 || second0 == 36) { // shows the moons name and its elevation and azimuth
   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and aximuth)
   lc.setChar(4,6,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
 
 // moon's elevation
   lc.setRow(5,4,B01100011); // degree symbol on far right of left 4 digit display
   int moon_elev = round(mal*irad);// rounded up/down moon elevation
   int moon_elev2 = abs(moon_elev); // absolute value of rounded up/down moon elevation
   byte m_elev1 = moon_elev2 / 10; // tens
   byte m_elev2 = moon_elev2 % 10; // units
   if (moon_elev >= 10) { // if moon elevation is greater or equal to 10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,6,m_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,m_elev2,false); // display the units digit
     }
   if (moon_elev >= 0 && moon_elev < 10) { // if moon elevation is between 0 degrees and 9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,5,m_elev2,false); // display the units digit	   
     }
   if (moon_elev < 0 && moon_elev > -10) { // if moon elevation is between -1 degrees and -9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,6,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,5,m_elev2,false); // display the units digit	   
     }
   if (moon_elev <= -10) { // if moon elevation is less than or equal to -10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,7,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,6,m_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,m_elev2,false); // display the units digit
     }   
	 
 // moon's azimuth	
   lc.setRow(5,0,B01100011); // degree symbol on far right of right 4 digit display 
   int moon_azim = round(mad);// rounded up/down moon azimuth
   if (moon_azim == 360) moon_azim = 0; // if azimuth is 360 then make it 0, as 360 and 0 degrees are the same thing, ie due North. 
   byte m_azim1 = moon_azim / 100; // hundreds
   byte m_azim2 = (moon_azim / 10) % 10; // tens
   byte m_azim3 = moon_azim % 10; // units
   if (moon_azim <= 9) {  //if moon azimuth is less than or equal to 9 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,1,m_azim3,false); // display the units digit
    }
   if (moon_azim >= 10 && moon_azim <= 99) { // if moon azimuth is between 10 and 99 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,2,m_azim2,false); // display the tens digit
    lc.setDigit(5,1,m_azim3,false); // display the units digit
    }	
   if (moon_azim > 99 && moon_azim <= 359) { // if moon azimuth is between 100 and 359 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,3,m_azim1,false); // display the hundreds digit
    lc.setDigit(5,2,m_azim2,false); // display the tens digit
    lc.setDigit(5,1,m_azim3,false); // display the units digit
    }   
 }
*/ // ORIGINAL Moon working end 
 
//if (second0 == 6 || second0 == 36) { // shows the moons name and its elevation and azimuth
  if ((minut0 % 2 == 0 && (second0 == 8 || second0 == 48)) || (minut0 % 2 == 1 && second0 == 28)) { // if the current minute is an even number and the seconds are 8 or 48, or, if the current minute is odd and the seconds are 28, then display the Moon's name and its elevation and azimuth
   elev_azim_disp(mal*irad, mad); //  display Moon's elevation and azimuth

   lc.setChar(4,6,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
  LED_azim = mad; // for 13 LED azimuth display at top of frame    
  LED_elev = mal*irad; // for 12 LED elevation display at top of frame
   
 }
 
///////////////////////////////////////////////////////////////////////////////////////// 
 
// if (second0 == 9 || second0 == 39) { // shows Mercury's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && (second0 == 12 || second0 == 52)) || (minut0 % 2 == 1 && second0 == 32)) { // if the current minute is an even number and the seconds are 12 or 52, or, if the current minute is odd and the seconds are 32, then display the Mercury's name and its elevation and azimuth
   elev_azim_disp(Merc_elev, Merc_azim); //  display mercury's elevation and azimuth

   lc.setChar(4,7,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'c',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,0,'y',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
   LED_azim = Merc_azim; // for 13 LED azimuth display at top of frame
   LED_elev = Merc_elev; // for 12 LED elevation display at top of frame
  }
   
   if (mag_show == true) { // if showing planet magnitude
	  if ((minut0 % 2 == 0 && (second0 == 14 || second0 == 54)) || (minut0 % 2 == 1 && second0 == 34)) { // if the current minute is an even number and the seconds are 14 or 54, or, if the current minute is odd and the seconds are 34, then display the abbreviated form of Mercury's name together with its magnitude, and also its elevation and azimuth
	   lc.setChar(4,4,'r',true); // to put a full stop after the letter 'r' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Merc_mag); // display Mercury's magnitude   
    }
   }




/*
 // Mercury's elevation
   lc.setRow(5,4,B01100011); // degree symbol on far right of left 4 digit display
   int Merc_elev_a = round(Merc_elev);// rounded up/down mercury elevation
   int Merc_elev_a2 = abs(Merc_elev_a); // absolute value of rounded up/down mercury elevation
   byte mer_elev1 = Merc_elev_a2 / 10; // tens
   byte mer_elev2 = Merc_elev_a2 % 10; // units
   if (Merc_elev_a >= 10) { // if mercury's elevation is greater or equal to 10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,6,mer_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,mer_elev2,false); // display the units digit
     }
   if (Merc_elev_a >= 0 && Merc_elev_a < 10) { // if mercury's elevation is between 0 degrees and 9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,5,mer_elev2,false); // display the units digit	   
     }
   if (Merc_elev_a < 0 && Merc_elev_a > -10) { // if mercury's elevation is between -1 degrees and -9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,6,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,5,mer_elev2,false); // display the units digit	   
     }
   if (Merc_elev_a <= -10) { // if mercury's elevation is less than or equal to -10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,7,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,6,mer_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,mer_elev2,false); // display the units digit
     }   
	 
 // Mercury's azimuth	
   lc.setRow(5,0,B01100011); // degree symbol on far right of right 4 digit display 
   int Merc_azim_a = round(Merc_azim);// rounded up/down mercury's azimuth
   if (Merc_azim_a == 360) Merc_azim_a = 0; // if azimuth is 360 then make it 0, as 360 and 0 degrees are the same thing, ie due North. 
   byte mer_azim1 = Merc_azim_a / 100; // hundreds
   byte mer_azim2 = (Merc_azim_a / 10) % 10; // tens
   byte mer_azim3 = Merc_azim_a % 10; // units
   if (Merc_azim_a <= 9) {  //if mercury's azimuth is less than or equal to 9 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,1,mer_azim3,false); // display the units digit
    }
   if (Merc_azim_a >= 10 && Merc_azim_a <= 99) { // if mercury's azimuth is between 10 and 99 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,2,mer_azim2,false); // display the tens digit
    lc.setDigit(5,1,mer_azim3,false); // display the units digit
    }	
   if (Merc_azim_a > 99 && Merc_azim_a <= 359) { // if mercury's azimuth is between 100 and 359 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,3,mer_azim1,false); // display the hundreds digit
    lc.setDigit(5,2,mer_azim2,false); // display the tens digit
    lc.setDigit(5,1,mer_azim3,false); // display the units digit
    }
*/
   
 
////////////////////////////////////////////////////////////////////////////////////////////
 
//if (second0 == 12 || second0 == 42) { // shows Venus's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && (second0 == 16 || second0 == 56)) || (minut0 % 2 == 1 && second0 == 36)) { // if the current minute is an even number and the seconds are 16 or 56, or, if the current minute is odd and the seconds are 36, then display Venus's name and its elevation and azimuth
   elev_azim_disp(Ven_elev, Ven_azim); //  display Venus's elevation and azimuth
   
   lc.setChar(4,7,'U',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'s',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
 LED_azim = Ven_azim; // for 13 LED azimuth display at top of frame
 LED_elev = Ven_elev; // for 12 LED elevation display at top of frame
   
 }
 
   if (mag_show == true) { // if showing planet magnitude
	  if ((minut0 % 2 == 0 && (second0 == 18 || second0 == 58)) || (minut0 % 2 == 1 && second0 == 38)) { // if the current minute is an even number and the seconds are 18 or 58, or, if the current minute is odd and the seconds are 38, then display the abbreviated form of Venus's name together with its magnitude, and also its elevation and azimuth
	   lc.setChar(4,4,'u',true); // to put a full stop after the letter 'u' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Ven_mag); // display Venus's magnitude   
    }
   }
 
////////////////////////////////////////////////////////////////////////////////////////// 
 
//if (second0 == 15 || second0 == 45) { // shows Mars's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && second0 == 20) || (minut0 % 2 == 1 && (second0 == 0 || second0 == 40))) { // if the current minute is an even number and the seconds are 20, or, if the current minute is odd and the seconds are 00 or 40, then display the Mars's name and its elevation and azimuth
   elev_azim_disp(Mars_elev, Mars_azim); //  display Mars's elevation and azimuth
   
   lc.setChar(4,7,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
  LED_azim = Mars_azim; // for 13 LED azimuth display at top of frame  
  LED_elev = Mars_elev; // for 12 LED elevation display at top of frame
   
 }
 
	if (mag_show == true) { // if showing planet magnitude
	  if ((minut0 % 2 == 0 && second0 == 22) || (minut0 % 2 == 1 && (second0 == 2 || second0 == 42))) { // if the current minute is an even number and the seconds are 22, or, if the current minute is odd and the seconds are 02 or 42, then display the Mars's name and its elevation and azimuth
	   lc.setChar(4,4,'r',true); // to put a full stop after the letter 'r' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Mars_mag); // display Mars's magnitude   
    }
   }

///////////////////////////////////////////////////////////////////////////////////

//if (second0 == 18 || second0 == 48) { // shows Jupiter's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && second0 == 24) || (minut0 % 2 == 1 && (second0 == 4 || second0 == 44))) { // if the current minute is an even number and the seconds are 24, or, if the current minute is odd and the seconds are 4 or 44, then display the Jupiter's name and its elevation and azimuth
   elev_azim_disp(Jup_elev, Jup_azim); //  display Jupiters's elevation and azimuth
   
   lc.setChar(4,7,'J',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'P',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'i',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
 LED_azim = Jup_azim; // for 13 LED azimuth display at top of frame   
 LED_elev = Jup_elev; // for 12 LED elevation display at top of frame 
   
 }
 
	if (mag_show == true) { // if showing planet magnitude
	 if ((minut0 % 2 == 0 && second0 == 26) || (minut0 % 2 == 1 && (second0 == 6 || second0 == 46))) { // if the current minute is an even number and the seconds are 26, or, if the current minute is odd and the seconds are 6 or 46, then display the Jupiter's name and its elevation and azimuth
	   lc.setChar(4,4,'i',true); // to put a full stop after the letter 'i' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Jup_mag); // display Jupiter's magnitude   
    }
   } 
 
///////////////////////////////////////////////////////////////////////////////////////// 
 
//if (second0 == 21 || second0 == 51) { // shows Saturn's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && second0 == 28) || (minut0 % 2 == 1 && (second0 == 8 || second0 == 48))) { // if the current minute is an even number and the seconds are 28, or, if the current minute is odd and the seconds are 8 or 48, then display the Saturn's name and its elevation and azimuth
   elev_azim_disp(Sat_elev, Sat_azim); //  display Saturns's elevation and azimuth
   
   lc.setChar(4,7,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
  LED_azim = Sat_azim; // for 13 LED azimuth display at top of frame 
  LED_elev = Sat_elev; // for 12 LED elevation display at top of frame
   
 }
 
	if (mag_show == true) { // if showing planet magnitude
	 if ((minut0 % 2 == 0 && second0 == 30) || (minut0 % 2 == 1 && (second0 == 10 || second0 == 50))) { // if the current minute is an even number and the seconds are 30, or, if the current minute is odd and the seconds are 10 or 50, then display the Saturn's name and its elevation and azimuth
	   lc.setChar(4,4,'u',true); // to put a full stop after the letter 'u' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Sat_mag); // display Saturns's magnitude   
    }
   }
 
//////////////////////////////////////////////////////////////////////////////////////////
 
//if (second0 == 24 || second0 == 54) { // shows Uranus's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && second0 == 32) || (minut0 % 2 == 1 && (second0 == 12 || second0 == 52))) { // if the current minute is an even number and the seconds are 32, or, if the current minute is odd and the seconds are 12 or 52, then display the Uranus's name and its elevation and azimuth
   elev_azim_disp(Uran_elev, Uran_azim); //  display Uranus's elevation and azimuth
   
   lc.setChar(4,7,'U',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
 LED_azim = Uran_azim; // for 13 LED azimuth display at top of frame 
 LED_elev = Uran_elev; // for 12 LED elevation display at top of frame
 
 }
 
	if (mag_show == true) { // if showing planet magnitude
	 if ((minut0 % 2 == 0 && second0 == 34) || (minut0 % 2 == 1 && (second0 == 14 || second0 == 54))) { // if the current minute is an even number and the seconds are 34, or, if the current minute is odd and the seconds are 14 or 54, then display the Uranus's name and its elevation and azimuth
	   lc.setChar(4,4,'n',true); // to put a full stop after the letter 'n' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Uran_mag); // display Saturns's magnitude   
    }
   }
 
///////////////////////////////////////////////////////////////////////////////////////// 
 
//if (second0 == 27 || second0 == 57) { // shows Neptune's name and its elevation and azimuth
  if ((minut0 % 2 == 0 && second0 == 36) || (minut0 % 2 == 1 && (second0 == 16 || second0 == 56))) { // if the current minute is an even number and the seconds are 36, or, if the current minute is odd and the seconds are 16 or 56, then display the Neptune's name and its elevation and azimuth
   elev_azim_disp(Nep_elev, Nep_azim); //  display Neptune's elevation and azimuth
   
   lc.setChar(4,7,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'P',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'n',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   
 LED_azim = Nep_azim; // for 13 LED azimuth display at top of frame   
 LED_elev = Nep_elev; // for 12 LED elevation display at top of frame  
   
 }
 
	if (mag_show == true) { // if showing planet magnitude
	 if ((minut0 % 2 == 0 && second0 == 38) || (minut0 % 2 == 1 && (second0 == 18 || second0 == 58))) { // if the current minute is an even number and the seconds are 38, or, if the current minute is odd and the seconds are 18 or 58, then display the Neptune's name and its elevation and azimuth
	   lc.setChar(4,4,'t',true); // to put a full stop after the letter 't' to signify it's an abreviation. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	   mag_display(Nep_mag); // display Neptune's magnitude   
    }
   }
 
//////////////////////////////////////////////////////////////////////////////////////////// 
 
 if (mal*irad >= 2) digitalWrite(LED1, LOW);  // If moon's elevation is greater to or equal to +2 degree then make moon visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED1, HIGH); // If moon elevation is NOT greater to or equal to +2 degree then make moon visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Sat_elev >= 2 && sal*irad < -8) digitalWrite(LED2, LOW);  // If saturn's (of magnitude +0.5) elevation is greater to or equal to +2 degree, and sun's elevation less than -8 degrees then make saturn visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED2, HIGH); // If saturn's elevation is NOT greater to or equal to +2 degree then make saturn visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Nep_elev >= 2 && sal*irad < -13) digitalWrite(LED3, LOW);  // If neptune's (of magnitude +8) elevation is greater to or equal to +2 degree, and sun's elevation less than -13 degrees then make neptune visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED3, HIGH); // If neptune's elevation is NOT greater to or equal to +2 degree then make neptune visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Merc_elev >= 2 && sal*irad < -5) digitalWrite(LED4, LOW);  // If mercury's (of varying magnitude +5 to -3) elevation is greater to or equal to +2 degree, and sun's elevation less than -5 degrees then make mercury visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED4, HIGH); // If mercury's elevation is NOT greater to or equal to +2 degree then make mercury visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Mars_elev >= 2 && sal*irad < -8) digitalWrite(LED5, LOW);  // If mars's (of varying magnitude -2 to +2) elevation is greater to or equal to +2 degree, and sun's elevation less than -8 degrees then make mars visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED5, HIGH); // If mars's elevation is NOT greater to or equal to +2 degree then make mars visible LED's cathode 5V hence NOT lighting this LED
  }
 
 
 if (Ven_elev >= 2 && sal*irad < -4) digitalWrite(LED6, LOW);  // If venus's elevation is greater to or equal to +2 degree, and sun's elevation less than -4 degrees then make venus visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED6, HIGH); // If venus's elevation is NOT greater to or equal to +2 degree then make venus visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Uran_elev >= 2 && sal*irad < -12) digitalWrite(LED7, LOW);  // If uranus's (of magnitude +5.6) elevation is greater to or equal to +2 degree, and sun's elevation less than -12 degrees then make uranus visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED7, HIGH); // If uranus's elevation is NOT greater to or equal to +2 degree then make uranus visible LED's cathode 5V hence NOT lighting this LED
  }
  
  
 if (Jup_elev >= 2 && sal*irad < -7) digitalWrite(LED8, LOW);  // If jupiter's (of magnitude -2.2) elevation is greater to or equal to +2 degree, and sun's elevation less than -7 degrees then make jupiter visible LED's cathode 0V hence lighting this LED
  else
  {
   digitalWrite(LED8, HIGH); // If jupiter's elevation is NOT greater to or equal to +2 degree then make jupiter visible LED's cathode 5V hence NOT lighting this LED
  }
 
 
/*
// moon phase day (0 to 29) 0 is new moon, 15 is full moon - less accurate
   byte m_phase1 = moon_phase / 10; // tens
   byte m_phase2 = moon_phase % 10; // units
   if (moon_phase <= 9) {  // if moon phase day is less than or equal to 9  
    lc.setDigit(6,0,m_phase2,false); // display the units digit
    }
   if (moon_phase >= 10) { // if moon phase days is between 10 and 29 inclusive
    lc.setDigit(6,1,m_phase1,false); // display the tens digit
    lc.setDigit(6,0,m_phase2,false); // display the units digit
    }
*/
	
/*	
// moon illumination percentage - less accurate, don't use
   byte m_illum1 = moon_ill / 10; // tens
   byte m_illum2 = moon_ill % 10; // units
   if (moon_ill <= 9) {  // if moon illumination percentage is less than or equal to 9  
    lc.setChar(6,3,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(6,2,m_illum2,false); // display the units digit
    }
   if (moon_ill >= 10) { // if moon illumination percentage is between 10 and 99
    lc.setDigit(6,3,m_illum1,false); // display the tens digit
    lc.setDigit(6,2,m_illum2,false); // display the units digit
    }
*/


//if (second0 % 3 == 0) { // TO UPDATE THE DISPLAY IN SYNC WITH THE PLANETS SCROLLING AZIMUTH/ELEVATION DATA, REALLY ONLY NOTICEABLE AFTER A MIDNIGHT FORCED RESET as the moon illumination and trend would of appeared 2 seconds before the planetary azimuth/elevation otherwise
 if (second0 % 4 == 0) { // TO UPDATE THE DISPLAY IN SYNC WITH THE PLANETS SCROLLING AZIMUTH/ELEVATION DATA, REALLY ONLY NOTICEABLE AFTER A MIDNIGHT FORCED RESET as the moon illumination and trend would of appeared 2 seconds before the planetary azimuth/elevation otherwise

	
// moon illumination percentage - very accurate, use
   byte mfract_rnd = byte(mfract*100.0 + 0.5); //moon illumination percentage rounded up/down
   mfract_rnd = constrain(mfract_rnd, 0, 100);  // limit percentage to between 0% and 100 %. just incase there are calculation issues that takes it slightly outside this range (but quick testing shows there isn't issues, but i'm keeping this line anyway)
   byte m_illum1 = mfract_rnd / 10; // tens rounded up/down
   byte m_illum2 = mfract_rnd % 10; // units rounded up/down
   if (mfract_rnd <= 9) {  // if moon illumination percentage is less than or equal to 9  
    lc.setChar(6,3,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(6,2,m_illum2,false); // display the units digit
    }	
   if (mfract_rnd >= 10 && mfract_rnd <= 99) { // if moon illumination percentage is between 10 and 99
    lc.setDigit(6,3,m_illum1,false); // display the tens digit
    lc.setDigit(6,2,m_illum2,false); // display the units digit
    }	
   if (mfract_rnd == 100) { // if moon illumination percentage is 100, as we have only 2 digits and can't display '100', we'll instead display the word 'All', update, now displaying 'FL.' - short for 'full'
//    lc.setChar(6,3,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
//    lc.setChar(6,2,'W',false); // 'W' is actually a double letter l (ie. 'll' on 1 digit). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,3,'F',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false). displaying 'FL.' - short for FULL
    lc.setChar(6,2,'L',true); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false). displaying 'FL.' - short for FULL
   }


/*
// NOTE FOR LINES OF CODE IMMEDIATELY BELOW: as this uses the moon phase (which could be upto nearly a day out, as the moon phase varies from
// 29.18 to about 29.93 days throughout the year), this is a very innacurate way of choosing when to display an increasing or
// decreasing lunar illumination trend. It will much better (UPDATE - NO, IT'S BETTER TO USE ACCURATE 'MPHASE' VARIABLE INSTEAD) to use the very accurate
// lunar illumination percentage (ie, mfract*100.0) trend (say by looking at the difference every 2 hours of cosequtive illumination percentage
// values) to determine when to display an increasing or decreasing lunar illumination trend (ie, if the difference
// every 2 hours of cosequtive illumination percentage values exceeds a certain value, and if its a positive or negative number).
// (Note, you can't just use the accurate illumination levels alone (ie, mfract*100.0) to determine the trend as the same illumination level occurs
// twice within a lunar phase cycle, once on an increasing illumination trend, and once on a decreasing illumination trend)

// moon ilumination trend (ie, up or down) // as this uses the moon phase (which could be upto nearly a day out as the moon phase varies from 29.18 to about 29.93 days throughout the year), this is a very innacurate way of choosing when to display an increasing or decreasing lunar illumination trend. It will much better to use the very accurate lunar illumination percenatge (ie, mfract*100.0) trend (say by looking at the difference every 2 hours of cosequtive illumination percentage values) to determine when to display an increasing or decreasing lunar illumination trend (ie, if the difference every 2 hours of cosequtive illumination percentage values exceeds a certain value, and if its a positive or negative number)
   if (ph_1 <= 1.0) { // if moon phase day is 1.0 or less, ie, 1 day after new moon (out of a maximum of 29.53)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (ph_1 > 1.0 && ph_1 <= 13.77) { // if moon phase day is between 1.0 and 13.77 (out of a maximum of 29.53)
    lc.setChar(6,1,'U',false); // display 'UP' as the intensity is noticeably increasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'P',false); // display 'UP' as the intensity is noticeably increasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (ph_1 > 13.77 && ph_1 < 15.77) { // if moon phase day is between 13.77 and 15.77, ie 2 days around full moon (out of a maximum of 29.53)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (full moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (full moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (ph_1 >= 15.77 && ph_1 < 28.53) { // if moon phase day is between 15.77 and 28.53 (out of a maximum of 29.53)
    lc.setChar(6,1,'d',false); // display 'dn.' (short for down) as the intensity is noticeably decreasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'n',true); // display 'dn.' (short for down) as the intensity is noticeably decreasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (ph_1 >= 28.53) { // if moon phase day is 28.53 or more, ie, 1 day before new moon (out of a maximum of 29.53)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase time (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
 */
 
   
// moon ilumination trend (ie, up or down) using accurate moon phase between 0.0 (beginning of cycle) and 1.0 (end of cycle) - ie, for new
// moon (0% illumination) mphase = 0.0, for first quarter (50% illimination) mphase = 0.25, for full moon (100% illumination) mphase = 0.50,
// for last quarter (50% illumination) mphase = 0.75, back to new moon (0% illumination) mphase = 0.0
   if (mphase <= 0.03) { // if moon phase fraction is 0.03 or less, ie, between the actual new noon and about 1 day after the new moon (in between which times the moon ilumination percentage is barely changing at all - say only about 1%)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (mphase > 0.03 && mphase <= 0.47) { // if moon phase fraction is between 0.03 and 0.47 ie, between about 1 day after new moon and 1 day before full moon (in between which times the moon ilumination percentage is noticeably increasing)
    lc.setChar(6,1,'U',false); // display 'UP' as the intensity is noticeably increasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'P',false); // display 'UP' as the intensity is noticeably increasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (mphase > 0.47 && mphase < 0.53) { // if moon phase fraction is between 0.47 and 0.53, ie, about 1 day on either side of the full moon (in between which times the moon ilumination percentage is barely changing at all - say only about 1%)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (full moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (full moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (mphase >= 0.53 && mphase < 0.97) { // if moon phase fraction is between 0.53 and 0.97 ie, between about 1 day after full moon and 1 day before new moon (in between which times the moon ilumination percentage is noticeably decreasing)
    lc.setChar(6,1,'d',false); // display 'dn.' (short for down) as the intensity is noticeably decreasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'n',true); // display 'dn.' (short for down) as the intensity is noticeably decreasing around this time. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }
   if (mphase >= 0.97) { // if moon phase fraction is 0.97 or more, ie, between about 1 day before the new moon and the new moon itself  (in between which times the moon ilumination percentage is barely changing at all - say only about 1%)
    lc.setChar(6,1,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setChar(6,0,'-',false); // display '--' as the intensity is barely changing at all around this moon phase fraction (new moon). arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }

 }  // END OF  'if (second0 % 4 == 0) {'
 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
// Start of the 13 azimuth indicating LEDs situated at top of photo frame - optional to fit
 




//                                 TOP VIEW
//                                 --------

//                               back of frame
//                              _______________
//                             |               |
//                             |_______________|

//                       front of frame (viewing side)



//                             NORTH AT 0 DEGREES
//                                    /|\
//                                     |
//                                     |
//                                     |
//    NORTH AT 270 DEGREES  /________     ________\  NORTH AT 90 DEGREES  
//                          \                     /
//                                     |
//                                     |
//                                     |
//                                    \|/
//                            NORTH AT 180 DEGREES

 

 
 
 
 
if (north_angle == 0) { // NORTH AT 0 DEGREES
 
// Number 1. With North at 0 degrees (ie, pointing directly away from viewing side of frame) 
 
if (LED_elev > 0.0) { 
 
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  } 
  
 }
  
//////////////////////////////////////////////////////////////////////////////////  
  
 
if (north_angle == 30) { 
 
// Number 2. With North at 30 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

///////////////////////////////////////////////////////////////////////////////////////////

  
 
if (north_angle == 60) { // NORTH AT 60 DEGREES  
  
// Number 3. With North at 60 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  } 
  
 } 
  
////////////////////////////////////////////////////////////////////////////  


 
if (north_angle == 90) { // NORTH AT 90 DEGREES

// Number 4. With North at 90 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }
  
 }


////////////////////////////////////////////////////////////////////////////////


 
if (north_angle == 120) { // NORTH AT 120 DEGREES

// Number 5. With North at 120 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

///////////////////////////////////////////////////////////////////////////////


 
if (north_angle == 150) { // NORTH AT 150 DEGREES

// Number 6. With North at 150 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

////////////////////////////////////////////////////////////////////////////////


 
if (north_angle == 180) { // NORTH AT 180 DEGREES

// Number 7. With North at 180 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
}  
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

/////////////////////////////////////////////////////////////////


 
if (north_angle == 210) { // NORTH AT 210 DEGREES

// Number 8. With North at 210 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
}  
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }
  
 }
  
////////////////////////////////////////////////////////////


 
if (north_angle == 240) { // NORTH AT 240 DEGREES

// Number 9. With North at 240 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
}  
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

///////////////////////////////////////////////////


 
if (north_angle == 270) { // NORTH AT 270 DEGREES

// Number 10. With North at 270 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
}  
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }

 }

/////////////////////////////////////////////////


 
if (north_angle == 300) { // NORTH AT 300 DEGREES

// Number 11. With North at 300 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }
  
  
 }


///////////////////////////////////////////////////


 
if (north_angle == 330) { // NORTH AT 330 DEGREES

// Number 12. With North at 330 degrees (where 0 degrees is pointing directly away from viewing side of frame)

if (LED_elev > 0.0) {

   if (LED_azim >= 15 && LED_azim < 45)  {
	lc.setRow(6, 7, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 45 && LED_azim < 75)  {
	lc.setRow(6, 7, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 75 && LED_azim < 105)  {
	lc.setRow(6, 7, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 105 && LED_azim < 135)  {
	lc.setRow(6, 7, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 135 && LED_azim < 165)  {
	lc.setRow(6, 7, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 165 && LED_azim < 195)  {
	lc.setRow(6, 7, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 195 && LED_azim < 225)  {
	lc.setRow(6, 7, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 225 && LED_azim < 255)  {
	lc.setRow(6, 7, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 7
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 6
  }
  
  if (LED_azim >= 255 && LED_azim < 285)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 6
  }
  
  if (LED_azim >= 285 && LED_azim < 315)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 6
  }
  
  if (LED_azim >= 315 && LED_azim < 345)  {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 6
  }
  
  if ((LED_azim >= 345 && LED_azim < 398) || LED_azim < 15)  { // note, when showing 'meteors' the variable 'LED_azim is set to be 400 (hence the need for the '&& LED_azim < 398')
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 7
	lc.setRow(6, 6, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 6
  }
} 
  
  if (LED_azim == 400 || LED_elev <= 0.0) {
	lc.setRow(6, 7, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
	lc.setRow(6, 6, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off all 13 LEDs
  }
  
  if (LED_azim != 400 && LED_elev > 0.0) {
//	lc.setRow(6, 6, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when not showing meteor information permanently light the centre LED of 12 LEDs surrounding it
    lc.setLed(6, 6, 4, true); // address, row number (top row is 0, bottom row is 7), column number (far left column is 0, far right column is 7), if 'true' LED is switched on whilst if 'false' LED is switched off. when not showing meteor information, and planet elevation is greater than 0 degrees, permanently light the centre LED of 12 LEDs surrounding it at row 7 and 4th from left column
  }
  
 }


// End of the 13 azimuth indicating LEDs situated at top of photo frame - optional to fit

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

 
// Start of the 12 elevation indicating LEDs situated at top of photo frame - optional to fit


  if (LED_elev == 400.0 || LED_elev <= 0.0) {
	lc.setRow(6, 5, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off any elevation LEDs that are lit
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). when showing meteor information, or planet elevation is below 0 degrees, turn off any elevation LEDs that are lit
  }

   if (LED_elev > 0.0 && LED_elev <= 7.5)  { // if elevation is between 0 and 7.5 degrees then light the lowest elevation LED
	lc.setRow(6, 5, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 7.5 && LED_elev <= 15.0)  {
	lc.setRow(6, 5, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 15.0 && LED_elev <= 22.5)  {
	lc.setRow(6, 5, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 22.5 && LED_elev <= 30.0)  {
	lc.setRow(6, 5, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 30.0 && LED_elev <= 37.5)  {
	lc.setRow(6, 5, B00001000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 4th from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 37.5 && LED_elev <= 45.0)  {
	lc.setRow(6, 5, B00000100); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 5th from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 45.0 && LED_elev <= 52.5)  {
	lc.setRow(6, 5, B00000010); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 6th from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 52.5 && LED_elev <= 60.0)  {
	lc.setRow(6, 5, B00000001); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 7th from left LED of row 5
	lc.setRow(6, 4, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 4
  }
  
  if (LED_elev > 60.0 && LED_elev <= 67.5)  {
	lc.setRow(6, 5, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 5
	lc.setRow(6, 4, B10000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting far left LED of row 4
  }
  
  if (LED_elev > 67.5 && LED_elev <= 75.0)  {
	lc.setRow(6, 5, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 5
	lc.setRow(6, 4, B01000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 1st from left LED of row 4
  }
  
  if (LED_elev > 75.0 && LED_elev <= 82.5)  {
	lc.setRow(6, 5, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 5
	lc.setRow(6, 4, B00100000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 2nd from left LED of row 4
  }
  
  if (LED_elev > 82.5 && LED_elev <= 93.0)  { // note, I've set this to 93 degrees (despite it theoretically not possible to be more than 90.0 degrees) in case the arduino calculations are slightly out.
	lc.setRow(6, 5, B00000000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting no LEDs of row 5
	lc.setRow(6, 4, B00010000); // address, row number (top row is 0, bottom row is 7), each bit set to 1 will light an LED (LED at left of row is closest to letter 'B). Lighting 3rd from left LED of row 4
  }


// End of the 12 elevation indicating LEDs situated at top of photo frame - optional to fit

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  



#if(serEn)
/*	// original
    Serial.print(yr-2000); Serial.print(F("/"));
    if(mo<10) Serial.print(F("0")); Serial.print(mo); Serial.print(F("/"));
    if(dy<10) Serial.print(F("0")); Serial.print(dy); Serial.print(F(" "));
    if(hr<10) Serial.print(F("0")); Serial.print(hr); Serial.print(F(":"));
    if(mn<10) Serial.print(F("0")); Serial.print(mn); Serial.print(F(":"));
    if(se<10) Serial.print(F("0")); Serial.print(se); 
*/
	Serial.print("OLD SUN ");
    if(hr<10) Serial.print(F("0")); Serial.print(hr); Serial.print(F(":"));
    if(mn<10) Serial.print(F("0")); Serial.print(mn); Serial.print(F(":"));
    if(se<10) Serial.print(F("0")); Serial.print(se); Serial.print(F(" "));
	if(dy<10) Serial.print(F("0")); Serial.print(dy); Serial.print(F("/"));
    if(mo<10) Serial.print(F("0")); Serial.print(mo); Serial.print(F("/"));
    Serial.print(yr);

    Serial.print(F("\t  SUN-Ele: ")); Serial.print(el_deg); Serial.print(" deg."); // old sun elevation that is ok
    Serial.print(F("\t  SUN-Azi: "));  Serial.print(az_deg); Serial.print(" deg. "); Serial.print(getCardinal(az_deg)); // old sun azimuth that goes mad around 0 degrees
    Serial.print(F("\t  SUNrise: ")); Serial.print(int(sunup)); Serial.print(F(":")); if(int((sunup - int(sunup))*60.0) <10) Serial.print(F("0")); Serial.print(int((sunup - int(sunup))*60.0));
    Serial.print(F("\t  SUNset: "));  Serial.print(int(sundn)); Serial.print(F(":")); if(int((sundn - int(sundn))*60.0) <10) Serial.print(F("0")); Serial.print(int((sundn - int(sundn))*60.0));
    
	
//    Serial.print(F("\t  Moon Phase: ")); Serial.print(moonphase()); // WITHIN THIS SUBROUTINE THE VALUE ph_1 IS A MORE ACCURATE CALCULATION THAN ph
//    Serial.print(F("\t  Moon %: ")); Serial.print(moon_ill); // NOT USED AS MORE ACCURATE CALCULATION A FEW LINES BELOW. Moon perecentage illumination
    Serial.print(F("\t  Moonrise: "));  if(Rise_time[0]==0 && Rise_time[1] ==0) { Serial.print(F("none")); } else { Serial.print(Rise_time[0]); Serial.print(F(":")); Serial.print(Rise_time[1]); } 
//    Serial.print(F("\t   Moonset: "));   Serial.print(Set_time[0]);  Serial.print(F(":")); Serial.print(Set_time[1]); // AUTHORS ORIGINAL
    Serial.print(F("\t  Moonset: "));  if(Set_time[0]==0 && Set_time[1] ==0) { Serial.print(F("none")); } else { Serial.print(Set_time[0]); Serial.print(F(":")); Serial.print(Set_time[1]); } // GING TEST TO SAY 'NONE';IF MOON DOESN'T SET THIS DAY (COPIED AND ADAPTED FROM Rise_time on the line above)
    Serial.print("  Time Zone: ");
	Serial.print(TZ);
	Serial.print("  Moon ele: ");
	Serial.print(mal*irad,1); // moon elevation in degrees
	Serial.print("  Moon azi: ");
	Serial.print(mad,1); // moon azimuth in degrees
    Serial.print(F("  Moon %: ")); Serial.print(mfract*100.0,1); // accurate moon illumination percentage from 0% to 100% illumination
    Serial.print(F("  Moon phase: ")); Serial.print(mphase,3); // accurate moon phase between 0.0 (beginning of cycle) and 1.0 (end of cycle) - ie. for new moon (0% illumination) mphase = 0.0, for first quarter (50% illimination) mphase = 0.25, for full moon (100% illumination) mphase = 0.50, for last quarter (50% illumination) mphase = 0.75, back to new moon (0% illumination) mphase = 0.0
//    Serial.print(F("  Moon Phase: ")); Serial.print(ph_1,6); // A still non-accurate moon phase (in days) to 6 decimal places (to ensure this serial printed value changes every second) between 0 and 29.53059 days (but actually varies from 29.18 to about 29.93 days in reality)
	Serial.println(); 

	Serial.print("NEW SUN ");
    if(hr<10) Serial.print(F("0")); Serial.print(hr); Serial.print(F(":"));
    if(mn<10) Serial.print(F("0")); Serial.print(mn); Serial.print(F(":"));
    if(se<10) Serial.print(F("0")); Serial.print(se); Serial.print(F(" "));
	if(dy<10) Serial.print(F("0")); Serial.print(dy); Serial.print(F("/"));
    if(mo<10) Serial.print(F("0")); Serial.print(mo); Serial.print(F("/"));
    Serial.print(yr);

    Serial.print(F("\t  SUN-Ele: ")); Serial.print(sal*irad,2); Serial.print(" deg."); // new sun elevation
    Serial.print(F("\t  SUN-Azi: "));  Serial.print(sad,2); Serial.print(" deg. "); Serial.print(getCardinal(sad)); // new sun azimuth that doesn't go mad around 0 degrees

	Serial.println(); 
	Serial.println(); 

	
#endif



    osec=se;
    omin=mn; // probably not needed as I can't find another mention of this variable
    ohr=hr%12; // probably not needed as I can't find another mention of this variable
  } // end of 'if (se != osec)'
  
  
  
#if(bmp180En)  
  
 if (TFT_Millis - TFT_Previous > TFT_Interval) {  
 
 
 
  char status;
  double T, P;
  bool success = false;

  // You must first get a temperature measurement to perform a pressure reading.
  status = bmp180.startTemperature();

  if (status != 0) {
    // Wait for the measurement to complete:
    delay(status);
    status = bmp180.getTemperature(T);

    if (status != 0) {
      // Start a pressure measurement:
      // The parameter is the oversampling setting, from 0 to 3 (highest res, longest wait).
      status = bmp180.startPressure(3);

      if (status != 0) {
        // Wait for the measurement to complete:
        delay(status);
        status = bmp180.getPressure(P, T); // absolute pressure at sensor's location, ie. not compensated for altitude

        if (status != 0) {
          seaLevelPressure = bmp180.sealevel(P, alt); // equivalent sea level pressure (taking into account sensor's altitude above sea level)

        }
      }
    }
  }
  
          seaLevelPressure = seaLevelPressure + 0.05; // to round up/down
          pressure_holding = seaLevelPressure * 10; // to remove decimal point 
		  
          for (int x = 0; x < (sizeTrend - 1); x++) {
           in1[x] = in1[x + 1]; // overwrite the data in the current cell of the array with the data from the current cell plus 1 of the array (eg data in cell 24 is overwritten with data from cell 25)
           }		  
		  
          in1[sizeTrend - 1] = pressure_holding; // fill last cell of the array with the current 'pressure_holding' value
		  
          // for reference, in1[sizeTrend - 1] is the most recent value, and, for example, in1[sizeTrend - 3] is the 3rd most recent value
          difference_4hour = (float(in1[sizeTrend - 1]) - float(in1[sizeTrend - 1 - 24])) / 10.0; // difference in mbar between current pressure and pressure from 4 hours ago if taking pressure samples every 10 minutes
          difference_2hour = (float(in1[sizeTrend - 1]) - float(in1[sizeTrend - 1 - 12])) / 10.0; // difference in mbar between current pressure and pressure from 2 hours ago if taking pressure samples every 10 minutes

          pressure_counter = pressure_counter + 1; // only display pressure difference over last 4 hours and 2 hours if 'pressure_counter' has reached certain values (equivalent to 4 hours and 2 hours having elapsed since power-up)
		  if (pressure_counter >= 26) pressure_counter = 25; // limit pressure counter to maximum value of 25
		  


    
  
  
#if(serEn)

		  Serial.print("Absolute pressure: ");
          Serial.print(P,2);
          Serial.println(" hPa");	
          Serial.print("Equivalent pressure at sea level: ");
          Serial.print(seaLevelPressure);
          Serial.println(" hPa");
          Serial.print("pressure_holding = ");
          Serial.println(pressure_holding); 
		  Serial.print("4 hour difference = ");
		  Serial.println(difference_4hour);
		  Serial.print("2 hour difference = ");
		  Serial.println(difference_2hour);
		  Serial.print("pressure counter = ");
		  Serial.println(pressure_counter);
		  Serial.print("diff_2hour_holding = ");
//		  Serial.println(difference_2hour_holding);
		  Serial.println(diff_2hour_holding);
		  Serial.println();
		  Serial.println();

#endif


  TFT_Previous = TFT_Millis;
  }

#endif  
  
  


} //////////////////////////// END OF 'void Loop'


///////////////////////////////////////////////////////////////////////////////////////


void temperatura (int temper)
{
	

if (ggg == 0) { // counter variable to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed

//	Serial.print("temperature x10 = ");
//	Serial.println(temper);

/*
//ORIGINAL
int zt = ((int)temper / 100) % 10;  // to calculate the 'hundreds' digit corresponding to the 'temperature x 10'	
int ut = ((int)temper / 10) % 10;  // to calculate the 'tens' digit corresponding to the 'temperature x 10'
int xt = (int)temper % 10;  // to calculate the 'units' digit corresponding to the 'temperature x 10'


 if (temp_limiter == 1) { // if there's been an actual temperature measurement display the actual value
   lc.setDigit(3,7,zt, false); // display 100's on column 7
   lc.setDigit(3,6,ut, true); // display 10's on column 6 with decimal point
   lc.setDigit(3,5,xt, false); // display units on column 5
   }
*/




int temper_abs = abs((int)temper); // absolute value of temperature (x10)
int zt = ((int)temper_abs / 100) % 10;  // to calculate the 'hundreds' digit corresponding to the 'temperature x 10'	
int ut = ((int)temper_abs / 10) % 10;  // to calculate the 'tens' digit corresponding to the 'temperature x 10'
int xt = (int)temper_abs % 10;  // to calculate the 'units' digit corresponding to the 'temperature x 10'


 if (temp_limiter == 1) { // if there's been an actual temperature measurement display the actual value
  if (temper >= 0) { // above and including 0.0 degrees
   if (temper >= 100) {   // above and including 10.0 degrees show the 'hundreds' digit
   lc.setDigit(3,7,zt, false); // display 100's on column 7 
   }
  else {
   lc.setChar(3,7,' ',false); // between 0.0 and 9.9 degrees inclusive blank the 'hundreds' digit that would otherwise show a zero. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)	
   }
   lc.setDigit(3,6,ut, true); // display 10's on column 6 with decimal point
   lc.setDigit(3,5,xt, false); // display units on column 5
    }
	
	
  if (temper < 0 && temper > -100) { //between -0.1 and -9.9 degrees
   lc.setChar(3,7,'-',false); // show minus sign. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setDigit(3,6,ut, true); // display 10's on column 6 with decimal point
   lc.setDigit(3,5,xt, false); // display units on column 5  	
    }
	
  if (temper <= -100) { // less than and including -10.0 degrees
 	int temper_abs_round = (int)temper_abs + 5; // as we've no room to show the decimal point on a 4 digit display for temperatures below (and including) -10.0 degrees we're rounding up/down the temperature to no decimal places
    int zt_round = ((int)temper_abs_round / 100) % 10;  // to calculate the 'hundreds' digit corresponding to the 'temperature x 10'	
    int ut_round = ((int)temper_abs_round / 10) % 10;  // to calculate the 'tens' digit corresponding to the 'temperature x 10'
    lc.setChar(3,7,'-',false); // show minus sign. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)	
    lc.setDigit(3,6,zt_round, false); // display 100's on column 6
    lc.setDigit(3,5,ut_round, false); // display 10's on column 5	
    }
	
   }


   
  if (temp_limiter == 0) { //if there's NOT been an actual temperature measurement display '---'
   lc.setChar(3,7,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,6,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(3,5,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   }

  lc.setRow(3,4,B01100011); // display a degrees mark on column 4

  }
  
  ggg = ggg + 1;
  if (ggg >= 1) ggg = 1;
  
  hhh = 0; // counter variable (used in 'void data_scrolling' subroutine) reset to zero to limit scrolling date display to one pass as opposed to multiple passes throughout the full second of the 'if (second0 == 6 || second0 == 12 || second0 == 18 || second0 == 24....' statement that defines when the scrolling date is displayed
  fff = 0; // counter variable (used in 'void data_2b' subroutine) reset to zero to limit static date display ('15 May' format) to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 9 || second0 == 19 || second0 == 29 || second0 == 39...' statement that defines when the static date ('15 May' format) is displayed
//  xxx = 0; // counter variable (used in 'void data_2a' subroutine) reset to zero to limit static date display ('Mon 15' format) to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 6 || second0 == 16 || second0 == 26 || second0 == 36...' statement that defines when the static date ('Mon 15' format) is displayed
  kkk = 0; // counter variable (used in 'void quote_temp_x' subroutine) reset to zero to limit quotes on top and bottom 4-digit displays to one update as opposed to multiple updates throughout the full second of the 'if' statement that defines when the quotes are displayed

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////

void ora (int ora1, int minut1, int second1) // time (hour, minute, second)
{

  if (second1 != old_secs) {   //if secs changed then update them on the display
  
//  digitalWrite(12, HIGH);  // Atmega328. Pulse for synchronising the seconds changing with another say Atmega328 (via interupts) to do some constant animation on the additional 12 pink index seconds LEDs i'm thinking of adding 
  digitalWrite(19, HIGH);  // Atmega644. Pulse for synchronising the seconds changing with another say Atmega328 (via interupts) to do some constant animation on the additional 12 pink index seconds LEDs i'm thinking of adding 
  delay(10);                  
//  digitalWrite(12, LOW);   // Atmega328  
  digitalWrite(19, LOW);   // Atmega644  
	

	
// minutes
int zm = int(minut1/10); // determin cifra zecilor, determine the number of mins tens
int um = minut1 - 10*zm; // determin cifra unitatilor, determine the number of mins units

// seconds
int zs = int(second1/10); // determin cifra zecilor, determine the number of seconds tens
int us = second1 - 10*zs; // determin cifra unitatilor, determine the number of seconds units


/////////////////////////////////////////////////////////////

  if (time_display_mode == 0) // DEFAULT. 24 hour clock with seconds with hyphen as hrs/mins/secs separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  lc.setDigit(0,7,zo, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(0,6,uo, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
	
  // minutes
  lc.setDigit(0,4,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,3,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3
  //lc.setRow(0,2,B00000001);  // afisez o liniuta pe coloana 2, display hyphen on column 2	
  
  // seconds
  lc.setDigit(0,1,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
  lc.setDigit(0,0,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0  
  
  lc.setRow(0,5,B00000001); // display a hyphen on column 5
  lc.setRow(0,2,B00000001);  // display a hyphen on column 2
  }
///////////////////////////////////////////////////////////////

  if (time_display_mode == 1) // 24 hour clock with seconds with decimal point as hrs/mins/secs separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  lc.setDigit(0,7,zo, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(0,6,uo, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
	
  // minutes
  lc.setDigit(0,4,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,3,um, true); // afisez unitatile de minute pe coloana 3, display the minute units on column 3
  //lc.setRow(0,2,B00000001);  // afisez o liniuta pe coloana 2, display hyphen on column 2	
  
  // seconds
  lc.setDigit(0,1,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
  lc.setDigit(0,0,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0  
  
  lc.setRow(0,5,B00000000); // blank column 5
  lc.setRow(0,2,B00000000);  // blank column 2
  }
///////////////////////////////////////////////////////////////
  
  if (time_display_mode == 2) // 24 hour clock with NO seconds with hyphen as hrs/mins separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  lc.setDigit(0,6,zo, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(0,5,uo, false); // afisez unitatile de ore pe coloana 5, display the hour units on column 5	
	
  // minutes
  lc.setDigit(0,3,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,2,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3
  
  lc.setRow(0,4,B00000001); // display a hyphen on column 4
  lc.setRow(0,7,B00000000);  // blank column 7
  lc.setRow(0,1,B00000000);  // blank column 1
  lc.setRow(0,0,B00000000);  // blank column 0
  }
//////////////////////////////////////////////////////////////////// 

  if (time_display_mode == 3) // 24 hour clock with NO seconds with decimal point as hrs/mins separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  lc.setDigit(0,6,zo, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
  lc.setDigit(0,5,uo, true); // afisez unitatile de ore pe coloana 5, display the hour units on column 5	
	
  // minutes
  lc.setDigit(0,3,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,2,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3
  
  lc.setRow(0,4,B00000000);  // blank column 4
  lc.setRow(0,7,B00000000);  // blank column 7
  lc.setRow(0,1,B00000000);  // blank column 1
  lc.setRow(0,0,B00000000);  // blank column 0
  }
//////////////////////////////////////////////////////////////////

  if (time_display_mode == 4) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with NO seconds with hyphen as hour/minute separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  if (ora1 > 12) ora1 = ora1 - 12;
  if (ora1 == 0) ora1 = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,6,B00000000);  // blank column 6 if first tens digit of hour is '0' (ie no leading zero)
  if (zo != 0) lc.setDigit(0,6,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,5,uo, false); // afisez unitatile de ore pe coloana 5, display the hour units on column 5	
  
  // minutes
  lc.setDigit(0,3,zm, false); // display the minute tens on column 3
  lc.setDigit(0,2,um, false); // display the minute units on column 2
  
  lc.setRow(0,4,B00000001); // display a hyphen on column 4
  lc.setRow(0,7,B00000000);  // blank column 7
  lc.setRow(0,1,B00000000);  // blank column 1
  lc.setRow(0,0,B00000000);  // blank column 0
  }  
///////////////////////////////////////////////////////////////////////////

  if (time_display_mode == 5) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with NO seconds with decimal point as hour/minute separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  if (ora1 > 12) ora1 = ora1 - 12;
  if (ora1 == 0) ora1 = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,6,B00000000);  // blank column 6 if first tens digit of hour is '0' (ie no leading zero)  
  if (zo != 0) lc.setDigit(0,6,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,5,uo, true); // afisez unitatile de ore pe coloana 5, display the hour units on column 5	
  
  // minutes
  lc.setDigit(0,3,zm, false); // afisez zecile de minute pe coloana 3, display the minute tens on column 3
  lc.setDigit(0,2,um, false); // afisez unitatile de minute pe coloana 2, display the minute units on column 2
  
  lc.setRow(0,7,B00000000);  // blank column 7
  lc.setRow(0,4,B00000000);  // blank column 4
  lc.setRow(0,1,B00000000);  // blank column 1
  lc.setRow(0,0,B00000000);  // blank column 0
  }    
///////////////////////////////////////////////////////////////////////////////////

  if (time_display_mode == 6) // 12 hour clock (with leading zero, ie. if first tens digit of hour is '0' then always display it, otherwise if the time displayed is say 9.31 it all to close to be properly readable - at least if it shows 09.31 it makes it a little more readable) with NO seconds with decimal point as hour/minute separator, and 'AM' or 'PM' showing at far right
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  if (ora1 > 12) hour_twelve = ora1 - 12;
  if (ora1 < 13 && ora1 != 0) hour_twelve = ora1;
  if (ora1 == 0) hour_twelve = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'

  byte zo = hour_twelve/10; // determin cifra zecilor, determine the number of hour tens
  byte uo = hour_twelve - 10*zo; // determin cifra unitatilor, determine the number of hour units
//  if (zo == 0) lc.setRow(0,7,B00000000);  // blank column 7 if first tens digit of hour is '0' (ie no leading zero)   
//  if (zo != 0) lc.setDigit(0,7,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,7,zo, false); // always display the hour tens
  lc.setDigit(0,6,uo, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  
  // minutes
  lc.setDigit(0,5,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,4,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3  
  
  lc.setRow(0,3,B00000000);  // blank column 3  
  lc.setChar(0,1,'K',false); // display left half of letter 'M'.  arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,0,'Z',false); // display right half of letter 'M'.  arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  if (ora1 > 11) lc.setChar(0,2,'P',false); // display letter 'P' if the 24 hour time is greater than 11
  if (ora1 < 12) lc.setChar(0,2,'A',false); // display letter 'A' if the 24 hour time is less than 12
  }
////////////////////////////////////////////////////////////////////////////////////////////  

  if (time_display_mode == 7) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with NO seconds with hyphen as hour/minute separator, and 'A' or 'P' showing at far right
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
 // hour
  if (ora1 > 12) hour_twelve = ora1 - 12;
  if (ora1 < 13 && ora1 != 0) hour_twelve = ora1;
  if (ora1 == 0) hour_twelve = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'

  byte zo = hour_twelve/10; // determin cifra zecilor, determine the number of hour tens
  byte uo = hour_twelve - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,7,B00000000);  // blank column 7 if first tens digit of hour is '0' (ie no leading zero)   
  if (zo != 0) lc.setDigit(0,7,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,6,uo, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	 

  // minutes
  lc.setDigit(0,4,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,3,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3    
  
  lc.setRow(0,5,B00000001); // display a hyphen on column 5
  lc.setRow(0,2,B00000000);  // blank column 2
  lc.setRow(0,1,B00000000);  // blank column 1
  if (ora1 > 11) lc.setChar(0,0,'P',false); // display letter 'P' if the 24 hour time is greater than 11
  if (ora1 < 12) lc.setChar(0,0,'A',false); // display letter 'A' if the 24 hour time is less than 12
  }
/////////////////////////////////////////////////////////////////////////////////////////////  

  if (time_display_mode == 8) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with NO seconds with decimal point as hour/minute separator, and 'A' or 'P' showing at far right
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
 // hour
  if (ora1 > 12) hour_twelve = ora1 - 12;
  if (ora1 < 13 && ora1 != 0) hour_twelve = ora1;
  if (ora1 == 0) hour_twelve = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'

  byte zo = hour_twelve/10; // determin cifra zecilor, determine the number of hour tens
  byte uo = hour_twelve - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,7,B00000000);  // blank column 7 if first tens digit of hour is '0' (ie no leading zero)   
  if (zo != 0) lc.setDigit(0,7,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,6,uo, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	 

  // minutes
  lc.setDigit(0,4,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
  lc.setDigit(0,3,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3    
  
  lc.setRow(0,5,B00000000);  // blank column 5
  lc.setRow(0,2,B00000000);  // blank column 2
  lc.setRow(0,1,B00000000);  // blank column 1
  if (ora1 > 11) lc.setChar(0,0,'P',false); // display letter 'P' if the 24 hour time is greater than 11
  if (ora1 < 12) lc.setChar(0,0,'A',false); // display letter 'A' if the 24 hour time is less than 12
  }
//////////////////////////////////////////////////////////////////////////////////////////////////

  if (time_display_mode == 9) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with seconds with hyphen as hour/minute/second separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  if (ora1 > 12) ora1 = ora1 - 12;
  if (ora1 == 0) ora1 = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,7,B00000000);  // blank column 7 if first tens digit of hour is '0' (ie no leading zero)
  if (zo != 0) lc.setDigit(0,7,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,6,uo, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  
  // minutes
  lc.setDigit(0,4,zm, false); // display the minute tens on column 4
  lc.setDigit(0,3,um, false); // display the minute units on column 3
  
  // seconds
  lc.setDigit(0,1,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
  lc.setDigit(0,0,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0    
  
  lc.setRow(0,5,B00000001); // display a hyphen on column 5
  lc.setRow(0,2,B00000001); // display a hyphen on column 2
  }
/////////////////////////////////////////////////////////////////////////

  if (time_display_mode == 10) // 12 hour clock (no leading zero, ie. if first tens digit of hour is '0' then don't display it) with seconds with decimal point as hour/minute/second separator
  {
  digitalWrite(DOT_CLOCK, HIGH);  // logic HIGH to Atmega328 to NOT show current hour on pink index LEDs
  // hour
  if (ora1 > 12) ora1 = ora1 - 12;
  if (ora1 == 0) ora1 = 12; // between midnight and 00:59 show 12 (ie, 12am) in '12 hour clock format'
  int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
  int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
  //if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
  if (zo == 0) lc.setRow(0,7,B00000000);  // blank column 7 if first tens digit of hour is '0' (ie no leading zero)
  if (zo != 0) lc.setDigit(0,7,zo, false); // if first tens digit of hour is not '0' then display the hour tens
  lc.setDigit(0,6,uo, true); // afisez unitatile de ore pe coloana 6, display the hour units on column 6	
  
  // minutes
  lc.setDigit(0,4,zm, false); // display the minute tens on column 4
  lc.setDigit(0,3,um, true); // display the minute units on column 3
  
  // seconds
  lc.setDigit(0,1,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
  lc.setDigit(0,0,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0    
  
  lc.setRow(0,5,B00000000); // blank column 5
  lc.setRow(0,2,B00000000); // blank column 2
  }
////////////////////////////////////////////////////////////////////////////////  

  if (time_display_mode == 11) // minutes displayed on outer 60 yellow LED ring via Atmega644, hour displayed as a single pink LED via Atmega328. The 'Time' 8-digit display shows optionally the seconds, or 'AM/PM'
  {
  
  digitalWrite(DOT_CLOCK, LOW);  // logic LOW to Atmega328 to show current hour on pink index LEDs
  
  
  
  // CHOOSE EITHER (A) TO DISPLAY SECONDS OR (B)'AM/PM' WHEN IN THIS MODE
  
if (dot_clock_display_seconds == true) {
  // (A) START OF DISPLAY SECONDS
  lc.setDigit(0,4,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
  lc.setDigit(0,3,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0    
  
  lc.setChar(0,7,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,6,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(0,0,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,1,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setRow(0,5,B00000000); // blank column 5
  lc.setRow(0,2,B00000000); // blank column 2
  // (A) END  OF DISPLAY SECONDS
}
  
  
 
if (dot_clock_display_seconds == false) { 
  // (B) START OF DISPLAY 'AM/PM'
  lc.setChar(0,7,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,0,'-',false); // asthetics only. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setRow(0,6,B00000000); // blank column 6
  lc.setRow(0,4,B00000000); // blank column 4
  lc.setRow(0,1,B00000000); // blank column 1
  
  if (IS_IT_AM == true)
  {
  lc.setChar(0,5,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  else
  {
  lc.setChar(0,5,'P',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  }
  
  lc.setChar(0,3,'K',false); // letter 'M' spread over 2 digits. This is the left part of letter 'M'. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,2,'Z',false); // letter 'M' spread over 2 digits. This is the right part of letter 'M'. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  // (B) END OF DISPLAY 'AM/PM'
}


  
        // at 0 seconds, or if the LED animation mode has just been changed on the fly, turn off all led's, but just once - hence the reason for the 'aaa' variable and the 'LED_MODE_1_CHANGED' boolean
      if ((minut1 == 0 && aaa == 0) || LED_MODE_1_CHANGED == true)
      {
		for (int i = 0; i < 60; i++)
        {
          lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  }
		LED_MODE_1_CHANGED = false;
		aaa = aaa + 1;
		if (aaa > 1) aaa = 1;
	  

      for (int i = 0; i <= minut1; i++)
      {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 minutes to current minute. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  }
//	  Serial.println("light LEDs from 0 mins to current minute");

	  
      if (minut1 == 59 && second1 == 59) aaa = 0; // reset aaa variable to 0 just before the minute and seconds are zero so all LEDs can be turned off just once when seconds and minute are at 0.
  
  
  }
  
//////////////////////////////////////////////////////////////////////////////

	  
	  
	  
	  
	
/*	
/////////////////////ORIGINAL TIME START	
// hour
int zo = int(ora1/10); // determin cifra zecilor, determine the number of hour tens
int uo = ora1 - 10*zo; // determin cifra unitatilor, determine the number of hour units
//if (zo >= 1) lc.setDigit(0,7,zo, false); // afisez zecile de ore pe coloana 7 (in stanga), display the hour tens if tens is 1 or greater - optional if you want to blank the tens hour digit if the digit is zero - comment out line below if this is needed
lc.setDigit(0,7,zo, false); // display the hour tens - always displays the leading zero if the tens hour digit is infact zero (comment line above if this is needed)
lc.setDigit(0,6,uo, false); // afisez unitatile de ore pe coloana 6, display the hour units on column 6

// minutes
int zm = int(minut1/10); // determin cifra zecilor, determine the number of mins tens
int um = minut1 - 10*zm; // determin cifra unitatilor, determine the number of mins units
lc.setDigit(0,4,zm, false); // afisez zecile de minute pe coloana 4, display the minute tens on column 4
lc.setDigit(0,3,um, false); // afisez unitatile de minute pe coloana 3, display the minute units on column 3
//lc.setRow(0,2,B00000001);  // afisez o liniuta pe coloana 2, display hyphen on column 2

// seconds
int zs = int(second1/10); // determin cifra zecilor, determine the number of seconds tens
int us = second1 - 10*zs; // determin cifra unitatilor, determine the number of seconds units
lc.setDigit(0,1,zs, false); // afisez zecile de secunde pe coloana 1, display the seconds tens on column 1
lc.setDigit(0,0,us, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the seconds units on column 0
/////////////////////ORIGINAL TIME END
*/



//SELECT ONE OF THE FOLLOWING 3 HYPHEN SEPARATOR OPTIONS (by commenting out the other two)



// OPTION 1: for solidly lit 2 separator hyphens
//option 1 begin
//lc.setRow(0,5,B00000001); // display a hyphen on column 5
//lc.setRow(0,2,B00000001);  // display a hyphen on column 2
//option 1 end



/*
// OPTION 2: for alternatively flashing separator hyphens (ie, when one of the 2 hyphens is on the other is off, and vice versa)
//option 2 begin
if (us % 2 == 0)
  {	
   lc.setRow(0,5,B00000001); // display a hyphen on column 5 for even seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
   lc.setRow(0,2,B00000000); // don't display a hyphen on column 2 for even seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }

if (us % 2 == 1)
  {	
   lc.setRow(0,5,B00000000); // don't display a hyphen on column 5 for odd seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
   lc.setRow(0,2,B00000001); // display a hyphen on column 2 for odd seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
 //option 2 end 
*/  
  
  
/*  
// OPTION 3: for simultaneously flashing separator hyphens (ie, both the hyphens are either simultaneously lit or unlit)
//option 3 begin
if (us % 2 == 0)
  {	
   lc.setRow(0,5,B00000001); // display a hyphen on column 5 for even seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
   lc.setRow(0,2,B00000001); // display a hyphen on column 2 for even seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }

if (us % 2 == 1)
  {	
   lc.setRow(0,5,B00000000); // don't display a hyphen on column 5 for odd seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
   lc.setRow(0,2,B00000000); // don't display a hyphen on column 2 for odd seconds only {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
//option 3 end
*/


// END OF HYPHEN SEPARATOR OPTIONS




/*
  Serial.print(zo);
  Serial.print(uo);
  Serial.print("-");
  Serial.print(zm);
  Serial.print(um);
  Serial.print("-");
  Serial.print(zs);
  Serial.print(us);
  Serial.println("  end");
*/



//lc.setRow(2,2,B00111111); // GARBAGE - testing only to see if 8x8 matrix lights up

//           Serial.print("LED_RING_ANIMATION variable in TIME subroutine = ");
//           Serial.println(LED_RING_ANIMATION);


////////START OF AUTO CYCLING LED SECONDS RING MODE

  if (time_display_mode != 11) { // show seconds on outer yellow LED ring for all time display modes except time display mode 11, where the minutes instead are shown on the outer yellow LED ring, whilst the hour is indicated by a single lit pink index LED

 
/* 
 if (digitalRead(auto_cycling_pin) == HIGH) 
  {
	  cycle = false;
  }
  else
  {
	  cycle = true;
  }
*/

// we are combining 2 switches here (the Daylight saving time switch, and the seconds ring auto cycling mode switch) into a single pin (Atmega644 pin 38) to (because i've run out of pins) allow the BMP180 pressure sensor to have its readings to be displayed or not (as opposed to displaying the next meteor day information) via a switch
     if (((analogRead(A2) >= 613) && (analogRead(A2) <= 715)) || ((analogRead(A2) >= 755) && (analogRead(A2) <= 858))) cycle = true; // pin at 3.25V or 3.94V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band either way) means 'Auto cycling seconds ring animation' switch has been set to ON, and so the seconds ring animation will alter automatcally
     if (((analogRead(A2) >= 0) && (analogRead(A2) <= 102)) || ((analogRead(A2) >= 460) && (analogRead(A2) <= 563))) cycle = false; // pin at 0.0V or 2.50V assuming 5V supply (but analogRead values won't change for lower supply voltages as it's ratiometric, with a bit of a band) means 'Auto cycling seconds ring animation' switch has been set to OFF, and so the seconds ring animation will NOT alter automatcally

#if(serEn)

		  Serial.print("Auto cycle seconds ring LEDs = ");
          Serial.println(cycle);

#endif

/*
// start of OLD auto cycling seconds ring animation modes  
  if (cycle == true)
  {
	  if (minut1/10 == 0)
	  {
		  LED_RING_ANIMATION = 0;
		  if (min_0s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_0s = false;
      min_10s = true;
	  }
	  
	  if (minut1/10 == 1)
	  {
		  LED_RING_ANIMATION = 1;
		  if (min_10s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_10s = false;
      min_20s = true;
	  }
	  
	  if (minut1/10 == 2)
	  {
		  LED_RING_ANIMATION = 2;
		  if (min_20s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_20s = false;
      min_30s = true;
	  }
	  
	  if (minut1/10 == 3)
	  {
		  LED_RING_ANIMATION = 3;
		  if (min_30s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_30s = false;
      min_40s = true;
	  }
	  
	  if (minut1/10 == 4)
	  {
		  LED_RING_ANIMATION = 4;
		  if (min_40s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_40s = false;
      min_50s = true;
	  }
	  
	  if (minut1/10 == 5)
	  {
		  LED_RING_ANIMATION = 6;
		  if (min_50s == true)
		  {
			 LED_MODE_1_CHANGED = true;
		  }
      min_50s = false;
      min_0s = true;
	  }

  } // end of 'if (cycle == true)'	 
// end of OLD auto cycling seconds ring animation modes   
*/



// start of NEW auto cycling seconds ring animation modes
  if (cycle == true)
  {

 if (Seconds_Millis - Seconds_Previous > Seconds_Interval) {  
		LED_RING_ANIMATION = LED_RING_ANIMATION + 1;
	    if (bmp180En == true) {	
		 if (LED_RING_ANIMATION == 16 || LED_RING_ANIMATION == 17 || LED_RING_ANIMATION == 18) LED_RING_ANIMATION = 0; // we need to bypass any of the last 2 pressure related animation modes, as I'm sure we'd like to select them manually and stay in them for lengthly periods. Also, we need to wrap back to first animation. This code line takes into account whether we've just activated the autocycling mode if currently in 'LED_RING_ANIMATION == 15', or if currently in 'LED_RING_ANIMATION == 16', or if currently in 'LED_RING_ANIMATION == 17'
	    }
	    if (bmp180En == false) {	
		 if (LED_RING_ANIMATION == 16) LED_RING_ANIMATION = 0; // wrap back to first animation after bypassing animations that involve the bmp180 pressure sensor 2hr and 4hr trends
	    }
		LED_MODE_1_CHANGED = true; // can be used for any of the seconds ring animation modes
		LED_MODE_1_CHANGED_END = true; // can be used for any of the seconds ring animation modes

     Seconds_Previous = Seconds_Millis;
  }

  } // end of 'if (cycle == true)'	
// end of NEW auto cycling seconds ring animation modes
  
  
//////////////////////////////////////////////////////////////////////////////////
//  CHOOSE ONE OF THE FOLLOWING 8 ARTISTIC SECOND RING REPRESENTATIONS USING 60 LEDs:


////////////////////////////////////////////////////////////////////////////////////Begin of LED_MODE 1
// 1)  LED_MODE 1. Light LED's sequentially from zero to current second - FINISHED

	if (LED_RING_ANIMATION == 0)
	{
      // at 0 seconds, or if the LED animation mode has just been changed on the fly, turn off all led's, but just once - hence the reason for the 'ddd' variable and the 'LED_MODE_1_CHANGED' boolean
      if ((second1 == 0 && ddd == 0) || LED_MODE_1_CHANGED == true || LED_MODE_1_CHANGED_END == true)
      {
		for (int i = 0; i < 60; i++)
        {
          lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  }
		LED_MODE_1_CHANGED = false;
		LED_MODE_1_CHANGED_END = false;
		ddd = ddd + 1;
		if (ddd > 1) ddd = 1;
	  

      for (int i = 0; i <= second1; i++)
      {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  }
//	  Serial.println("light LEDs from 0secs to curent second");

	  
      if (second1 == 59) ddd = 0; // reset ddd variable to 0 so all LEDs can be turned off just once when seconds are at 0.
	}
//////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 1

	  
	  

//////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 2
// 2) LED_MODE 2. Light single LED at current second - FINISHED (in simulation temperature being displayed goes mad at 1 and 11 seconds display time if measuring temperature at 0 seconds, so now I'm now measuring temperature at 14 and 44 secs with this line 'if (second0 == 14 || second0 == 44) t = measure_Temp();')
	if (LED_RING_ANIMATION == 1)
	{
		
      // if the LED animation mode has just been changed on the fly, turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
      if (LED_MODE_1_CHANGED == true)
      {
		for (int i = 0; i < 60; i++)
        {
          lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  }
		LED_MODE_1_CHANGED = false;
	
     // turn off LED's from zero to one less than current second, (do not turn off LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
      for (int i = 0; i <= second1-1; i++)
      {
        lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	  
	  if (second1 == 0) lc.setLed(2, 7, 3, false); // Turn off final 59 second LED which is left lit at 0 seconds because of 'for (int i = 0; i <= second1-1; i++)' line above. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off

	  
      // turn on one led, to indicate the current second
      lc.setLed(2, (second1) / 8, (second1) % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	}
////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 2



////////////////////////////////////////////////////////////////////////////////////Begin of LED_MODE 3
// 3)  LED_MODE 3. Animating anticlockwise seconds LED over 0.2 seconds from 59 second LED to current second LED - FINISHED I THINK
//NOTE, COMMENT OUT THE 'if (second1 == 59) zzz = 0;' LINE AT THE BOTTOM OF THIS SUBROUTINE IF YOU WANT A GRADUAL (OVER A TIMESCALE DEFINED BY THE 'DELAY...' LINE AT THE BOTTOM OF THIS 'LED_MODE 3' SUBROUTINE - WHICH ACTUALLY LOOKS QUITE NICE) RATHER THAN AN INSTANTANEOUS UNLIT OF THE CURRENTLY LIT 0 TO 59 SECOND LEDS WHEN THE SECONDS GO FROM 59 TO 0 SECS
	if (LED_RING_ANIMATION == 2)
	{
      // at 0 seconds, or if the LED animation mode has just been changed on the fly, or if the button on port C0 has just been 'short' pushed, turn off all led's, but just once - hence the reason for the 'ddd' variable and the 'LED_MODE_1_CHANGED' boolean
      if ((second1 == 0 && zzz == 0) || LED_MODE_1_CHANGED == true || short_push == true)
      {
		for (int i = 0; i < 60; i++)
        {
          lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  }
	  
	if (LED_MODE_1_CHANGED == true || short_push == true || just_powered_up == true || midnight_animation == true || quote_occured == true || scroll_occured == true || face_occured == true) { // if animation mode has just changed, or if clock has just been powered up in this mode, or if the button on port C0 has just been 'short' pushed, or if the midnight animation has just run, or if 'this day in 1945...' style quote has just ended, or if a scrolling quote has just ended, or if sleepy/awake face has just been displayed, then need to light up all the LEDS from 0 secs to the current seconds to duplicate what would have been if the animation mode hadn't been changed
	  for (int i = 0; i <= second1; i++)
	   {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	   }
	  }
	  
	    face_occured = false;
		scroll_occured = false;	  
		quote_occured = false;	  
		midnight_animation = false;
		just_powered_up = false;
		LED_MODE_1_CHANGED = false;
		short_push = false;
		zzz = zzz + 1;
		if (zzz > 1) zzz = 1;
	  

      for (int i = 59; i >= second1; i--)
      {
		lc.setLed(2, i / 8, i % 8, true); // Light LEDs sequentially anticlockwise from the 59th second LED to the current second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
// CHOOSE EITHER ONE OF THE 2 'delay...' LINES DIRECTLY BELOW THIS LINE
//		delay(6); // was 3. make LEDs sequentially lit animation last no more than say about 0.2 secs (at worst case when current second is zero - ie, all 60 LEDS need to be sequentially lit)
		delay(360/(60 - second1)); // was 'delay(200/(60 - second1))'. If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off lit LED during animation sequence except when current second LED is now lit
	  }
	}
//////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 3




///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 4
// 4) LED_MODE 4. Inverse of single LED lit at current second, ie, inverse of (2) above - FINISHED

	if (LED_RING_ANIMATION == 3)  
	{
  
	  // turn all LED ring LED's on but just once, on power up, or after the clock/date has been adjusted, or if the button on port C0 has just been 'short' pushed, or if the midnight animation has just occured, or if 'this day in 1945...' style quote has just ended, or if a scrolling quote has just ended, or if sleepy/awake face had just been displayed
        if (eee == 0 || ClockJustBeenSet == true || LED_MODE_1_CHANGED == true || short_push == true || midnight_animation == true || quote_occured == true || scroll_occured == true || face_occured == true) {
		  for (int i = 0; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}
		eee = eee + 1;
		if (eee > 1) eee = 1;
		scroll_occured = false;	  
		quote_occured = false;	
		ClockJustBeenSet = false;
		LED_MODE_1_CHANGED = false;
		short_push = false;
		midnight_animation = false;
		face_occured = false;
	
	    // At 0 seconds only, turn on LED representing 59 seconds, which is not lit as a consequence of the 'for (int i = 0; i <= (second1-1); i++)' line below
		if (second1 == 0) lc.setLed(2, 7, 3, true); // Turn on final 59 second LED which is left lit at 0 seconds because of 'for (int i = 0; i <= second1-1; i++)' line above. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off	
		
        // light LED's from zero to current second minus one (do not light LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
        for (int i = 0; i <= (second1-1); i++)
        {
          lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  
        // turn off one led at current second to indicate the current second
        lc.setLed(2, second1 / 8, second1 % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 4


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 5
// 5) LED_MODE 5. One LED rotating clockwise from 0 secs LED to 30 secs LED - taking about 0.3sec to do so, whilst simultaneously a second LED is rotating anticlockwise from 0 secs LED to 30 secs LED - taking about 0.3sec to do so also. NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 4)  
	{
		
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
      {
		for (byte i = 0; i < 60; i++)
        {
          lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  }
		LED_MODE_1_CHANGED = false;

	 for (byte j = 0; j < 31; j++)
	 {
      lc.setLed(2, j / 8, j % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      lc.setLed(2, (60 - j) / 8, (60 - j) % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  delay(12); // if it still looks visually ok then better to use delay(11) or even delay(10)
      lc.setLed(2, j / 8, j % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      lc.setLed(2, (60 - j) / 8, (60 - j) % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	 }

	}
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 5	


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 6
// 6) LED_MODE 6. A pendulum style animation where 11 LEDs are oscillating around the 30 sec LED position - taking about 0.3 sec to do so.  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 5)  
	{
		
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2);
	 }
	  LED_MODE_1_CHANGED = false;
	  
	 if (second1 % 2 == 0) // if an even number of seconds
	 {
	  for (byte i = 30; i < 41; i++)
        {
          lc.setLed(2, i / 8, i % 8, true); // light LEDs 1 at a time incrementally from 30 to 40.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (i - 11) / 8, (i - 11) % 8, false); // unlight LEDs 1 at a time incrementally from 19 to 29.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		  delay(30); // 30 makes total animation time of 0.3 secs
		}
	 }	
	 
	 if (second1 % 2 == 1) // if an odd number of seconds
	 {
	  for (byte j = 30; j > 19; j--)
        {
          lc.setLed(2, j / 8, j % 8, true); // light LEDs 1 at a time incrementally from 30 to 20.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (j + 11) / 8, (j + 11) % 8, false); // unlight LEDs 1 at a time incrementally from 41 to 31.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		  delay(30); // 30 makes total animation time of 0.3 secs
		}
	 }		
		
	}
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 6

///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 7
// 7) LED_MODE 7. Similar to LED mode 3, but this time throwing away seconds over a 0.3 sec duration towards the 0 secs LED

	if (LED_RING_ANIMATION == 6)  
	{
		
	  // turn all LED ring LED's on but just once, at 0 secs, on power up, or after the clock/date has been adjusted, or if the button on port C0 has just been 'short' pushed, or if the midnight animation has just occured, or if 'this day in 1945...' style quote has just ended, or if a scrolling quote has just ended, or if a sleepy/awake face has just been displayed
        if ((second1 == 0 && nnn == 0) || eee == 0 || ClockJustBeenSet == true || just_powered_up == true || LED_MODE_1_CHANGED == true || short_push == true || midnight_animation == true || quote_occured == true || scroll_occured == true || face_occured == true) {
	      lc.clearDisplay(2); // addition 
//		  for (byte i = 0; i <= 59; i++) // original
		  for (byte i = second1; i <= 59; i++) 
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}
		
		
		if (just_powered_up == true || LED_MODE_1_CHANGED == true) {
		 lc.setLed(2, 0, 0, true);	// turn 0 sec LED on	
		}
		
		  eee = eee + 1;
		  if (eee > 1) eee = 1;
		  scroll_occured = false;	  
		  quote_occured = false;	
		  ClockJustBeenSet = false;
		  just_powered_up = false;
		  LED_MODE_1_CHANGED = false;
		  short_push = false;
		  midnight_animation = false;
		  face_occured = false;
		  nnn = nnn + 1;
		  if (nnn > 1) nnn = 1;
		
	    
		
		if (second1 == 1)
		{
		 lc.setLed(2, 0, 1, false);	// just turn 1 sec LED off
	    }
		
		
//		if (second1 == 2)
//		{
//		 lc.setLed(2, 0, 0, true);	// just turn 0 sec LED back on
//	    }
		
			
	
	     if (second1 != 0 && second1 != 1) // without this all the lit LEDS at zero seconds from the 'if' statement above will be erased again as at zero seconds 'for (byte j = (second1 - 1); j > 0; j--)' actually cycles through 'j' from 255 to 1
	     {
	      for (byte j = second1; j > 0; j--)
            {
              lc.setLed(2, j / 8, j % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
//   CHOOSE EITHER ONE OF THE 2 'delay...' LINES DIRECTLY BELOW THIS LINE
//		      delay(6); //6 makes total animation time of 0.3 secs
		      delay(360 / second1); //  If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
              lc.setLed(2, j / 8, j % 8, false); // unlight LEDs sequentially from the seconds minus one LED to Zero secs LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off

		    }			
	     }
							
	}
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 7


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 8
// 8) LED_MODE 8. A double pendulum style animation where 11 LEDs are oscillating around the 15 and 45 sec LED positions - taking about 0.3 sec to do so.  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 7)  
	{
		
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2);
	 }
	  LED_MODE_1_CHANGED = false;
	  
	 if (second1 % 2 == 0) // if an even number of seconds
	 {
	  for (byte i = 45; i < 56; i++)
        {
          lc.setLed(2, i / 8, i % 8, true); // light LEDs 1 at a time incrementally from 45 to 55.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (i - 11) / 8, (i - 11) % 8, false); // unlight LEDs 1 at a time incrementally from 34 to 44.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (i - 30) / 8, (i - 30) % 8, true); // light LEDs 1 at a time incrementally from 15 to 25.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (i - 11 - 30) / 8, (i - 11 - 30) % 8, false); // unlight LEDs 1 at a time incrementally from 4 to 14.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		  delay(30); // 30 makes total animation time of 0.3 secs
		}
	 }	
	 
	 if (second1 % 2 == 1) // if an odd number of seconds
	 {
	  for (byte j = 45; j > 34; j--)
        {
          lc.setLed(2, j / 8, j % 8, true); // light LEDs 1 at a time incrementally from 45 to 35.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (j + 11) / 8, (j + 11) % 8, false); // unlight LEDs 1 at a time incrementally from 56 to 46.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (j - 30) / 8, (j - 30) % 8, true); // light LEDs 1 at a time incrementally from 5 to 15.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          lc.setLed(2, (j + 11 - 30) / 8, (j + 11 - 30) % 8, false); // unlight LEDs 1 at a time incrementally from 26 to 16.   arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		  delay(30); // 30 makes total animation time of 0.3 secs
		}
	 }		
		
	}
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 8


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 9

// 9) LED_MODE 9. Four groups of 3 adjacent LEDs spaced equally around the circle of 60 LEDs rotate clockwise by 3 LEDs at every second, the previous seconds lit LEDs being unlit (thus the pattern will repeat every 5 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 8)  
	{
	  lc.clearDisplay(2); // clear the previous seconds LEDs lit

	  for (int i = 0; i < 3; i++)
      {		  
       lc.setLed(2, (((second1 % 5) * 3) + i) / 8, (((second1 % 5) * 3) + i) % 8, true); // light LEDs corresponding to 0,1,2 secs, then 3,4,5 secs, then 6,7,8 secs, then 9,10,11 secs, then 12,13,14 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 5) * 3) + i + 15) / 8, (((second1 % 5) * 3) + i + 15) % 8, true); // light LEDs corresponding to 15,16,17 secs, then 18,19,20 secs, then 21,22,23 secs, then 24,25,26 secs, then 27,28,29 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 5) * 3) + i + 30) / 8, (((second1 % 5) * 3) + i + 30) % 8, true); // light LEDs corresponding to 30,31,32 secs, then 33,34,35 secs, then 36,37,38 secs, then 39,40,41 secs, then 42,43,44 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 5) * 3) + i + 45) / 8, (((second1 % 5) * 3) + i + 45) % 8, true); // light LEDs corresponding to 45,46,47 secs, then 48,49,50 secs, then 51,52,53 secs, then 54,55,56 secs, then 57,58,59 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  } 
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 9


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 10

// 10) LED_MODE 10. Four groups of 3 adjacent LEDs spaced equally around the circle of 60 LEDs rotate clockwise by 3 LEDs at every second, the previous seconds lit LEDs staying lit  (thus the pattern will repeat every 5 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 9)  
	{

	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2);
	 }
	 LED_MODE_1_CHANGED = false;
	 

    if (second1 % 5 == 0) { // unlight all the LEDs when all the LEDs are lit (ie, at 0, 5, 10, 15......50, 55 secs)
     lc.clearDisplay(2);
	}

	  for (int i = 0; i < ((second1 % 5) * 3) + 3; i++)
      {		  
       lc.setLed(2, i / 8, i % 8, true); // light LEDs incrementaly in groups of 3 from the 0 second LED to the 14 second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (i + 15) / 8, (i + 15) % 8, true); // light LEDs incrementaly in groups of 3 from the 15 second LED to the 29 second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (i + 30) / 8, (i + 30) % 8, true); // light LEDs incrementaly in groups of 3 from the 30 second LED to the 44 second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (i + 45) / 8, (i + 45) % 8, true); // light LEDs incrementaly in groups of 3 from the 45 second LED to the 49 second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  } 
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 10


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 11

// 11) LED_MODE 11. Four groups of 5 adjacent LEDs spaced equally around the circle of 60 LEDs rotate clockwise by 5 LEDs at every second, the previous seconds lit LEDs being unlit  (thus the pattern will repeat every 3 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 10)  
	{
	  lc.clearDisplay(2); // clear the previous seconds LEDs lit

	  for (int i = 0; i < 5; i++)
      {		  
       lc.setLed(2, (((second1 % 3) * 5) + i) / 8, (((second1 % 3) * 5) + i) % 8, true); // light LEDs corresponding to 0,1,2,3,4 secs, then 5,6,7,8,9 secs, then 10,11,12,13,14 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 3) * 5) + i + 15) / 8, (((second1 % 3) * 5) + i + 15) % 8, true); // light LEDs corresponding to 15,16,17,18,19 secs, then 20,21,22,23,24, then 25,26,27,28,29 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 3) * 5) + i + 30) / 8, (((second1 % 3) * 5) + i + 30) % 8, true); // light LEDs corresponding to 30,31,32,33,34 secs, then 35,36,37,38,39 secs, then 40,41,42,43,44 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 3) * 5) + i + 45) / 8, (((second1 % 3) * 5) + i + 45) % 8, true); // light LEDs corresponding to 45,46,47,48,49 secs, then 50,51,52,53,54 secs, then 55,56,57,58,59 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  } 
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 11


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 12

// 12) LED_MODE 12. Two groups of 15 adjacent LEDs spaced 180 degrees apart rotate clockwise by 15 LEDs at every second, the previous seconds lit LEDs being unlit  (thus the pattern will repeat every 2 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 11)  
	{
	  lc.clearDisplay(2); // clear the previous seconds LEDs lit

	  for (int i = 0; i < 15; i++)
      {		  
       lc.setLed(2, (((second1 % 2) * 15) + i) / 8, (((second1 % 2) * 15) + i) % 8, true); // light LEDs corresponding to 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14 secs, then 15,16,17,18,19,20,21,22,23,24,25,26,27,28,29 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 2) * 15) + i + 30) / 8, (((second1 % 2) * 15) + i + 30) % 8, true); // light LEDs corresponding to 30,31,32,33,34,35,36,37,38,39,40,41,42,43,44 secs, then 45,46,47,48,49,50,51,52,53,54,55,56,57,58,59 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
 	  } 
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 12


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 13

// 13) LED_MODE 13. Three groups of 10 adjacent LEDs spaced 120 degrees apart rotate clockwise by 10 LEDs at every second, the previous seconds lit LEDs being unlit  (thus the pattern will repeat every 2 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 12)  
	{
	  lc.clearDisplay(2); // clear the previous seconds LEDs lit

	  for (int i = 0; i < 10; i++)
      {		  
       lc.setLed(2, (((second1 % 2) * 10) + i) / 8, (((second1 % 2) * 10) + i) % 8, true); // light LEDs corresponding to 0,1,2,3,4,5,6,7,8,9 secs, then 10,11,12,13,14,15,16,17,18,19 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 2) * 10) + i + 20) / 8, (((second1 % 2) * 10) + i + 20) % 8, true); // light LEDs corresponding to 20,21,22,23,24,25,26,27,28,29 secs, then 30,31,32,33,34,35,36,37,38,39 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, (((second1 % 2) * 10) + i + 40) / 8, (((second1 % 2) * 10) + i + 40) % 8, true); // light LEDs corresponding to 40,41,42,43,44,45,46,47,48,49 secs, then 50,51,52,53,54,55,56,57,58,59 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
 	  } 
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 13


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 14

// 14) LED_MODE 14. Every second 6 more LEDs are lit, with a short delay between the last 3 pairs of LEDs lighting up, the previous seconds lit LEDs staying lit. This pattern is duplicated 180 degrees apart  (thus the pattern will repeat every 6 seconds).  NOTE - the lit LEDs have no meaning to what the actual seconds are - this is purely for asthetics (the seconds can be got from the 8-digit display anyhow)

	if (LED_RING_ANIMATION == 13)  
	{

	 if (LED_MODE_1_CHANGED == true || just_powered_up == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2); // keep
	  if ((second1 % 6 != 0) || (second1 % 6 != 1)) // Not that necessary, but if complications just remove this 'if' statement. light up LEDs that would have ben lit up if this animation hadn't been changed on the fly (ie, in the middle of the animation)
	  {
       for (int i = 0; i <= (((second1 % 6) - 1) * 6); i++)
       {
        lc.setLed(2, i / 8, i % 8, true); // light LEDs that what would have been lit up if animation not changed on the fly. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        lc.setLed(2, (i + 30) / 8, (i + 30) % 8, true); // light LEDs that what would have been lit up if animation not changed on the fly. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	   }		  
	  }
	 }
	 LED_MODE_1_CHANGED = false;
	 just_powered_up = false;
	 

    if (second1 % 6 == 0) { // unlight all the LEDs when all the LEDs are lit (ie, at 0, 6, 12, 18......48, 54 secs)
     lc.clearDisplay(2);
	}

    if (second1 % 6 != 0)
	{
	      delay (100);  // optional -check to see if it makes it visually better of worse
	
	  for (int i = 0; i < 2; i++)
	  {
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i) / 8, ((((second1 % 6) - 1) * 6) + i) % 8, true); // light LEDs corresponding to 0,1 secs, then 6,7 secs, then 12,13 secs, then 18,19 secs, then 24,25 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i + 30) / 8, ((((second1 % 6) - 1) * 6) + i + 30) % 8, true); // light LEDs corresponding to 30,31 secs, then 36,37 secs, then 42,43 secs, then 48,49 secs, then 54,55 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	  
      delay (100);	  
	  
	  for (int i = 0; i < 2; i++)
	  {
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i + 2) / 8, ((((second1 % 6) - 1) * 6) + i + 2) % 8, true); // light LEDs corresponding to 2,3 secs, then 8,9 secs, then 14,15 secs, then 20,21 secs, then 26,27 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i + 32) / 8, ((((second1 % 6) - 1) * 6) + i + 32) % 8, true); // light LEDs corresponding to 32,33 secs, then 38,39 secs, then 44,45 secs, then 50,51 secs, then 56,57 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	  
      delay (100);	  
	  
	  for (int i = 0; i < 2; i++)
	  {
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i + 4) / 8, ((((second1 % 6) - 1) * 6) + i + 4) % 8, true); // light LEDs corresponding to 4,5 secs, then 10,11 secs, then 16,17 secs, then 22,23 secs, then 28,29 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
       lc.setLed(2, ((((second1 % 6) - 1) * 6) + i + 34) / 8, ((((second1 % 6) - 1) * 6) + i + 34) % 8, true); // light LEDs corresponding to 34,35 secs, then 40,41 secs, then 46,47 secs, then 52,53 secs, then 58,59 secs. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }

	}
	 
	}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 14


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 15
// 15) LED_MODE 15. A single lit LED representing the actual second which looks like it's advancing by one LED every second due to an animating clockwise rotating LED (over 0.2 seconds) from 0 second LED to current second LED 'hitting' (and hence 'pushing') the singly lit seconds LED to its new position

	if (LED_RING_ANIMATION == 14)  
	{
		
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2);
	 }
	 LED_MODE_1_CHANGED = false;
	 
		
	 if (second1!= 0)	
     {		 
      for (int i = 0; i <= second1; i++)
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        delay (360 / second1); // light up LEDs sequentially from the 0 sec LED to the current second LED with a short delay between
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off sequentially the just lit LED (except the last lit LED)
      }
	 }
	 
	 if (second1 == 0)
	 {
     lc.setLed(2, 59 / 8, 59 % 8, false); // turn off LED 59 which would still be lit otherwise 
     lc.setLed(2, 0 / 8, 0 % 8, true); // turn on LED 0
	 }
	 
	}		


/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 15


///////////////////////////////////////////////////////////////////////////////////////////////////////  Begin of LED_MODE 16
// 16) LED_MODE 16. All LEDs always off

	if (LED_RING_ANIMATION == 15)  
	{
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly turn off all led's, but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean
	 {
	  lc.clearDisplay(2);
	 }
	  LED_MODE_1_CHANGED = false;
	}		


/////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 16


//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////Begin of LED_MODE 17
// 17) LED_MODE 17. Showing Pressure change over previous 2 and 4 hours

// The 0 seconds LED (signifying a 0hPa pressure change for the last 2 hours) and the 30 seconds LED (signifying a 0hPa
// pressure change for the last 4 hours) are always lit. Positive pressure changes are indicated by lighting LEDS to the
// right of an imaginary vertical line joining the 0/30 seconds LEDs, each lit LED indicating a 1hPa change. Negative
// pressure changes are indicated by lighting LEDS to the left of an imaginary vertical line joining the 0/30 seconds LEDs,
// each lit LED indicating a 1hPa change.

	if (LED_RING_ANIMATION == 16)  
	{
		
     difference_2hour_holding = fabs(difference_2hour); // to find absolute value - fabs is absolute value of a float
     difference_2hour_holding = difference_2hour_holding + 0.5; // round up/down
//     difference_2hour_holding = (int)difference_2hour_holding; // float to int conversion. if this doesn't work use line below instead
     diff_2hour_holding = difference_2hour_holding; // float to int conversion.
     difference_4hour_holding = fabs(difference_4hour); // to find absolute value - fabs is absolute value of a float
     difference_4hour_holding = difference_4hour_holding + 0.5; // round up/down
//     difference_4hour_holding = (int)difference_4hour_holding; // float to int conversion. if this doesn't work use line below instead
     diff_4hour_holding = difference_4hour_holding; // float to int conversion.
	 
#if(serEn)

		  Serial.print("diff_2hour_holding: ");
          Serial.print(diff_2hour_holding);
          Serial.print("   diff_2hour_holding_old: ");	
          Serial.println(diff_2hour_holding_old);
		  Serial.print("diff_4hour_holding: ");
          Serial.print(diff_4hour_holding);
          Serial.print("   diff_4hour_holding_old: ");	
          Serial.println(diff_4hour_holding_old);
		  Serial.println();

#endif
				
	 if (LED_MODE_1_CHANGED == true || (diff_2hour_holding != diff_2hour_holding_old) || (diff_4hour_holding != diff_4hour_holding_old)) // if the LED animation mode has just been changed on the fly, or the latest 2 hour pressure difference is different to the previous 2 hour pressure difference, or the latest 4 hour pressure difference is different to the previous 4 hour pressure difference, then turn off all led's (but just once if the LED animation mode has just been changed on the fly - hence the reason for the 'LED_MODE_1_CHANGED' boolean)
	 {
	  lc.clearDisplay(2);
	 }
	  LED_MODE_1_CHANGED = false;
	
	
	 lc.setLed(2, 0 / 8, 0 % 8, true); // light 0 seconds LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
     lc.setLed(2, 30 / 8, 30 % 8, true); // light 30 seconds LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
 
 

   if(pressure_counter > 12) { // if 2 hours or more have elapsed since power-up then display the pressure change over the last 2 hours on the seconds ring, starting at the zero seconds LED position
	
	 if (difference_2hour >= 0.0)	
     {		 
      for (int i = 0; i <= diff_2hour_holding; i++) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }
	 
	 if ((difference_2hour < 0.0) && (diff_2hour_holding >= 1))	
     {		 
      for (int i = 59; i >= 60 - diff_2hour_holding; i--) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }

	      }
     diff_2hour_holding_old = diff_2hour_holding;
	 

	 
	 
   if(pressure_counter > 24) { // if 4 hours or more have elapsed since power-up then display the pressure change over the last 4 hours on the seconds ring, starting at the 30 seconds LED position

	 if ((difference_4hour > 0.0) && (diff_4hour_holding >= 1))	
     {		 
      for (int i = 29; i >= 30 - diff_4hour_holding; i--) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }
	 
	 if (difference_4hour < 0.0)	
     {		 
      for (int i = 30; i <= 30 + diff_4hour_holding; i++) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }

	      }
     diff_4hour_holding_old = diff_4hour_holding;
	 
 	 
	        }
	
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 17


//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////Begin of LED_MODE 18
// 18) LED_MODE 18. Showing an alternating pressure change over previous 2 and 4 hours, followed by the actual seconds which is represented by lighting LED's sequentially from zero to current second

// Whilst displaying the pressure changes, the 0 seconds LED (signifying a 0hPa pressure change for the last 2 hours) and
// the 30 seconds LED (signifying a 0hPa pressure change for the last 4 hours) are always lit. Positive pressure changes
// are indicated by lighting LEDS to the right of an imaginary vertical line joining the 0/30 seconds LEDs, each lit LED
// indicating a 1hPa change. Negative pressure changes are indicated by lighting LEDS to the left of an imaginary
// vertical line joining the 0/30 seconds LEDs, each lit LED indicating a 1hPa change.

	if (LED_RING_ANIMATION == 17)  
	{
		
	 if (LED_MODE_1_CHANGED == true) // if the LED animation mode has just been changed on the fly then turn off all led's (but just once - hence the reason for the 'LED_MODE_1_CHANGED' boolean)
	 {
	  lc.clearDisplay(2);
	 }	
	  
		
	 if ((second1 >= 0 && second1 <= 5) || (second1 >= 10 && second1 <= 15) || (second1 >= 20 && second1 <= 25) || (second1 >= 30 && second1 <= 35) || (second1 >= 40 && second1 <= 45) || (second1 >= 50 && second1 <= 55)) // at 0, 10, 20, 30, 40, 50 seconds display the seconds on the outer seconds ring for 6 seconds
	 {
	  if (second1 % 10 == 0) lc.clearDisplay(2); // clear display at 0, 10, 20, 30, 40, 50 secs
	    if (press_auto_cycle == false) // only show a single seconds ring animation when displaying the actual seconds (as opposed to cycling through a variety of seconds animations)
		{
	  
	  
//CHOOSE WHICH TIME SECONDS RING ANIMATION YOU WANT BY UNCOMMENTING ONE OF THE FOLLOWING ANIMATIONS:

//-------------------------------------------------------------------------------------------	  
	  
/*	  
// Start of animation 1. light LEDs from 0 secs to current second (same as animation as LED_RING_ANIMATION == 0) 	  
      for (int i = 0; i <= second1; i++)
      {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  }
// End of animation 1. light LEDs from 0 secs to current second (same as animation as LED_RING_ANIMATION == 0) 
*/	  

//-----------------------------------------------------------------------------------------

/*
// Start of animation 2. A single lit LED representing the actual second which looks like it's advancing by one LED every second due to an animating clockwise rotating LED (over 0.2 seconds) from 0 second LED to current second LED 'hitting' (and hence 'pushing') the singly lit seconds LED to its new position. (same as animation as LED_RING_ANIMATION == 14)
	 if (second1!= 0)	
     {		 
      for (int i = 0; i <= second1; i++)
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        delay (360 / second1); // light up LEDs sequentially from the 0 sec LED to the current second LED with a short delay between
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off sequentially the just lit LED (except the last lit LED)
      }
	 }
	 
	 if (second1 == 0)
	 {
     lc.setLed(2, 0 / 8, 0 % 8, true); // turn on LED 0
	 }	
// End of animation 2. A single lit LED representing the actual second which looks like it's advancing by one LED every second due to an animating clockwise rotating LED (over 0.2 seconds) from 0 second LED to current second LED 'hitting' (and hence 'pushing') the singly lit seconds LED to its new position. (same as animation as LED_RING_ANIMATION == 14)
*/	  	  

//---------------------------------------------------------------------------------------------

		  
// Start of animation 3. Animating anticlockwise seconds LED over 0.2 seconds from 59 second LED to current second LED. (Same as animation LED_RING_ANIMATION == 2).
	if (second1 % 10 == 0 || LED_MODE_1_CHANGED == true || just_powered_up == true) {
	  for (int i = 0; i <= second1; i++)
	   {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	   }
	  }
	
	just_powered_up = false;
	
    if (second1 % 10 != 0) {
      for (int i = 59; i >= second1; i--)
      {
		lc.setLed(2, i / 8, i % 8, true); // Light LEDs sequentially anticlockwise from the 59th second LED to the current second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		delay(360/(60 - second1)); // was 'delay(200/(60 - second1))'. If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off lit LED during animation sequence except when current second LED is now lit
	  }
	}
// End of animation 3. Animating anticlockwise seconds LED over 0.2 seconds from 59 second LED to current second LED. (Same as animation LED_RING_ANIMATION == 2).


//-----------------------------------------------------------------------------------------------

/*
// Start of animation 4. Light single LED at current second. (Same as animation LED_RING_ANIMATION == 1).
      for (int i = 0; i <= second1-1; i++)  // turn off LED's from zero to one less than current second, (do not turn off LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
      {
        lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	  
	  
      // turn on one led, to indicate the current second
      lc.setLed(2, (second1) / 8, (second1) % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
// End of animation 4. Light single LED at current second. (Same as animation LED_RING_ANIMATION == 1).
*/
		  
//-----------------------------------------------------------------------------------------------------		

/*
// Start of animation 5. Inverse of single LED lit at current second. (Same as animation LED_RING_ANIMATION == 3).
        if (LED_MODE_1_CHANGED == true || second1 % 10 == 0 || just_powered_up == true) { 
		  for (int i = 0; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}

		just_powered_up = false;
	
	    // At 0 seconds only, turn on LED representing 59 seconds, which is not lit as a consequence of the 'for (int i = 0; i <= (second1-1); i++)' line below
		if (second1 == 0) lc.setLed(2, 7, 3, true); // Turn on final 59 second LED which is left lit at 0 seconds because of 'for (int i = 0; i <= second1-1; i++)' line above. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off	
		
        // light LED's from zero to current second minus one (do not light LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
        for (int i = 0; i <= (second1-1); i++)
        {
          lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  
        // turn off one led at current second to indicate the current second
        lc.setLed(2, second1 / 8, second1 % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
// End of animation 5. Inverse of single LED lit at current second. (Same as animation LED_RING_ANIMATION == 3)..
*/

//-----------------------------------------------------------------------------------------------------

/*
// Start of animation 6. Similar to LED mode 3, but this time throwing away seconds over a 0.3 sec duration towards the 0 secs LED. (Same as animation LED_RING_ANIMATION == 6) 
		
	  // turn all LED ring LED's on but just once, at 0 secs, or if the LED ring animation mode has been changed
        if (second1 == 0 || LED_MODE_1_CHANGED == true || second1 % 10 == 0 || just_powered_up == true) {
//		  for (byte i = 0; i <= 59; i++) // original
		  for (byte i = second1; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}

		just_powered_up == false;	    
		
		if (second1 == 1)
		{
		 lc.setLed(2, 0, 1, false);	// just turn 1 sec LED off
	    }
		
		
		 lc.setLed(2, 0, 0, true);	// turn 0 sec LED on - it should always be on in this animation					
	
	
	     if (second1!= 0 && second1 != 1) // without this all the lit LEDS at zero seconds from the 'if' statement above will be erased again as at zero seconds 'for (byte j = (second1 - 1); j > 0; j--)' actually cycles through 'j' from 255 to 1
	     {
	      for (byte j = second1; j > 0; j--)
            {
              lc.setLed(2, j / 8, j % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
//   CHOOSE EITHER ONE OF THE 2 'delay...' LINES DIRECTLY BELOW THIS LINE
//		      delay(6); //6 makes total animation time of 0.3 secs
		      delay(360 / second1); //  If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
              lc.setLed(2, j / 8, j % 8, false); // unlight LEDs sequentially from the seconds minus one LED to Zero secs LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off

		    }			
	     }
							
// End of animation 6. Similar to LED mode 3, but this time throwing away seconds over a 0.3 sec duration towards the 0 secs LED. (Same as animation LED_RING_ANIMATION == 6) 
*/

//------------------------------------------------------------------------------------------------------

	 }
	 
	 
	    if (press_auto_cycle == true) //  Cycle through 6 seconds ring animations every 10 mins
		{


	  if (minut1/10 == 0)
	  {
//		  if (min_0s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 1. light LEDs from 0 secs to current second (same as animation as LED_RING_ANIMATION == 0) 	  
      for (int i = 0; i <= second1; i++)
      {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	  }
// End of animation 1. light LEDs from 0 secs to current second (same as animation as LED_RING_ANIMATION == 0) 		  
		  		  
      min_0s = false;
      min_10s = true;
	  }


	  
	  if (minut1/10 == 1)
	  {
//		  if (min_10s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 2. A single lit LED representing the actual second which looks like it's advancing by one LED every second due to an animating clockwise rotating LED (over 0.2 seconds) from 0 second LED to current second LED 'hitting' (and hence 'pushing') the singly lit seconds LED to its new position. (same as animation as LED_RING_ANIMATION == 14)
	 if (second1!= 0)	
     {		 
      for (int i = 0; i <= second1; i++)
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        delay (360 / second1); // light up LEDs sequentially from the 0 sec LED to the current second LED with a short delay between
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off sequentially the just lit LED (except the last lit LED)
      }
	 }
	 
	 if (second1 == 0)
	 {
     lc.setLed(2, 0 / 8, 0 % 8, true); // turn on LED 0
	 }	
// End of animation 2. A single lit LED representing the actual second which looks like it's advancing by one LED every second due to an animating clockwise rotating LED (over 0.2 seconds) from 0 second LED to current second LED 'hitting' (and hence 'pushing') the singly lit seconds LED to its new position. (same as animation as LED_RING_ANIMATION == 14)
	  		  
      min_10s = false;
      min_20s = true;
	  }


	  
	  if (minut1/10 == 2)
	  {
//		  if (min_20s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 3. Animating anticlockwise seconds LED over 0.2 seconds from 59 second LED to current second LED. (Same as animation LED_RING_ANIMATION == 2).
	if (second1 % 10 == 0 || LED_MODE_1_CHANGED == true || just_powered_up == true) {
	  for (int i = 0; i <= second1; i++)
	   {
       lc.setLed(2, i / 8, i % 8, true); // light LEDs from 0 secs to current second. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
	   }
	  }
	  
		just_powered_up = false;
	  
    if (second1 % 10 != 0) {
      for (int i = 59; i >= second1; i--)
      {
		lc.setLed(2, i / 8, i % 8, true); // Light LEDs sequentially anticlockwise from the 59th second LED to the current second LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		delay(360/(60 - second1)); // was 'delay(200/(60 - second1))'. If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
		if (i != second1) lc.setLed(2, i / 8, i % 8, false); // turn off lit LED during animation sequence except when current second LED is now lit
	  }
	}
// End of animation 3. Animating anticlockwise seconds LED over 0.2 seconds from 59 second LED to current second LED. (Same as animation LED_RING_ANIMATION == 2).
		  		  
      min_20s = false;
      min_30s = true;
	  }
	

	
	  if (minut1/10 == 3)
	  {
//		  if (min_30s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 4. Light single LED at current second. (Same as animation LED_RING_ANIMATION == 1).
      for (int i = 0; i <= second1-1; i++)  // turn off LED's from zero to one less than current second, (do not turn off LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
      {
        lc.setLed(2, i / 8, i % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	  
	  
      // turn on one led, to indicate the current second
      lc.setLed(2, (second1) / 8, (second1) % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
// End of animation 4. Light single LED at current second. (Same as animation LED_RING_ANIMATION == 1).
	  		  
      min_30s = false;
      min_40s = true;
	  }
	 

	 
	  if (minut1/10 == 4)
	  {
//		  if (min_40s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 5. Inverse of single LED lit at current second. (Same as animation LED_RING_ANIMATION == 3).
        if (LED_MODE_1_CHANGED == true || second1 % 10 == 0 || just_powered_up == true) { 
		  for (int i = 0; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}

		just_powered_up = false;
	
	    // At 0 seconds only, turn on LED representing 59 seconds, which is not lit as a consequence of the 'for (int i = 0; i <= (second1-1); i++)' line below
		if (second1 == 0) lc.setLed(2, 7, 3, true); // Turn on final 59 second LED which is left lit at 0 seconds because of 'for (int i = 0; i <= second1-1; i++)' line above. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off	
		
        // light LED's from zero to current second minus one (do not light LEDs from zero to current second otherwise the current second LED will be constantly flickering due to being turned on and off many times per second)
        for (int i = 0; i <= (second1-1); i++)
        {
          lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
        }
	  
        // turn off one led at current second to indicate the current second
        lc.setLed(2, second1 / 8, second1 % 8, false); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
// End of animation 5. Inverse of single LED lit at current second. (Same as animation LED_RING_ANIMATION == 3).
	  		  
      min_40s = false;
      min_50s = true;
	  }
	 

	 
	  if (minut1/10 == 5)
	  {
//		  if (min_50s == true)
//		  {
//			 LED_MODE_1_CHANGED = true;
//		  }
		  
// Start of animation 6. Similar to LED mode 3, but this time throwing away seconds over a 0.3 sec duration towards the 0 secs LED. (Same as animation LED_RING_ANIMATION == 6) 		
	  // turn all LED ring LED's on but just once, at 0 secs, or if the LED ring animation mode has been changed
	  
	  
/*	  // original
        if (second1 == 0 || LED_MODE_1_CHANGED == true || second1 % 10 == 0) {
		  for (byte i = 0; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}
*/

        if (second1 == 0 || LED_MODE_1_CHANGED == true || second1 % 10 == 0 || just_powered_up == true) {
		  for (byte i = second1; i <= 59; i++)
          {
           lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
          }
		}		

		just_powered_up == false;		
			
		lc.setLed(2, 0, 0, true);	// turn 0 sec LED on - it should always be on in this animation	    
		
		if (second1 == 1)
		{
		 lc.setLed(2, 0, 1, false);	// just turn 1 sec LED off
	    }
		
			
	
	     if (second1!= 0 && second1 != 1) // without this all the lit LEDS at zero seconds from the 'if' statement above will be erased again as at zero seconds 'for (byte j = (second1 - 1); j > 0; j--)' actually cycles through 'j' from 255 to 1
	     {
	      for (byte j = second1; j > 0; j--)
            {
              lc.setLed(2, j / 8, j % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
//   CHOOSE EITHER ONE OF THE 2 'delay...' LINES DIRECTLY BELOW THIS LINE
//		      delay(6); //6 makes total animation time of 0.3 secs
		      delay(360 / second1); //  If problems are seen with this new 360 numerator (particularly at the seconds when the temperature ds18B20 sensor reading is being taken-which takes about 700msec, or when the date scrolling is happening-which takes about 600msec), then try changing to 342 instead. NOTE, the shorter the delay time here the lower the LED brightness - hence the reason to maximise the delay time, but still such that the total delay time lighting 60 LEDs (in this 'for' loop) plus any other long delays (eg the ds18b20 read time) is less than 1000 msecs, which would otherwise cause the LED ring to no longer refresh every 1000 msecs and look weird. Trying to have a roughly uniform 0.2 seconds sequentially LED lit animation length regardless of how many LEDs are being lit (ie, regardless of the current second number)
              lc.setLed(2, j / 8, j % 8, false); // unlight LEDs sequentially from the seconds minus one LED to Zero secs LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off

		    }			
	     }
// End of animation 6. Similar to LED mode 3, but this time throwing away seconds over a 0.3 sec duration towards the 0 secs LED. (Same as animation LED_RING_ANIMATION == 6) 
	  		  
      min_50s = false;
      min_0s = true;
	  }
		}		
	     }
  	  LED_MODE_1_CHANGED = false;



	 
	 if ((second1 >= 6 && second1 < 10) || (second1 >= 16 && second1 < 20) || (second1 >= 26 && second1 < 30) || (second1 >= 36 && second1 < 40) || (second1 >= 46 && second1 < 50) || (second1 >= 56 && second1 <= 59)) // at 6, 16, 26, 36, 46, 56 seconds display the previous 2hr and 4hr pressure trends on the outer seconds ring in an identical way to the previous LED_RING_ANIMATION mode for 4 seconds
	 {
     difference_2hour_holding = fabs(difference_2hour); // to find absolute value - fabs is absolute value of a float
     difference_2hour_holding = difference_2hour_holding + 0.5; // round up/down
//     difference_2hour_holding = (int)difference_2hour_holding; // float to int conversion. if this doesn't work use line below instead
     diff_2hour_holding = difference_2hour_holding; // float to int conversion.
     difference_4hour_holding = fabs(difference_4hour); // to find absolute value - fabs is absolute value of a float
     difference_4hour_holding = difference_4hour_holding + 0.5; // round up/down
//     difference_4hour_holding = (int)difference_4hour_holding; // float to int conversion. if this doesn't work use line below instead
     diff_4hour_holding = difference_4hour_holding; // float to int conversion.
	 
#if(serEn)

		  Serial.print("diff_2hour_holding: ");
          Serial.print(diff_2hour_holding);
          Serial.print("   diff_2hour_holding_old: ");	
          Serial.println(diff_2hour_holding_old);
		  Serial.print("diff_4hour_holding: ");
          Serial.print(diff_4hour_holding);
          Serial.print("   diff_4hour_holding_old: ");	
          Serial.println(diff_4hour_holding_old);
		  Serial.println();

#endif


	 if ((diff_2hour_holding != diff_2hour_holding_old) || (diff_4hour_holding != diff_4hour_holding_old) || (second1 % 10 == 6)) // if the latest 2 hour pressure difference is different to the previous 2 hour pressure difference, or the latest 4 hour pressure difference is different to the previous 4 hour pressure difference, or at 6secs or 16secs or 26secs or 36secs or 46secs or 56secs, then turn off all led's
	 {
	  lc.clearDisplay(2);
	 }				
	
	 lc.setLed(2, 0 / 8, 0 % 8, true); // light 0 seconds LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
     lc.setLed(2, 30 / 8, 30 % 8, true); // light 30 seconds LED. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
 
 

   if(pressure_counter > 12) { // if 2 hours or more have elapsed since power-up then display the pressure change over the last 2 hours on the seconds ring, starting at the zero seconds LED position
	
	 if (difference_2hour >= 0.0)	
     {		 
      for (int i = 0; i <= diff_2hour_holding; i++) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }
	 
	 if ((difference_2hour < 0.0) && (diff_2hour_holding >= 1))	
     {		 
      for (int i = 59; i >= 60 - diff_2hour_holding; i--) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }

	      }
     diff_2hour_holding_old = diff_2hour_holding;
	 
	 

	 
	 
   if(pressure_counter > 24) { // if 4 hours or more have elapsed since power-up then display the pressure change over the last 4 hours on the seconds ring, starting at the 30 seconds LED position

	 if ((difference_4hour > 0.0) && (diff_4hour_holding >= 1))	
     {		 
      for (int i = 29; i >= 30 - diff_4hour_holding; i--) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }
	 
	 if (difference_4hour < 0.0)	
     {		 
      for (int i = 30; i <= 30 + diff_4hour_holding; i++) 
      {
        lc.setLed(2, i / 8, i % 8, true); // arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
      }
	   }

	      }
     diff_4hour_holding_old = diff_4hour_holding;
	       
	 }
	 
	}
	 

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////End of LED_MODE 18


/*
  Serial.print(zo);
  Serial.print(uo);
  Serial.print("-");
  Serial.print(zm);
  Serial.print(um);
  Serial.print("-");
  Serial.print(zs);
  Serial.print(us);
  Serial.println("  end");
*/

//    old_secs = second1; //reset old_secs for comparison next time with current seconds value - WAS HERE AND PROBABLY IN WRONG POSITION - so now moving to outside of 'if (second1 != old_secs)'
	
//	if (second1 == 59) zzz = 0; // was here
//	if (second1 == 59) nnn = 0; // was here

 } // end of 'if (time_display_mode != 11)'


  } // end of 'if (second1 != old_secs)', ie, in English: end of 'if seconds have changed value

    old_secs = second1; //reset old_secs for comparison next time with current seconds value
	
	if (second1 == 59) zzz = 0;
	if (second1 == 59) nnn = 0;

}


//////////////////////////////////////////////////////////////////////////////////////////
/*
// ging - date with '15 May' format - CHOOSE THIS OR ONE OF THE 3 OTHER DATE VARIATIONS BELOW
void data_2b (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
	
if (fff == 0) { // counter variable to limit static date display ('15 May' format) to one display update as opposed to multiple display updates throughout the full second of the 'if (second0 == 9 || second0 == 19 || second0 == 29 || second0 == 39....' statement that defines when the static date is displayed	
	
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,7,B00000000);  // afisez o liniuta pe coloana 5, display a blank character on column 7. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,6,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 6 (on the left)
lc.setDigit(1,5,uz, false); // afisez unitatile de ore pe coloana 6, display the units of days on column 5
lc.setRow(1,4,B00000000);  // afisez o liniuta pe coloana 5, display a blank character on column 4. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//Month Name
if (luna1 == 1) { // display 'Jan'
  lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 2) { // display 'Feb'
  lc.setRow(1,3,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B00011111);	// displays the character 'B'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 3) { // display 'Mar'
  lc.setRow(1,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
  
if (luna1 == 4) { // display 'Apr'
  lc.setRow(1,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 5) { // display 'May'
  lc.setRow(1,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00111011);	// displays the character 'Y'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
  
if (luna1 == 6) { // display 'Jun'
  lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 7) { // display 'Jul'
  lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B00001110);	// displays the character 'l'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }

if (luna1 == 8) { // display 'Aug'
  lc.setRow(1,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,1,B01111011);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01011110);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 9) { // display 'Sep'
  lc.setRow(1,3,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 10) { // display 'Oct'
  lc.setRow(1,3,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,2,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B00001101);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 if (luna1 == 11) { // display 'Nov'
  lc.setRow(1,3,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 if (luna1 == 12) { // display 'Dec'
  lc.setRow(1,3,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,1,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }

//  Serial.println("displaying '15 May' format");

}

  fff = fff + 1;
  if (fff >= 1) fff = 1;

ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed
}
*/
////////////////////////////////////////////////////////////////////////////////////////

// ging - date with 'Wed 15 May' format spread over 1x 8-digit, and 1x 4-digit display
void data_3 (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// Day of week (sunday is 0, saturday is 6)

// NOTE for reference, instead of writing:    lc.setRow(1,4,B01110110);	// displays the character 'N'.
// this will also do exactly the same:        lc.setRow(1,4,118);	// displays the character 'N'  (118 is the decimal version of the binary number 01110110)

if (xxx == 0) { // counter variable to limit static date display ('Mon 15' format) to one display update as opposed to multiple display updates throughout the full second of the 'if (second0 == 6 || second0 == 16 || second0 == 26 || second0 == 36....' statement that defines when the static date is displayed	

if (dow1 == 0) { // display 'Sun'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,5,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
  lc.setRow(1,5,B00011101);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00010101);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

 }
 
if (dow1 == 2) { // display 'Tue'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,3,B00000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,2,zz, false); // display the tens of days on column 2 
lc.setDigit(1,1,uz, false); // display the units of days on column 1
lc.setRow(1,0,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//  Serial.println("displaying 'Mon 15' format");

//Month Name
if (luna1 == 1) { // display 'Jan'
  lc.setRow(3,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 2) { // display 'Feb'
  lc.setRow(3,3,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B00011111);	// displays the character 'B'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 3) { // display 'Mar'
  lc.setRow(3,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
  
if (luna1 == 4) { // display 'Apr'
  lc.setRow(3,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 5) { // display 'May'
  lc.setRow(3,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00111011);	// displays the character 'Y'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  }
  
if (luna1 == 6) { // display 'Jun'
  lc.setRow(3,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 7) { // display 'Jul'
  lc.setRow(3,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B00001110);	// displays the character 'l'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }

if (luna1 == 8) { // display 'Aug'
  lc.setRow(3,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(3,1,B01111011);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01011110);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 9) { // display 'Sep'
  lc.setRow(3,3,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (luna1 == 10) { // display 'Oct'
  lc.setRow(3,3,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(3,2,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B00001101);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 if (luna1 == 11) { // display 'Nov'
  lc.setRow(3,3,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 if (luna1 == 12) { // display 'Dec'
  lc.setRow(3,3,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,1,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(3,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }


}

  xxx = xxx + 1;
  if (xxx >= 1) xxx = 1;

//ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}

////////////////////////////////////////////////////////////////////////////////////////

/*
void data_scrolling (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week). scrolls from 'Wed 23' format to '23 May' format
{
	
if (hhh == 0) { // counter variable to limit scrolling date display to one pass as opposed to multiple passes throughout the full second of the 'if (second0 == 6 || second0 == 12 || second0 == 18 || second0 == 24....' statement that defines when the scrolling date is displayed
	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////

if (dow1 == 0) { // display 'Sun'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
//  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,6,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,5,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
  lc.setRow(1,6,B00011101);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00010101);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

 }
 
if (dow1 == 2) { // display 'Tue'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
//  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,4,B00000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,3,zz, false); // display the tens of days on column 2 
lc.setDigit(1,2,uz, false); // display the units of days on column 1
lc.setRow(1,1,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//Month Name
if (luna1 == 1) lc.setRow(1,0,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,0,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,0,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,0,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,0,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,0,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,0,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,0,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,0,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,0,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,0,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,0,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }


delay(200);

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

if (dow1 == 0) { // display 'Sun'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
//  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,6,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
  lc.setRow(1,7,B00011101);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00010101);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

 }
 
if (dow1 == 2) { // display 'Tue'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
//  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
//int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
//int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,5,B00000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,4,zz, false); // display the tens of days on column 2 
lc.setDigit(1,3,uz, false); // display the units of days on column 1
lc.setRow(1,2,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//Month Name
if (luna1 == 1) lc.setRow(1,1,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,1,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,1,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,1,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,1,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,1,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,1,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,1,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,1,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 1) lc.setRow(1,0,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,0,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,0,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,0,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,0,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,0,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,0,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,0,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,0,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//if (luna1 == 10) lc.setRow(1,0,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,0,B00001101);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,0,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,0,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }


delay(200);
	
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

if (dow1 == 0) { // display 'Sun'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
//  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
  lc.setRow(1,7,B00010101);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

 }
 
if (dow1 == 2) { // display 'Tue'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
//  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,7,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
// ziua (day)
//int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
//int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,6,B00000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,5,zz, false); // display the tens of days on column 2 
lc.setDigit(1,4,uz, false); // display the units of days on column 1
lc.setRow(1,3,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//Month Name
if (luna1 == 1) lc.setRow(1,2,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,2,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,2,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,2,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,2,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,2,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,2,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,2,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,2,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,2,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,2,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,2,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 1) lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,1,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,1,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,1,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,1,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,1,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//if (luna1 == 10) lc.setRow(1,1,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,1,B00001101);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,1,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,1,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 1) lc.setRow(1,0,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,0,B00011111);	// displays the character 'B'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,0,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,0,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,0,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,0,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,0,B00001110);	// displays the character 'L'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//if (luna1 == 8) lc.setRow(1,0,B01111011);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,0,B01011110);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,0,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,0,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,0,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,0,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

delay(200);

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

lc.setRow(1,7,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 
 
// ziua (day)
//int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
//int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
//lc.setRow(1,6,B0000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,6,zz, false); // display the tens of days on column 2 
lc.setDigit(1,5,uz, false); // display the units of days on column 1
lc.setRow(1,4,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//Month Name
if (luna1 == 1) lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,3,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,3,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,3,B00111000);	// displays the character 'J'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,3,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,3,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,3,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,3,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,3,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 1) lc.setRow(1,2,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,2,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,2,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,2,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//if (luna1 == 10) lc.setRow(1,2,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,2,B00001101);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,2,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,2,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 1) lc.setRow(1,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 2) lc.setRow(1,1,B00011111);	// displays the character 'B'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 3) lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 4) lc.setRow(1,1,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,1,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 6) lc.setRow(1,1,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 7) lc.setRow(1,1,B00001110);	// displays the character 'l'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//if (luna1 == 8) lc.setRow(1,1,B01111011);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 8) lc.setRow(1,1,B01011110);	// displays the character 'G'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 9) lc.setRow(1,1,B01100111);	// displays the character 'P'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 10) lc.setRow(1,1,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 11) lc.setRow(1,1,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 12) lc.setRow(1,1,B01001110);	// displays the character 'C'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

if (luna1 == 3) lc.setRow(1,0,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
if (luna1 == 5) lc.setRow(1,0,B00111011);	// displays the character 'Y'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }


if (!(luna1 == 3 || luna1 == 5))  lc.setRow(1,0,B00000000);	// displays blank character. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

//delay(200);

}

  hhh = hhh + 1;
  if (hhh >= 1) hhh = 1;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	
ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed
	
}
*/
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
/*
// ging - date with 'Mon 15' format - CHOOSE THIS OR ONE OF THE OTHER 3 DATE VARIATIONS (1 ABOVE, 2 BELOW)
void data_2a (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// Day of week (sunday is 0, saturday is 6)

// NOTE for reference, instead of writing:    lc.setRow(1,4,B01110110);	// displays the character 'N'.
// this will also do exactly the same:        lc.setRow(1,4,118);	// displays the character 'N'  (118 is the decimal version of the binary number 01110110)

if (xxx == 0) { // counter variable to limit static date display ('Mon 15' format) to one display update as opposed to multiple display updates throughout the full second of the 'if (second0 == 6 || second0 == 16 || second0 == 26 || second0 == 36....' statement that defines when the static date is displayed	

if (dow1 == 0) { // display 'Sun'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,5,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
  lc.setRow(1,5,B00011101);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00010101);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 

 }
 
if (dow1 == 2) { // display 'Tue'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,4,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,3,B00000000);  // display a blank character on column 3. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,2,zz, false); // display the tens of days on column 2 
lc.setDigit(1,1,uz, false); // display the units of days on column 1
lc.setRow(1,0,B00000000);  // display a blank character on column 0. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

//  Serial.println("displaying 'Mon 15' format");

}

  xxx = xxx + 1;
  if (xxx >= 1) xxx = 1;

ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}
*/


/*
// ging - date with 'We 15.10' format (for Wednesday 15 Oct) - CHOOSE THIS OR ONE OF THE OTHER STATIC DATE VARIATIONS
void data (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// Day of week (sunday is 0, saturday is 6)

// NOTE for reference, instead of writing:    lc.setRow(1,4,B01110110);	// displays the character 'N'.
// this will also do exactly the same:        lc.setRow(1,4,118);	// displays the character 'N'  (118 is the decimal version of the binary number 01110110)

if (dow1 == 0) { // display 'Sun'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01111110);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 2) { // display 'Tue'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setRow(1,4,B00000000);  // display a blank character on column 4. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,3,zz, false); // display the tens of days on column 2 
lc.setDigit(1,2,uz, true); // display the units of days on column 1

// luna (month)
int zl = int(luna1/10); // determin cifra zecilor, determine the number of month tens
int ul = luna1 - 10*zl; // determin cifra unitatilor, determine the number of month units
lc.setDigit(1,1,zl, false); // afisez zecile de minute pe coloana 5, display the month tens on column 4
lc.setDigit(1,0,ul, false); // afisez unitatile de minute pe coloana 4, display the month units on column 3



ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}
*/


/*
// ging - date with 'WE 15-10' format (for Wednesday 15 Oct) - note, Wednesday and Monday alone have no gap between day name and day number as 'w' and 'm' take up 2 digits (ie, WE15-10, Mo08-10, Su 08-10). CHOOSE THIS OR ONE OF THE OTHER STATIC DATE VARIATIONS
void data (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// Day of week (sunday is 0, saturday is 6)

// NOTE for reference, instead of writing:    lc.setRow(1,4,B01110110);	// displays the character 'N'.
// this will also do exactly the same:        lc.setRow(1,4,118);	// displays the character 'N'  (118 is the decimal version of the binary number 01110110)

if (dow1 == 0) { // display 'Sun'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B0000000);  // display a blank character on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 1) { // display 'Mon'
  lc.setRow(1,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B00011101);	// displays the character 'O'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01110110);	// displays the character 'N'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 2) { // display 'Tue'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B0000000);  // display a blank character on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 3) { // display 'Wed'
  lc.setRow(1,7,B00011110);	// displays the left half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00111100);	// displays the right half of the character 'W' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B01001111);	// displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00111101);	// displays the character 'D'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 4) { // display 'Thu'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00010111);	// displays the character 'H'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B0000000);  // display a blank character on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00111110);	// displays the character 'U'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 5) { // display 'Fri'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01000111);	// displays the character 'F'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B00000101);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B0000000);  // display a blank character on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000100);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
//  lc.setRow(1,5,B01000110);	// displays the character 'R'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00000110);	// displays the character 'I'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
if (dow1 == 6) { // display 'Sat'
//  lc.setRow(1,7,B00000000);	// displays blank character'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,7,B01011011);	// displays the character 'S'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,6,B01110111);	// displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(1,5,B0000000);  // display a blank character on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(1,4,B00001111);	// displays the character 'T'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) } 
 }
 
 
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(0,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
//lc.setRow(1,4,B00000000);  // display a blank character on column 4. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setDigit(1,4,zz, false); // display the tens of days on column 2 
lc.setDigit(1,3,uz, false); // display the units of days on column 1

lc.setRow(1,2,B00000001);	// displays a hyphen. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

// luna (month)
int zl = int(luna1/10); // determin cifra zecilor, determine the number of month tens
int ul = luna1 - 10*zl; // determin cifra unitatilor, determine the number of month units
lc.setDigit(1,1,zl, false); // afisez zecile de minute pe coloana 5, display the month tens on column 4
lc.setDigit(1,0,ul, false); // afisez unitatile de minute pe coloana 4, display the month units on column 3



ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}
*/



/*
// ging - date with '15-11-22' format - CHOOSE THIS OR ONE OF THE OTHER 3 DATE VARIATIONS (2 ABOVE AND 1 BELOW)
void data (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of day tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of day units
//if (zz >= 1) lc.setDigit(1,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setDigit(1,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of days on column 7 (on the left)
lc.setDigit(1,6,uz, false); // afisez unitatile de ore pe coloana 6, display the units of days on column 6
lc.setRow(1,5,B00000001);  // afisez o liniuta pe coloana 5, display a hyphen on column 5. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

// luna (month)
int zl = int(luna1/10); // determin cifra zecilor, determine the number of month tens
int ul = luna1 - 10*zl; // determin cifra unitatilor, determine the number of month units
lc.setDigit(1,4,zl, false); // afisez zecile de minute pe coloana 5, display the month tens on column 4
lc.setDigit(1,3,ul, false); // afisez unitatile de minute pe coloana 4, display the month units on column 3
lc.setRow(1,2,B00000001);  // afisez o liniuta pe coloana 2, display a hyphen on column 2. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

// anul (year)
int ma = int(anul1/1000); // determin cifra miilor, determine the number of year thousands
int rsa = anul1 - 1000*ma; // determin restul sutelor, determine the remaining year hundreds
int sa = int(rsa/100); // determin cifra sutelor, determine the figure of year hundreds
int rza = rsa - 100*sa; // determin restul zecilor, determine the remaining year tens
int za = int(rza/10); // determin cifra zecilor, determine the number of year tens
int ua = rza - 10*za; // determin cifra anilor, determine the number of year units

//lc.setDigit(1,3,ma, false); // afisez zecile de secunde pe coloana 3, display the thousands of year on column 3
//lc.setDigit(1,2,sa, false); // afisez unitatile de minute pe coloana 2, display the hundreds of year on column 2
lc.setDigit(1,1,za, false); // afisez zecile de secunde pe coloana 1, display tens of year on column 1
lc.setDigit(1,0,ua, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the year units on column 0 (right)

ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}
*/



/*
// Original date with '15.11.2022' format - CHOOSE THIS OR ONE OF THE OTHER 3 DATE VARIATIONS ABOVE
void data (int ziua1, int luna1, int anul1, int dow1) // date (day, month, year, day of week)
{
// ziua (day)
int zz = int(ziua1/10); // determin cifra zecilor, determine the number of tens
int uz = ziua1 - 10*zz; // determin cifra unitatilor, determine the number of units
if (zz >= 1) lc.setDigit(1,7,zz, false); // afisez zecile de ore pe coloana 7 (in stanga), display the tens of hours on column 7 (on the left)
lc.setDigit(1,6,uz, true); // afisez unitatile de ore pe coloana 6, display the units of hours on column 6
//lc.setRow(1,5,B00000001);  // afisez o liniuta pe coloana 5, display a line on column 5

// luna (month)
int zl = int(luna1/10); // determin cifra zecilor, determine the number of tens
int ul = luna1 - 10*zl; // determin cifra unitatilor, determine the number of units
lc.setDigit(1,5,zl, false); // afisez zecile de minute pe coloana 5, display the tens of minutes on column 5
lc.setDigit(1,4,ul, true); // afisez unitatile de minute pe coloana 4, display the minute units on column 4
//lc.setRow(1,2,B00000001);  // afisez o liniuta pe coloana 2, display a line on column 2

// anul (year)
int ma = int(anul1/1000); // determin cifra miilor, determine the number of thousands
int rsa = anul1 - 1000*ma; // determin restul sutelor, determine the remaining hundreds
int sa = int(rsa/100); // determin cifra sutelor, determine the figure of hundreds
int rza = rsa - 100*sa; // determin restul zecilor, determine the remaining tens
int za = int(rza/10); // determin cifra zecilor, determine the number of tens
int ua = rza - 10*za; // determin cifra anilor, determine the number of years

lc.setDigit(1,3,ma, false); // afisez zecile de secunde pe coloana 3, display the thousands of year on column 3
lc.setDigit(1,2,sa, false); // afisez unitatile de minute pe coloana 2, display the hundreds of year on column 2
lc.setDigit(1,1,za, false); // afisez zecile de secunde pe coloana 1, display tens of year on column 1
lc.setDigit(1,0,ua, false); // afisez unitatile de minute pe coloana 0 (dreapta), display the year units on column 0 (right)

ggg = 0; // counter variable (used in 'void temperatura' subroutine) reset to zero to limit temperature display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the temperature is displayed
ttt = 0; // counter variable (used in 'void umiditate' subroutine) reset to zero to limit humidity display to one update as opposed to multiple updates throughout the full second of the 'if (second0 == 1 || second0 == 5 || second0 == 9 || second0 == 13....' statement that defines when the humidity is displayed

}
*/

///////////////////////////////////////////////////////////////////////////////////////////

//sets the clock
void setclock (){
   setyear ();
lc.clearDisplay(0); // Clear display register 
   setmonth ();
lc.clearDisplay(0); // Clear display register 
   setday ();
lc.clearDisplay(0); // Clear display register 
   sethours ();
lc.clearDisplay(0); // Clear display register 
   setmins ();
lc.clearDisplay(0); // Clear time display register 
lc.clearDisplay(1); // Clear temperature/date display register 
lc.clearDisplay(2); // Clear seconds ring display register 
ClockJustBeenSet = true; // used for turning on just once all seconds ring LEDs on in the 'Inverse of single LED lit at current second' seconds ring animation immediately after the time/date has been set
   
   RTC.adjust(DateTime(setyeartemp,setmonthtemp,setdaytemp,sethourstemp,setminstemp,setsecs));

//   delay (1000); //  GING - why is this delay here as it makes the clock re-start at 1 second past the minute and not dead on zero seconds
   
}


// subroutine to return the length of the button push. - ORIGINAL
int getpushlength () {
//  buttonstate = digitalRead(A0);  // atmega328
  buttonstate = digitalRead(A1);  // atmega644
       if(buttonstate == LOW && buttonflag==false) {     
              pushstart = millis();
              buttonflag = true;
          };
          
       if (buttonstate == HIGH && buttonflag==true) {
         pushstop = millis ();
         pushlength = pushstop - pushstart;
         buttonflag = false;
       };
       return pushlength;
}

//////////////////////////////////////////////////////////////////////////////////////////////////

// The following subroutines set the individual clock parameters
int setyear () {
//lcd.clear();
//lc.clearDisplay(0); // Clear display register 
//    lcd.print ("Set Year");
lc.setRow(0,7,B00111011);  // displays the character 'Y'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//lc.setRow(0,6,B1101111);  // afisez litera "e" pe coloane 6
lc.setRow(0,6,B01001111);  // displays the character 'E'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//lc.setRow(0,5,B1111101);  // afisez litera "a" pe coloane 5
lc.setRow(0,5,B01110111);  // displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//lc.setRow(0,4,B0000101);  // afisez litera "r" pe coloane 4
lc.setRow(0,4,B10000101);  // displays the character 'r.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

    pushlength = pushlengthset;
    pushlength = getpushlength ();
    if (pushlength != pushlengthset) {
      return setyeartemp;
    }

//lc.clearDisplay(0); // Clear display register
    if (!digitalRead(SW1)) { //bit of software de-bounce
      knobval = -1;
       delay(150);
          setyeartemp=setyeartemp + knobval;
    if (setyeartemp < 2014) { //Year can't be older than currently, it's not a time machine.
      setyeartemp = 2014;
    }
    }
    if (!digitalRead(SW2)) {
      knobval = 1;  
       delay(150);
          setyeartemp=setyeartemp + knobval;
    if (setyeartemp < 2014) { //Year can't be older than currently, it's not a time machine.
      setyeartemp = 2014;
    }
    }
 //   setyeartemp=setyeartemp + knobval;
 //   if (setyeartemp < 2014) { //Year can't be older than currently, it's not a time machine.
 //     setyeartemp = 2014;
 //   }
//    lcd.print (setyeartemp);
int zua = setyeartemp - 2000;  // aflu ultimele 2 cifre din an
int za = zua / 10;  // aflu cifra zecilor din an
int ua = zua - 10*za; // aflu cifra unitatilor din an
lc.setDigit(0,3,2, false); // afisez cifra "2" din an pe coloana 3
lc.setDigit(0,2,0, false); // afisez cifra "0" din an pe coloana 2
lc.setDigit(0,1,za, false); // afisez cifra zecilor din an pe coloana 1
lc.setDigit(0,0,ua, false); // afisez cifra unitatilor din an pe coloana 0 (dreapta de tot)
    setyear();
//    delay(150);
}

//////////////////////////////////////////////////////////////////////////////////////////////
  
int setmonth () {
//lcd.clear();
//lcd.print ("Set Month");
//lc.setRow(0,7,B0110111);  // afisez litera "H" (in loc de "m") pe coloane 7 (in stanga de tot)
//lc.setRow(0,7,B1001111);  // afisez litera "E" (in loc de "m") pe coloane 7 (in stanga de tot)
//lc.setRow(0,6,B0011101);  // afisez litera "o" pe coloane 6
//lc.setRow(0,5,B0010101);  // afisez litera "n" pe coloane 5
//lc.setRow(0,4,B0001111);  // afisez litera "t" pe coloane 4
//lc.setRow(0,3,B0010111);  // afisez litera "h" pe coloane 3
  lc.setRow(0,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(0,5,B01111110);	// displays the character 'o'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(0,4,B01110110);	// displays the character 'n'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,5,B00011101);	// displays the character 'o'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,4,B00010101);	// displays the character 'n'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,3,B00001111);	// displays the character 't'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,2,B10010111);	// displays the character 'h.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  

    pushlength = pushlengthset;
    pushlength = getpushlength ();
    if (pushlength != pushlengthset) {
      return setmonthtemp;
    }

//    lcd.setCursor (0,1);
   if (!digitalRead(SW1)) { //bit of software de-bounce
      knobval = -1;
      delay(150);
        setmonthtemp=setmonthtemp + knobval;
    if (setmonthtemp < 1) {// month must be between 1 and 12
      setmonthtemp = 1;
    }
    }
    if (!digitalRead(SW2)) {
      knobval = 1;
      delay(150);
      setmonthtemp=setmonthtemp + knobval;
    if (setmonthtemp > 12) {
      setmonthtemp=12;
    }  
    }  
  
 //   lcd.print (setmonthtemp);
 //   lcd.print("  ");
int zl = setmonthtemp / 10;  // aflu cifra zecilor din luna
int ul = setmonthtemp - 10*zl; // aflu cifra unitatilor din luna
lc.setDigit(0,1,zl, false); // afisez cifra zecilor din luna pe coloana 1
lc.setDigit(0,0,ul, false); // afisez cifra unitatilor din luna pe coloana 0 (dreapta de tot)
     setmonth();
}

//////////////////////////////////////////////////////////////////////////////////////////////////

int setday () {
  if (setmonthtemp == 4 || setmonthtemp == 6 || setmonthtemp == 9 || setmonthtemp == 11) { //30 days hath September, April June and November
    maxday = 30;
  }
  else {
  maxday = 31; //... all the others have 31
  }
  if (setmonthtemp ==2 && setyeartemp % 4 ==0) { //... Except February alone, and that has 28 days clear, and 29 in a leap year.
    maxday = 29;
  }
  if (setmonthtemp ==2 && setyeartemp % 4 !=0) {
    maxday = 28;
  }
//lcd.clear();  
//    lcd.print ("Set Day");
lc.setRow(0,7,B00111101);  //  displays the character 'd'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//lc.setRow(0,6,B1111101);  // afisez litera "a" pe coloane 6
lc.setRow(0,6,B01110111);  // displays the character 'A'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setRow(0,5,B10111011);  //  displays the character 'Y.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }

    pushlength = pushlengthset;
    pushlength = getpushlength ();
    if (pushlength != pushlengthset) {
      return setdaytemp;
    }

 //   lcd.setCursor (0,1);
    if (!digitalRead(SW1)) { //bit of software de-bounce
      knobval = -1;
      delay(150);
        setdaytemp=setdaytemp+ knobval;
    if (setdaytemp < 1) {
      setdaytemp = 1;
    }
    }
    if (!digitalRead(SW2)) {
      knobval = 1;  
      delay(150);
        setdaytemp=setdaytemp+ knobval;
    if (setdaytemp > maxday) {
      setdaytemp = maxday;
    }
    } 
  
//    lcd.print (setdaytemp);
//    lcd.print("  "); 
int zz = setdaytemp / 10;  // aflu cifra zecilor din zi
int uz = setdaytemp - 10*zz; // aflu cifra unitatilor din zi
lc.setDigit(0,1,zz, false); // afisez cifra zecilor din zi pe coloana 1
lc.setDigit(0,0,uz, false); // afisez cifra unitatilor din zi pe coloana 0 (dreapta de tot)
    setday();
}

//////////////////////////////////////////////////////////////////////////////////////

int sethours () {
//lcd.clear();
//    lcd.setCursor (0,0);
//    lcd.print ("Set Hours");
lc.setRow(0,7,B00010111);  //  displays the character 'h'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setRow(0,6,B00011101);  //  displays the character 'o'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setRow(0,5,B00011100);  //  displays the character 'u'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
lc.setRow(0,4,B10000101);  //  displays the character 'r.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//lc.setRow(0,3,B11011011);  //  displays the character 's.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }


    pushlength = pushlengthset;
    pushlength = getpushlength ();
    if (pushlength != pushlengthset) {
      return sethourstemp;
    }

//    lcd.setCursor (0,1);
    if (!digitalRead(SW1)) { //bit of software de-bounce
      knobval = -1;
       delay(150);
        sethourstemp=sethourstemp + knobval;
//    if (sethourstemp < 0) { // original
//      sethourstemp = 0;     // original
//    }                       // original
    if (sethourstemp == -1) { // new
		sethourstemp = 23;    // new
	}                         // new
    }
    if (!digitalRead(SW2)) {
      knobval = 1;
     delay(150);  
    sethourstemp=sethourstemp + knobval;
//    if (sethourstemp > 23) {  // original
//      sethourstemp=23;        // original
//    }                         // original
    if (sethourstemp == 24) {   // new
		sethourstemp = 0;       // new
	}                           // new
    }
//    lcd.print (sethourstemp);
//    lcd.print("  "); 
int zo = sethourstemp / 10;  // aflu cifra zecilor de ore
int uo = sethourstemp - 10*zo; // aflu cifra unitatilor de ore
lc.setDigit(0,1,zo, false); // afisez cifra zecilor de ora pe coloana 1
lc.setDigit(0,0,uo, false); // afisez cifra unitatilor de ora pe coloana 0 (dreapta de tot)
    sethours();
}

/////////////////////////////////////////////////////////////////////////////////

int setmins () {
//lcd.clear();
//   lcd.setCursor (0,0);
//    lcd.print ("Set Mins");
//lc.setRow(0,7,B0110111);  // afisez litera "H" (in loc de "m") pe coloane 7 (in stanga de tot)
//lc.setRow(0,7,B1001111);  // afisez litera "E" (in loc de "m") pe coloane 7 (in stanga de tot)    
//lc.setRow(0,6,B0010000);  // afisez litera "i" pe coloane 6
//lc.setRow(0,5,B0010101);  // afisez litera "n" pe coloane 5
//lc.setRow(0,4,B0011100);  // afisez litera "u" pe coloane 4
//lc.setRow(0,3,B0001111);  // afisez litera "t" pe coloane 3
//lc.setChar(0,2,'e',true);
//lc.setRow(0,2,B11101111);  // afisez litera "e" cu punct jos
  lc.setRow(0,7,B01100110);	// displays the left half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,6,B01110010);	// displays the right half of the character 'M' which has to spread over 2 digits. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(0,5,B00110000);	// displays the character 'i'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(0,4,B11110110);	// displays the character 'n.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,5,B00010000);	// displays the character 'i'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
  lc.setRow(0,4,B10010101);	// displays the character 'n.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
//  lc.setRow(0,3,B11011011);	// displays the character 's.'. {arguments are: device address, row number, which LEDS are lit (number closest to letter B represents decimal point LED, ie.  dp,a,b,c,d,e,f,g)) }
 


    pushlength = pushlengthset;
    pushlength = getpushlength ();
    if (pushlength != pushlengthset) {
      return setminstemp;
    }

//    lcd.setCursor (0,1);
   if (!digitalRead(SW1)) { //bit of software de-bounce
      knobval = -1;
       delay(150);  
         setminstemp=setminstemp + knobval;
//    if (setminstemp < 0) { // original
//      setminstemp = 0;     // original
//    }                      // original
    if (setminstemp == -1) { // new
      setminstemp = 59;      // new
    }                        // new
    }
    if (!digitalRead(SW2)) {
      knobval = 1;  
       delay(150);   
    setminstemp=setminstemp + knobval;
//    if (setminstemp > 59) { // original
//      setminstemp=59;       // original
//   }                        // original
    if (setminstemp == 60) {  // new
      setminstemp = 0;        // new
    }                         // new
    }
//    lcd.print (setminstemp);
//    lcd.print("  ");
int zm = setminstemp / 10;  // aflu cifra zecilor de minute
int um = setminstemp - 10*zm; // aflu cifra unitatilor de minute
lc.setDigit(0,1,zm, false); // afisez cifra zecilor de minute pe coloana 1
lc.setDigit(0,0,um, false); // afisez cifra unitatilor de minute pe coloana 0 (dreapta de tot)
    setmins();
}

/////////////////////////////////////////////////////////////////////////////////////////

void ShortPush () {


// blank all the  displays
lc.clearDisplay(0); // Clear display register (time)
lc.clearDisplay(1); // Clear display register (date)
lc.clearDisplay(2); // Clear display register (secs ring)
lc.clearDisplay(3); // Clear display register (2x 4-digit temperature displays)
lc.clearDisplay(4); // Clear planets name display
lc.clearDisplay(5); // Clear elevation/azimuth display
lc.clearDisplay(6); // Clear moon illumination display

  lc.setChar(4,7,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(4,6,'b',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(4,5,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(4,4,'i',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(4,3,'L',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(4,2,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(4,1,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(4,0,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  
  lc.setChar(5,7,'J',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(5,6,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(5,5,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(5,4,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(5,3,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(5,2,'0',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(5,1,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(5,0,'4',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
 
  lc.setChar(0,7,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,6,'P',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,5,'L',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,4,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,3,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(0,2,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(0,1,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(0,0,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  
  lc.setChar(1,7,'L',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,6,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,5,'c',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,4,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,3,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(1,2,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(1,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(1,0,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  

/*  
  lc.setChar(3,7,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(3,6,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(3,5,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(3,4,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  
  lc.setChar(0,7,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,6,'b',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,5,'u',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,4,'i',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(0,3,'L',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(0,2,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(0,1,' ',true); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(0,0,' ',true); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  
  lc.setChar(1,7,'J',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,6,'A',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,5,'N',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,4,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
  lc.setChar(1,3,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(1,2,'0',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(1,1,'2',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(1,0,'4',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  
  lc.setChar(3,3,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
  lc.setChar(3,2,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(3,1,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)  
  lc.setChar(3,0,' ',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false) 
*/
  
//  delay(2000);  

  counter_rotating_animation ();

// blank all the  displays
lc.clearDisplay(0); // Clear display register (time)
lc.clearDisplay(1); // Clear display register (date)
// lc.clearDisplay(2); // Clear display register (secs ring) - already blanked from above
lc.clearDisplay(3); // Clear display register (2x 4-digit temperature displays)
lc.clearDisplay(4); // Clear display register (planet name)
lc.clearDisplay(5); // Clear display register (elevation/azimuth)


	short_push = true;
}

////////////////////////////////////////////////////////////////////////////////

//Measure Temperature 
float measure_Temp(){

  sensors.requestTemperaturesByAddress(tempDeviceAddress);  // sends command for one device to perform a temperature by address
 
  float TempC = sensors.getTempC(tempDeviceAddress);   
//  float TempC = (sensors.getTempC(tempDeviceAddress)) - 2.0;   //subtracting 2.0 degrees off what the DS18B20 sensor is reporting as it's reading too high.
  TempC = TempC * 10; // ging - added to remove decimal point
//  TempC = 173; // 17.3 degrees. testing only - works in conjunction with 'return TempC' line below
  temp_limiter = 1; // to allow a real temperature to be displayed
//  Serial.println("temperature measured");
   return  TempC ; // 
}
//  End of measure temperature


///////////////////////////////////////////////////////////////////////////////////////////////////////////

// setBright: set the brightness to a value between 0 and 15 (= 16 steps, in dependence of LDR)
//void setBright(){ // both 'void' and 'int' work
int setBright(){ // both 'void' and 'int' work

if (www == 0) { // new. to limit to one instance at the designated second

/*
// original - but if the lightReading is right on the threshold of changing the value of the 'bright' variable (due to the 'map' function), then, for a constant ambient brighness, the 'bright' variable could well change it's value (the next time this 'setBright' function is called to run) due to the 'currentHysteresis' being added/subtracted to the lightReading value, thus pushing it over the threshold for the 'map' function to change the value of the 'bright' variable. Obviously, we don't want the intensity of the 7-segment displays to change for a constant ambient brightness level - although it would only change once at this ambeient brightness level.
   // Read ambient light sensor
  int lightReading = analogRead(LIGHT); // 0 to 1023
  lightReading += currentHysteresis; // Add the current hysteresis value to the reading (this has the same effect as moving the thresholds)
//  lightReading = constrain(lightReading, 243, 640); // when using an ldr connected to +supply in series with 4.7k connected to ground: In bright conditions LDR = say 3k, therefore analogRead at LDR/4.7K junction is 640; In dark conditions LDR = say 16k, therefore analogRead at LDR/4.7K junction is 243.(if this line is changed need to alter the 2 numbers in the 'map....' line (2 lines below)
  lightReading = constrain(lightReading, 250, 700); // when using an ldr connected to +supply in series with 4.7k connected to ground: In bright conditions LDR = say 3k, therefore analogRead at LDR/4.7K junction is 640; In dark conditions LDR = say 16k, therefore analogRead at LDR/4.7K junction is 243.(if this line is changed need to alter the 2 numbers in the 'map....' line (2 lines below)
  // lightReading -> bright mapping
//  int bright = map(lightReading, 243, 640, 0, 5); //  an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
//  int bright = map(lightReading, 430, 800, 0, 5); //  ORIGINAL. an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
  int bright = map(lightReading, 250, 700, 0, 7); //  (x25 difference in min to max). an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
//  int pwm_bright = map(bright, 0, 5, 8, 88); // converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255)
//  int pwm_bright = map(bright, 0, 5, 247, 167); // converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 88 (out of 255) duty cycle, I'm now having a 255 - 88, ie 167 (out of 255) duty cycle.
//  int pwm_bright = map(bright, 0, 5, 231, 15); // ORIGINAL. converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 24 (out of 255) duty cycle, I'm now having a 255 - 24, ie 231 (out of 255) duty cycle.
  int pwm_bright = map(bright, 0, 7, 239, 15); //  converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 24 (out of 255) duty cycle, I'm now having a 255 - 24, ie 231 (out of 255) duty cycle.
  
 if (bright != brightness2)
  {
    if (bright < brightness2) currentHysteresis = -HYSTERESIS; // Going down
    else                     currentHysteresis =  HYSTERESIS; // Going up
    
    brightness2 = bright;
	
// MOVE THE FOLLOWING (SETTING INTENSITY) 3 LINES TO OUTSIDE THE 'if (bright != brightness)' LOOP IF IT CAUSES PROBLEMS HAVING IT IN LOOP (WHICH CURRENTLY ONLY UPDATES THE INTENSITIES IF THERE'S A CHANGE IN THE BRIGHTNESS)	
	for (byte aa = 0; aa < 7; aa++) { // 7 is 7 max7219 devices
    lc.setIntensity(aa, bright);
    analogWrite(pwm_auto_dimming, pwm_bright); // output an additional auto-dimming pwm signal on arduino pin D5 (pwm_auto_dimming), that mimics the auto-dimming on the max7219s
    }

//  Serial.print(" bright variable is = ");
//  Serial.println(bright);

  }

//  Serial.print(" bright variable is = ");
//  Serial.println(bright);
*/






   // Read ambient light sensor
  int lightReading = analogRead(LIGHT); // 0 to 1023
  lightReading = constrain(lightReading, 250, 700); // ALTER TO SUIT YOUR OWN AMBIENT LIGHTING/LDR MODEL SITUATION. when using an ldr connected to +supply in series with 4.7k connected to ground: In bright conditions LDR = say 3k, therefore analogRead at LDR/4.7K junction is 640; In dark conditions LDR = say 16k, therefore analogRead at LDR/4.7K junction is 243.(if this line is changed need to alter the 2 numbers in the 'map....' line (2 lines below)
  // lightReading -> bright mapping
//  int bright = map(lightReading, 243, 640, 0, 5); //  an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
//  int bright = map(lightReading, 430, 800, 0, 5); //  ORIGINAL. an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
  bright = map(lightReading, 250, 700, 0, 7); //  ALTER TO SUIT YOUR OWN AMBIENT LIGHTING/LDR MODEL SITUATION. (a x15 difference in min to max intensity of 7-segment displays). an intensity of 15 is 31/32, an intensity of 2 is 5/32, an intensity of 1 is 3/32, an intensity of 0 is 1/32
//  int pwm_bright = map(bright, 0, 5, 8, 88); // converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255)
//  int pwm_bright = map(bright, 0, 5, 247, 167); // converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 88 (out of 255) duty cycle, I'm now having a 255 - 88, ie 167 (out of 255) duty cycle.
//  int pwm_bright = map(bright, 0, 5, 231, 15); // ORIGINAL. converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 24 (out of 255) duty cycle, I'm now having a 255 - 24, ie 231 (out of 255) duty cycle.
  int pwm_bright = map(bright, 0, 7, 239, 15); //  DON'T NEED THIS LIKE ANYMORE AS I'M USING FASTPWM LIBRARY INSTEAD OF ANALOGWRITE COMMAND. 'converting the max7219 intensities to analogWrite values for pink seconds index LEDs. So, from line above, a max7219 intensity of 1 is 3/32 in reality, which converts to an analogWrite value of 24 (3/32 x 255). Likewise a max7219 intensity of 15 is 31/32 in reality, which converts to an analogWrite value of 247 (31/32 x 255). As the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account (eg, instead of a 24 (out of 255) duty cycle, I'm now having a 255 - 24, ie 231 (out of 255) duty cycle.
  
	for (byte aa = 0; aa < 7; aa++) { // 7 is 7 max7219 devices
     lc.setIntensity(aa, bright);
//     analogWrite(pwm_auto_dimming, pwm_bright); // output an additional auto-dimming pwm signal on arduino pin D5 (pwm_auto_dimming), that mimics the auto-dimming on the max7219s
    }
	
  int fastpwm_bright = map(bright, 0, 7, 94, 10); // the 0 to 7 input values correspond to 1/32 and 15/32 max7219 intensity values, ie a 15 times difference between min and max. But because the attached p-channel mosfet inverts the logic signal I'm now altering the duty cycles to take this into account {ie, the 94 percentage duty cycle after the mosfet is 100-94 = 6. Likewise, the 10 percent duty cycle after the mosfet is 100-10 = 90. So, again, the difference between the min and max percentage duty cycles is 15 times (90/6 = 15)}
//  FastPwmPin::enablePwmPin(pwm_auto_dimming, 7800L, pwm_bright); // FastPWM output on Arduino pin 14 (actual pin 20) of the Atmega644, at 7800Hz, at PWM duty cycle
  FastPwmPin::enablePwmPin(pwm_auto_dimming, 7800L, fastpwm_bright); // remember, these are percentages and go from 0% to 100%, unlike the analogWrite which goes from 0 to 255 steps.
	

//  Serial.print(" bright variable is = ");
//  Serial.println(bright);
 } // new
 
  www = www + 1; // new
  if (www >= 1) www = 1; // new
 
}


////////////////////////////////////////////////////////////////////////////////////////


void test_only()
 {
         lc.clearDisplay(0); // Clear time display
         lc.clearDisplay(1); // Clear date display (added)
         lc.clearDisplay(2); // Clear seconds ring (added) 
	     lc.clearDisplay(3); // Clear 2x 4-digit temperature displays (added)
         lc.clearDisplay(4); // Clear planets name display
         lc.clearDisplay(5); // Clear elevation/azimuth display
         lc.clearDisplay(6); // Clear moon illumination display
         DateTime now = RTC.now();
         setyeartemp=now.year(),DEC;
         setmonthtemp=now.month(),DEC;
         setdaytemp=now.day(),DEC;
         sethourstemp=now.hour(),DEC;
         setminstemp=now.minute(),DEC;
         setclock();
         pushlength = pushlengthset;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////
 
 void Increment_LED_RING ()
 {
		LED_RING_ANIMATION = LED_RING_ANIMATION + 1;
	    if (bmp180En == true) {	
		 if (LED_RING_ANIMATION == 18) LED_RING_ANIMATION = 0; // wrap back to first animation after including animations that involve the bmp180 pressure sensor 2hr and 4hr trends
	    }
	    if (bmp180En == false) {	
		 if (LED_RING_ANIMATION == 16) LED_RING_ANIMATION = 0; // wrap back to first animation after bypassing animations that involve the bmp180 pressure sensor 2hr and 4hr trends
	    }
		LED_MODE_1_CHANGED = true; // can be used for any of the seconds ring animation modes
		LED_MODE_1_CHANGED_END = true; // can be used for any of the seconds ring animation modes
//		LED_MODE_3_CHANGED = true;
//           Serial.print("LED_RING_ANIMATION variable in subroutine = ");
//           Serial.println(LED_RING_ANIMATION);
 }
 
 /////////////////////////////////////////////////////////////////////////////////////
 
 void Increment_time_display ()
 {
		time_display_mode = time_display_mode + 1;
		if (time_display_mode == 12) time_display_mode = 0;
		LED_MODE_1_CHANGED = true;

//           Serial.print("time_display_mode variable in subroutine = ");
//           Serial.println(time_display_mode);
 } 
 
/////////////////////////////////////////////////////////////////////////////



void counter_rotating_animation ()
{
	  for (byte i = 0; i <= 1; i++) // repeat animation say 2 times
	   {  
		  for (byte v = 0; v < 60; v++)
		  {
		   // want 0 sec LED to light by itself, then 1 sec and 59 sec LED to light, then 2 sec and 58 sec LED to light...etc (note 60 sec LED is not fitted)		  
		   lc.setLed(2, v / 8, v % 8, true); // light LEDs consequtively going clockwise from LED 0 sec to LED 59 sec. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		   lc.setLed(2, (60 - v) / 8, (60 - v) % 8, true); // light LEDs consequtively going anti-clockwise from LED 60 sec (not actually fitted) to LED 1 sec. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		   delay(53); // was 50 - now trying to make animation last exactly 7 secs. hold lit LED for a short time to look nice
		   lc.setLed(2, v / 8, v % 8, false); // UN-light LEDs consequtively going clockwise from LED 0 sec to LED 59 sec. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		   lc.setLed(2, (60 - v) / 8, (60 - v) % 8, false); // UN-light LEDs consequtively going anti-clockwise from LED 60 sec (not actually fitted) to LED 1 sec. arguements are: device addr, row number, column number, boolean state of LED - If true the led is switched on, if false it is switched off
		  }
	   }
}

/////////////////////////////////////////////////////////////////////////////////////////////////



//////////////////MORE EXTRA MOON/SUN/PLANETARY STUFF

/*
// getTime obtains current time from RTC
void getTime() {
  DateTime now = RTC.now();
  hr = now.hour(); if(hr==0) hr=24;                      // adjust to 1-24
  mn = now.minute();
  se = now.second();
  yr = now.year();
  mo = now.month();
  dy = now.day();
  dw = now.dayOfTheWeek();
}
*/

/*
// doDSTAdjust increments (or decrements) by one hour when entering (or leaving) DST
void doDSTAdjust() {
  if(dst == IsDST()) return;                    // if prior setting is same as DST setting, do nothing
  if(hr != 2) return;                           // do nothing until 2pm

  DateTime now = RTC.now();                     // get time
  if(IsDST() && !dst) {
    DateTime newTime (now.unixtime() + 3600);   // add one hour
    RTC.adjust(newTime);                        
  }
  if(!IsDST() && dst) {
    DateTime newTime (now.unixtime() - 3600);   // subtract one hour
    RTC.adjust(newTime);
  }
  dst = IsDST(); 
//  saveSettings();                // save change to DST
}
*/


// calculate moonrise and moonset times
void riseset(const float lat, const float lon, const int day, const int month, const int year, const int TimezoneOffset) {
    int i, j, k;
    float ph;
    // guido: julian day has been converted to int from float
//    float jd = (julian_day(day, month, year)) - 2451545;    // Julian day relative to Jan 1.5, 2000
    float jd = (julian_day(day, month, year)) - 2451545;    // Julian day relative to Jan 1.5, 2000
    float mp[3][3];
    float lon_local = lon;

    for (i = 0; i < 3; i++) {
    for (j = 0; j < 3; j++)
        mp[i][j] = 0.0;
    }

    lon_local = lon / 360;
    float tz = -((float)TimezoneOffset) / 24;
    float t0 = lst(lon_local, jd, tz);    // local sidereal time

    jd = jd + tz;        // get moon position at start of day

    for (k = 0; k < 3; k++) {
    moonpos(jd);
    mp[k][0] = Sky[0];
    mp[k][1] = Sky[1];
    mp[k][2] = Sky[2];
    jd = jd + 0.5;
    }

    if (mp[1][0] <= mp[0][0])
    mp[1][0] = mp[1][0] + 2 * M_PI;

    if (mp[2][0] <= mp[1][0])
    mp[2][0] = mp[2][0] + 2 * M_PI;

    RAn[0] = mp[0][0];
    Dec[0] = mp[0][1];

    Moonrise = 0;        // initialize
    Moonset = 0;

    for (k = 0; k < 24; k++)    // check each hour of this day
    {
    ph = ((float) (k + 1)) / 24;

    RAn[2] = interpolate(mp[0][0], mp[1][0], mp[2][0], ph);
    Dec[2] = interpolate(mp[0][1], mp[1][1], mp[2][1], ph);

    VHz[2] = test_moon(k, t0, lat, mp[1][2]);

    RAn[0] = RAn[2];    // advance to next hour
    Dec[0] = Dec[2];
    VHz[0] = VHz[2];
    }
}

// determine Julian day from calendar date: Jean Meeus, "Astronomical Algorithms", Willmann-Bell, 1991
float julian_day(const int day_const, const int month_const, const int year_const) {
    float a, b, jd;
    bool gregorian;

    int month = month_const;
    int day = day_const;
    float year = (float) year_const;

    gregorian = (year < 1583) ? 0 : 1;

    if ((month == 1) || (month == 2)) {
    year = year - 1;
    month = month + 12;
    }

    a = floor(year / 100);
    if (gregorian)
    b = 2.0 - a + floor(a / 4.0);
    else
    b = 0.0;

    jd = floor(365.25 * (float)(year + 4716.0))
    + floor(30.6001 * (float)(month + 1))
    + day + b - 1524.5;

    return jd;
}

// Local Sidereal Time for zone
float lst(const float lon, const float jd, const float z) {
    float s =
    24110.5 + 8640184.812999999 * jd / 36525 + 86636.6 * z +
    86400 * lon;
    s = s / 86400;
    s = s - floor(s);
    return s * 360 * DR;
}

// moon's position using fundamental arguments by Van Flandern & Pulkkinen, 1979
void moonpos(float jd) {

  float d, f, g, h, m, n, s, u, v, w;

    h = 0.606434 + 0.03660110129 * jd;
    m = 0.374897 + 0.03629164709 * jd;
    f = 0.259091 + 0.0367481952 * jd;
    d = 0.827362 + 0.03386319198 * jd;
    n = 0.347343 - 0.00014709391 * jd;
    g = 0.993126 + 0.0027377785 * jd;

    h = h - floor(h);
    m = m - floor(m);
    f = f - floor(f);
    d = d - floor(d);
    n = n - floor(n);
    g = g - floor(g);

    h = h * 2 * M_PI;
    m = m * 2 * M_PI;
    f = f * 2 * M_PI;
    d = d * 2 * M_PI;
    n = n * 2 * M_PI;
    g = g * 2 * M_PI;

    v = 0.39558 * sin(f + n);
    v = v + 0.082 * sin(f);
    v = v + 0.03257 * sin(m - f - n);
    v = v + 0.01092 * sin(m + f + n);
    v = v + 0.00666 * sin(m - f);
    v = v - 0.00644 * sin(m + f - 2 * d + n);
    v = v - 0.00331 * sin(f - 2 * d + n);
    v = v - 0.00304 * sin(f - 2 * d);
    v = v - 0.0024 * sin(m - f - 2 * d - n);
    v = v + 0.00226 * sin(m + f);
    v = v - 0.00108 * sin(m + f - 2 * d);
    v = v - 0.00079 * sin(f - n);
    v = v + 0.00078 * sin(f + 2 * d + n);

    u = 1 - 0.10828 * cos(m);
    u = u - 0.0188 * cos(m - 2 * d);
    u = u - 0.01479 * cos(2 * d);
    u = u + 0.00181 * cos(2 * m - 2 * d);
    u = u - 0.00147 * cos(2 * m);
    u = u - 0.00105 * cos(2 * d - g);
    u = u - 0.00075 * cos(m - 2 * d + g);

    w = 0.10478 * sin(m);
    w = w - 0.04105 * sin(2 * f + 2 * n);
    w = w - 0.0213 * sin(m - 2 * d);
    w = w - 0.01779 * sin(2 * f + n);
    w = w + 0.01774 * sin(n);
    w = w + 0.00987 * sin(2 * d);
    w = w - 0.00338 * sin(m - 2 * f - 2 * n);
    w = w - 0.00309 * sin(g);
    w = w - 0.0019 * sin(2 * f);
    w = w - 0.00144 * sin(m + n);
    w = w - 0.00144 * sin(m - 2 * f - n);
    w = w - 0.00113 * sin(m + 2 * f + 2 * n);
    w = w - 0.00094 * sin(m - 2 * d + g);
    w = w - 0.00092 * sin(2 * m - 2 * d);

    s = w / sqrt(u - v * v);    // compute moon's right ascension ...  
    Sky[0] = h + atan(s / sqrt(1 - s * s));

    s = v / sqrt(u);        // declination ...
    Sky[1] = atan(s / sqrt(1 - s * s));

    Sky[2] = 60.40974 * sqrt(u);    // and parallax
}

// 3-point interpolation
float interpolate(const float f0, const float f1, const float f2, const float p) {
    float a = f1 - f0;
    float b = f2 - f1 - a;
    float f = f0 + p * (2 * a + b * (2 * p - 1));
    return f;
}

// test an hour for an event
float test_moon(int k, float t0, float lat, float plx) {

const static float K1 = 15 * M_PI * 1.0027379 / 180;
static float Rise_az = 0.0, Set_az = 0.0;

    float ha[3] = { 0.0, 0.0, 0.0 };
    float a, b, c, d, e, s, z;
    float hr_1, min, time;
    float az, hz, nz, dz;

    if (RAn[2] < RAn[0])
    RAn[2] = RAn[2] + 2 * M_PI;

    ha[0] = t0 - RAn[0] + (k * K1);
    ha[2] = t0 - RAn[2] + (k * K1) + K1;

    ha[1] = (ha[2] + ha[0]) / 2;    // hour angle at half hour
    Dec[1] = (Dec[2] + Dec[0]) / 2;    // declination at half hour

    s = sin(DR * lat);
    c = cos(DR * lat);

    // refraction + sun semidiameter at horizon + parallax correction
    z = cos(DR * (90.567 - 41.685 / plx));

    if (k <= 0)            // first call of function
    VHz[0] = s * sin(Dec[0]) + c * cos(Dec[0]) * cos(ha[0]) - z;

    VHz[2] = s * sin(Dec[2]) + c * cos(Dec[2]) * cos(ha[2]) - z;

    if (sgn(VHz[0]) == sgn(VHz[2]))
    return VHz[2];        // no event this hour

    VHz[1] = s * sin(Dec[1]) + c * cos(Dec[1]) * cos(ha[1]) - z;

    a = 2 * VHz[2] - 4 * VHz[1] + 2 * VHz[0];
    b = 4 * VHz[1] - 3 * VHz[0] - VHz[2];
    d = b * b - 4 * a * VHz[0];

    if (d < 0)
    return VHz[2];        // no event this hour

    d = sqrt(d);
    e = (-b + d) / (2 * a);

    if ((e > 1) || (e < 0))
    e = (-b - d) / (2 * a);

    time = ((float) k) + e + 1 / 120;    // time of an event + round up
    hr_1 = floor(time);
    min = floor((time - hr_1) * 60);

    hz = ha[0] + e * (ha[2] - ha[0]);    // azimuth of the moon at the event
    nz = -cos(Dec[1]) * sin(hz);
    dz = c * sin(Dec[1]) - s * cos(Dec[1]) * cos(hz);
    az = atan2(nz, dz) / DR;
    if (az < 0)
    az = az + 360;

    if ((VHz[0] < 0) && (VHz[2] > 0)) {
    Rise_time[0] = (int) hr_1;
    Rise_time[1] = (int) min;
    Rise_az = az;
    Moonrise = 1;
    }

    if ((VHz[0] > 0) && (VHz[2] < 0)) {
    Set_time[0] = (int) hr_1;
    Set_time[1] = (int) min;
    Set_az = az;
    Moonset = 1;
    }

    return VHz[2];
}

// returns value for sign of argument
float sgn(float x) {
    float rv;
    if (x > 0.0)
    rv = 1;
    else if (x < 0.0)
    rv = -1;
    else
    rv = 0;
    return rv;
}

// getCardinal: converts the headsing (in degrees) to a text-based cardinal heading ("ENE", for example)
String getCardinal( float h ) { 
  h += 11.25; if (h > 360.0) h = h-360.0;
  strcpy_P(cb, (char*) pgm_read_word(&(cas[(int) (h / 22.5)]) ) );
  return cb;  
}


/* // ORIGINAL MOONPHASE
// moonphase:  the phase day (0 to 29, where 0=new moon, 15=full etc.): see http://www.ben-daglish.net/moon.shtml
int moonphase() {
  long lp = 2551443;                                   // 2551223 secs / lunar cycle. new scaling for 0-26 (i.e. 27 unique) bitmaps
  DateTime now = RTC.now();
  DateTime new_moon (1970, 1, 7, 20, 35, 0);
  long ph = (now.unixtime() - new_moon.unixtime()) % lp;  // scales to 0-29 days
  ph = floor (ph/3600L);                                    
  ph = map(ph, 0.0, 29*24.0, 0, 26);                      // map to 0-26
  return ph;  
}
*/


/* // my sort of working illumnination percentage but not that accurate
// moonphase:  the phase day (0 to 29, where 0=new moon, 15=full etc.): see http://www.ben-daglish.net/moon.shtml
int moonphase() {
  long lp = 2551443;                                   // 2551223 secs / lunar cycle. new scaling for 0-26 (i.e. 27 unique) bitmaps
  DateTime now = RTC.now();
  DateTime new_moon (1970, 1, 7, 20, 35, 0);
  long ph = (now.unixtime() - new_moon.unixtime()) % lp;  // moon phase in seconds. scales to 0-29 days. ging note (this calculation could be upto about 1 day out)
  ph = floor (ph/86400L);     // converts from seconds to days.  ging note (this calculation could be upto about 1 day out)
  moon_phase = ph;
  moon_ill = 49.871+(50.18*cos(0.20846*ph - 3.24)); //ging approx calculation (using curveexpert and an online actual moon illumination) for moon percentage illumination based on moon phase day (which in itself could be upto 1 day out)
  moon_ill = constrain(moon_ill, 0, 99);  // limit percentage to between 0% and 99 %. ie can't go outside this range -- 99% as a max as I've only got a 2-digit display and thus can't display 100, so i'll have to show 99 instead
//  ph = map(ph, 0.0, 29*24.0, 0, 26);                      // map to 0-26
  return ph;  
}
*/


// moonphase:  the phase day (0 to 29, where 0=new moon, 15=full etc.): see http://www.ben-daglish.net/moon.shtml
int moonphase() {
  long lp = 2551443; // 2551223 secs is a lunar cycle. equals 29.53059 days but actually varies from 29.18 to about 29.93 days
  DateTime now = RTC.now();
  DateTime new_moon (1970, 1, 7, 20, 35, 0);
  long ph = (now.unixtime() - new_moon.unixtime()) % lp;  // moon phase in seconds. ging note (this calculation could be upto about 1 day out)
  ph_1 = ph/86400.0;     // A  MORE ACCURATE CALCULATION OF PHASE DAY. converts from seconds to days.  ging note (this calculation could be upto about 1 day out because of the variation in the lunar cycle)
  ph = floor (ph/86400L);     // NOT USED IN THE END AS A MORE ACCURATE CALCULATION IN LINE ABOVE. converts from seconds to days.  ging note (this calculation could be upto about 1 day out)
  moon_ill = 49.871+(50.18*cos(0.20846*ph - 3.24)); //NOT USED IN THE END AS A MORE ACCURATE CALCULATION IN 'getMoonIllumination' SUBROUTINE. ging approx calculation (using curveexpert and an online actual moon illumination) for moon percentage illumination based on moon phase day (which in itself could be upto 1 day out)
  moon_ill = constrain(moon_ill, 0, 99);  // limit percentage to between 0% and 99 %. ie can't go outside this range -- 99% as a max as I've only got a 2-digit display and thus can't display 100, so i'll have to show 99 instead
  return ph;  
}



// ********************************************************************************** //
//                             MOON ILLUMINATION CALCULATIONS
// ********************************************************************************** //
// calculations for illumination parameters of the moon,
// based on http://idlastro.gsfc.nasa.gov/ftp/pro/astro/mphase.pro formulas and
// Chapter 48 of "Astronomical Algorithms" 2nd edition by Jean Meeus (Willmann-Bell, Richmond) 1998.

void getMoonIllumination() {
   long sdist = 149598000L;        // distance from Earth to Sun in km

   double phi   = acos(sin(sdec)*sin(mdec) + cos(sdec)*cos(mdec)*cos(sra - mra));
   double inc   = atan2(sdist*sin(phi), mdist - sdist*cos(phi));
   double angle = atan2(cos(sdec)*sin(sra - mra), sin(sdec)*cos(mdec)-cos(sdec)*sin(mdec)*cos(sra-mra));
   mfract = (1 + cos(inc)) / 2; // accurate illuminated fraction of the moon between 0.0 and 1.0.
   mphase = (0.5 + 0.5*inc*(angle < 0 ? -1 : 1) / PI); // accurate moon phase between 0.0 (beginning of cycle) and 1.0 (end of cycle) - ie. for new moon (0% illumination) mphase = 0.0, for first quarter (50% illimination) mphase = 0.25, for full moon (100% illumination) mphase = 0.50, for last quarter (50% illumination) mphase = 0.75, back to new moon (0% illumination) mphase = 0.0
   mangle = angle;
}

// // sun calculations are based on http://aa.quae.nl/en/reken/zonpositie.html formulas
void getSunPosition() {
  double lw  = rad * -LONGITUDE;
  double phi = rad * LATITUDE;
  double nd = nDays();                         // number of days since Jan 1, 2000 12:00 UTC 

  double M = solarMeanAnomaly(nd);
  double L = eclipticLongitude(M);
  sdec = declination(L, 0);
  sra  = rightAscension(L, 0);
  
  double H  = siderealTime(nd,lw) - sra;
  saz = azimuth(H, phi, sdec);
  sad = 180.0+saz*irad;
  sal = altitude(H, phi, sdec);
}

double solarMeanAnomaly(double ds) { return rad * (357.5291 + 0.98560028 * ds); }

double eclipticLongitude(double M) {
    double C = rad * (1.9148 * sin(M) + 0.02 * sin(2 * M) + 0.0003 * sin(3 * M)); // equation of center
    double P = rad * 102.9372;                                                    // perihelion of the Earth
    return (M + C + P + PI);
}






// ********************************************************************************** //
//                                  MOON POSITION CALCULATIONS
// ********************************************************************************** //
// moon calculations, based on http://aa.quae.nl/en/reken/hemelpositie.html formulas

void getMoonPosition() {
  double lw = rad * -LONGITUDE; 
  double phi = rad * LATITUDE;
  double nd =  nDays();                         // number of days since Jan 1, 2000 12:00 UTC 
  
  double L = rad * (218.316 + 13.176396 * nd);  // ecliptic longitude
  double M = rad * (134.963 + 13.064993 * nd);  // mean anomoly
  double F = rad * (93.272  + 13.229350 * nd);  // mean distance
  
  double mlo = L + (rad * 6.289 * sin(M));      // lunar longitude
  double mla = rad * 5.128 * sin(F);            // lunar lattitude
  // geocentric ecliptic coordinates of the moon
  mdist = 385001L - (20905L * cos(M));          // lunar distance (km)
  mra   = rightAscension(mlo, mla);             // right ascension
  mdec   = declination(mlo, mla);               // declination

  double H = siderealTime(nd,lw) - mra;
  maz = azimuth(H, phi, mdec);                   // lunar azimuth
  mad = 180.0+maz*irad;
  
  mal = altitude(H, phi, mdec);                  // lunar elevation 
  mal = mal + rad * 0.017 / tan(mal + rad * 10.26 / (mal + rad * 5.10));    // altitude correction for refraction
}

// Note, the originl author had declared TZ as a 'int'. This caused Time zones of +10 to give wrong
// values of TZ*3600, as, for example, 10*3600 is 36000, which is greater than 32768 (the max value
// of an 'int'), and hence, instead of giving 36000 as the answer, it gave -29536 (ie, it wrapped
// back around to the minimum negative value of an 'int', ie, -32768.) So, the returned value of the
// subroutine nDays, for Time Zones of +10 or more was gibberish, and so the Sun's position, the moon's
// position, and the moon's illumination were all gibberish. I've now made TZ a 'long', and now all is good.
double nDays() {
  DateTime now = RTC.now();
  DateTime ntim (now.unixtime() - (TZ*3600));  // current time UTC
  DateTime stim (2000, 1, 1, 12, 0, 0);        // Jan 1, 2000 12:00 UTC
  return (((double) ntim.unixtime() - (double) stim.unixtime())/86400L);
}


double siderealTime(double ds, double ls)      { return rad * (280.16 + 360.9856235 * ds) - ls;  }
double rightAscension(double lr, double br)    { return atan2((sin(lr)*cos(ob) - tan(br)*sin(ob)), cos(lr) ); }
double declination(double ld, double bd)       { return asin(sin(bd)*cos(ob) + cos(bd)*sin(ob)*sin(ld)); }
double azimuth(double ha,double pa,double da)  { return atan2(sin(ha), (cos(ha)*sin(pa) - tan(da)*cos(pa))); }
double altitude(double ha,double pa,double da) { return asin(sin(pa)*sin(da) + cos(pa)*cos(da)*cos(ha)); }


void PlanetVisibility() {
//
// Agrees with https://www.heavens-above.com/PlanetSummary.aspx?lat=59.8348&lng=10.4299&loc=Unnamed&alt=0&tz=CET
// except for brightness or magnitude of mercury: this code says 0.2 when web says 0.6
  
  // Julian day ref noon Universal Time (UT) Monday, 1 January 4713 BC in the Julian calendar:
  //jd = get_julian_date (20, 1, 2017, 17, 0, 0);//UTC
  
/*  
  DateTime now = RTC.now();
  Hour = now.hour(); if(Hour==0) Hour=24;    // adjust to 1-24 . original ---IS THIS CORRECT FOR THIS USE ging ???????????? yes
  if (TZ == 1) Hour = Hour - 1; // ging added this line and line below to take into account daylight saving time, by subtracting 1 hour to the actual time for planetary position calculations only
  if (Hour == 0) Hour = 24; // ging added this line and line above to take into account daylight saving time, by subtracting 1 hour to the actual time for planetary position calculations only
// NOTE, THE ABOVE 2 LINES DON'T TAKE INTO ACCOUNT THE CHANGE IN DAY THAT WOULD OCCUR BY SUBTRACTING 1 HOUR BEWTEEN THE TIMES MIDNIGHT (00:00) TO 00:59 - however the planetary positions for the same time on consequtive nights don't differ in position by more than about 1 degree in altitude or azimuth for all the planets. so, this is ok to do
*/


  DateTime now = RTC.now();
  Hour = now.hour(); if(Hour==0) Hour=24;    // adjust to 1-24 . original ---IS THIS CORRECT FOR THIS USE ging ???????????? yes
  Hour = Hour - TZ; // if the time isn't GMT we need to correct for this in the planetary positions calculations
  if (Hour > 24) Hour = Hour - 24;
  if (Hour < 0) Hour = Hour + 24;
  if (Hour == 0) Hour = 24;
// NOTE, THE ABOVE 3 LINES DON'T TAKE INTO ACCOUNT A POSSIBLE CHANGE IN DAY (if hour > 24, or hour < 0) THAT WOULD OCCUR however the planetary positions for the same time on consequtive nights don't differ in position by more than about 1 degree in altitude or azimuth for all the planets. so, this is ok to do



  Minute = now.minute();
  Seconds = now.second();
  Year = now.year();
  Month = now.month();
  Day = now.day();
  
  
/* 
// Ging - If TZ is 1 (ie DST), then the time serial printed should be 1 hour less than the actual time for planetary calculations only
  Serial.print(Day);
  Serial.print(" of ");
  Serial.print(Month);
  Serial.print(", ");
  Serial.print(Year);
  Serial.print("    ");
  Serial.print(Hour);
  Serial.print(":");
  Serial.print(Minute);
  Serial.print(":");
  Serial.print(Seconds);
  Serial.println();
*/
  

  
/*
//ORIGINAL
  Seconds = second(now());
  Minute = minute(now());
  Hour = hour(now());
  Day = day(now()); // duplicated above, does it matter ?
  Month = month(now());
  Year = year(now());
*/
   
  jd = get_julian_date (Day, Month, Year, Hour, Minute, Seconds); // local
 
  #ifdef FEATURE_SERIAL_PLANETARY
    Serial.println("JD:" + String(jd, DEC) + "+" + String(jd_frac, DEC)); // jd = 2457761.375000;
  #endif
  
  get_object_position (2, jd, jd_frac);//earth -- must be included always
  
//  lcd.setCursor(0, 0); // top line ********* 
//  lcd.print("    El");lcd.write(DEGREE);lcd.print(" Az");lcd.write(DEGREE);lcd.print("   % Magn");
  


    get_object_position (0, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Mer "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Merc_elev = altitudePlanet;
	Merc_azim = azimuthPlanet;
	Merc_mag = magnitude;
#if(serEn)
	Serial.print("  Mercury elev: ");
	Serial.print(altitudePlanet,1); // mercury altitude in degrees
	Serial.print("  Mercury azim: ");
	Serial.print(azimuthPlanet,1); // mercury azimuth in degrees
	Serial.print("  Mercury Magn: ");
	Serial.print(magnitude,1); // mercury magnitude
	Serial.println(); 
#endif
	
    get_object_position (1, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Ven "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Ven_elev = altitudePlanet;
	Ven_azim = azimuthPlanet;
	Ven_mag = magnitude;
#if(serEn)
	Serial.print("  Venus elev: ");
	Serial.print(altitudePlanet,1); // venus altitude in degrees
	Serial.print("  Venus azim: ");
	Serial.print(azimuthPlanet,1); // venus azimuth in degrees
	Serial.print("  Venus Magn: ");
	Serial.print(magnitude,1); // venus magnitude
	Serial.println();
#endif

    get_object_position (3, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Mar "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Mars_elev = altitudePlanet;
	Mars_azim = azimuthPlanet;
	Mars_mag = magnitude;
#if(serEn)
	Serial.print("  Mars elev: ");
	Serial.print(altitudePlanet,1); // mars altitude in degrees
	Serial.print("  Mars azim: ");
	Serial.print(azimuthPlanet,1); // mars azimuth in degrees
	Serial.print("  Mars Magn: ");
	Serial.print(magnitude,1); // mars magnitude
	Serial.println(); 
#endif

    get_object_position (4, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Jup "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Jup_elev = altitudePlanet;
	Jup_azim = azimuthPlanet;
	Jup_mag = magnitude;
#if(serEn)
	Serial.print("  Jupiter elev: ");
	Serial.print(altitudePlanet,1); // jupiter altitude in degrees
	Serial.print("  Jupiter azim: ");
	Serial.print(azimuthPlanet,1); // jupiter azimuth in degrees
	Serial.print("  Jupiter Magn: ");
	Serial.print(magnitude,1); // jupiter magnitude
	Serial.println(); 
#endif
	
    get_object_position (5, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Sat "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Sat_elev = altitudePlanet;
	Sat_azim = azimuthPlanet;
	Sat_mag = magnitude;
#if(serEn)
	Serial.print("  Saturn elev: ");
	Serial.print(altitudePlanet,1); // Saturn altitude in degrees
	Serial.print("  Saturn azim: ");
	Serial.print(azimuthPlanet,1); // Saturn azimuth in degrees
	Serial.print("  Saturn Magn: ");
	Serial.print(magnitude,1); // saturn magnitude
	Serial.println(); 
#endif
	
    get_object_position (6, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Ura "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Uran_elev = altitudePlanet;
	Uran_azim = azimuthPlanet;
	Uran_mag = magnitude;
#if(serEn)
	Serial.print("  Uranus elev: ");
	Serial.print(altitudePlanet,1); // Uranus altitude in degrees
	Serial.print("  Uranus azim: ");
	Serial.print(azimuthPlanet,1); // Uranus azimuth in degrees
	Serial.print("  Uranus Magn: ");
	Serial.print(magnitude,1); // uranus magnitude
	Serial.println(); 
#endif
	
    get_object_position (7, jd, jd_frac);
//    lcd.setCursor(0, 1);
//    lcd.print("Nep "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    Nep_elev = altitudePlanet;
	Nep_azim = azimuthPlanet;
	Nep_mag = magnitude;
#if(serEn)
	Serial.print("  Neptune elev: ");
	Serial.print(altitudePlanet,1); // Neptune altitude in degrees
	Serial.print("  Neptune azim: ");
	Serial.print(azimuthPlanet,1); // Neptune azimuth in degrees
	Serial.print("  Neptune Magn: ");
	Serial.print(magnitude,1); // neptune magnitude
	Serial.println(); 
#endif
    
//    get_object_position (4, jd, jd_frac);
//    lcd.setCursor(0, 2);
//    lcd.print("Jup "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);
    
//   get_object_position (5, jd, jd_frac);
//    lcd.setCursor(0, 3);
//    lcd.print("Sat "); LCDPlanetData(round(altitudePlanet), round(azimuthPlanet), phase, magnitude);

//    if (full) get_object_position (6, jd, jd_frac); // Uranus
//    if (full) get_object_position (7, jd, jd_frac); // Neptune
  
}  

///////////////////////////END OF EXTRA SUN/MOON/PLANETARY EXTRA STUFF


// subroutine to display all the planets
void elev_azim_disp (float Elevat, float Azim) {
	
   lc.clearDisplay(4); // Clear display register (top 8-digit display showing planets names)
   lc.clearDisplay(5); // Clear display register (upper left and right 4-digit displays showing elevation and aximuth)

// elevation displaying
   lc.setRow(5,4,B01100011); // degree symbol on far right of left 4 digit display
   int elev_a = round(Elevat);// rounded up/down elevation
   int elev_a2 = abs(elev_a); // absolute value of rounded up/down elevation
   byte p_elev1 = elev_a2 / 10; // tens
   byte p_elev2 = elev_a2 % 10; // units
   if (elev_a >= 10) { // if elevation is greater or equal to 10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,6,p_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,p_elev2,false); // display the units digit
     }
   if (elev_a >= 0 && elev_a < 10) { // if elevation is between 0 degrees and 9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,5,p_elev2,false); // display the units digit	   
     }
   if (elev_a < 0 && elev_a > -10) { // if elevation is between -1 degrees and -9 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,6,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,5,p_elev2,false); // display the units digit	   
     }
   if (elev_a <= -10) { // if elevation is less than or equal to -10 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setChar(5,7,'-',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
    lc.setDigit(5,6,p_elev1,false); // display the tens digit	   
    lc.setDigit(5,5,p_elev2,false); // display the units digit
     }   
	 	 
	 
 // azimuth displaying	
   lc.setRow(5,0,B01100011); // degree symbol on far right of right 4 digit display 
   int azim_a = round(Azim);// rounded up/down azimuth
   if (azim_a == 360) azim_a = 0; // if azimuth is 360 then make it 0, as 360 and 0 degrees are the same thing, ie due North. 
   byte p_azim1 = azim_a / 100; // hundreds
   byte p_azim2 = (azim_a / 10) % 10; // tens
   byte p_azim3 = azim_a % 10; // units
   if (azim_a <= 9) {  //if azimuth is less than or equal to 9 degrees (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,1,p_azim3,false); // display the units digit
    }
   if (azim_a >= 10 && azim_a <= 99) { // if azimuth is between 10 and 99 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,2,p_azim2,false); // display the tens digit
    lc.setDigit(5,1,p_azim3,false); // display the units digit
    }	
   if (azim_a > 99 && azim_a <= 359) { // if azimuth is between 100 and 359 degrees inclusive (note, we're only displaying angles to the nearest degree, ie. no decimal points)
    lc.setDigit(5,3,p_azim1,false); // display the hundreds digit
    lc.setDigit(5,2,p_azim2,false); // display the tens digit
    lc.setDigit(5,1,p_azim3,false); // display the units digit
    }
	
}


// subroutine to display the word 'meteors'
void meteors () {
   lc.setChar(4,7,'K',false); // left half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,6,'Z',false); // right half of letter 'M' spread over 2 digits. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,5,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,4,'t',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,3,'E',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,2,'o',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,1,'r',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
   lc.setChar(4,0,'S',false); // arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false
}

/*
// subroutine to blank the far right 4 digits of the 'planents name' 7-seg display in preparation for displaying the planet's magnitude in these digits
void magnitude_prep () {
	   lc.setChar(4,3,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
       lc.setChar(4,2,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
       lc.setChar(4,1,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
       lc.setChar(4,0,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
}
*/


void mag_display (float plan_mag) {
	
	lc.setChar(4,3,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	lc.setChar(4,2,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	lc.setChar(4,1,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	lc.setChar(4,0,' ',false); // blank this row in preparation for displaying the magnitude. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
		
	int mag_a = plan_mag * 10; // magnitude x10 to get rid of decimal point
	int mag_a2 = abs(mag_a); // absolute value of magnitude x 10
	byte p_mag1 = mag_a2 / 10; // tens
	byte p_mag2 = mag_a2 % 10; // units

    lc.setDigit(4,1,p_mag1,true); // display the tens digit (include the decimal point)
    lc.setDigit(4,0,p_mag2,false); // display the units digit   

	if (mag_a < 0) { // if magnitude is less than 0.0
    lc.setChar(4,2,'-',false); // display a minus sign. arguments are: device address, row number, character to display, decimal point lit (true) or unlit (false)
	}
		
}